<?php
/**
 * Webfolio CMS
 *
 * Copyright (C) 2009 Nikola Posa (http://www.nikolaposa.in.rs)
 *
 * This file is part of Webfolio CMS.
 *
 * Webfolio CMS is free software: you can redistribute it and/or modify 
 * it under the terms of the GNU General Public License as published by 
 * the Free Software Foundation, either version 3 of the License, or 
 * (at your option) any later version.
 *
 * Webfolio CMS is distributed in the hope that it will be useful, but 
 * WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU 
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License 
 * along with Webfolio CMS. If not, see <http://www.gnu.org/licenses/>.
 */
 
/**
 * Webfolio CMS bootstrap file.
 *
 * @author Nikola Posa <posa.nikola@gmail.com>
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License
 */
class Bootstrap extends Zend_Application_Bootstrap_Bootstrap
{
	/**
     * Application resource namespace
     * @var false|string
     */
    protected $_appNamespace = '';

	/**
	 * Initializing autoloading utility.
	 *
	 * @return void
	 */
	protected function _initAutoloaders()
    {
        include_once('Zend/Loader/Autoloader.php');
        include_once('WebfolioCMS/Loader.php');

		$autoloader = Zend_Loader_Autoloader::getInstance()
        ->setDefaultAutoloader(array('WebfolioCMS_Loader', 'loadClass'))
		->setFallbackAutoloader(true)
        ->suppressNotFoundWarnings(true);
    }

	/**
	 * Initializing logging system.
	 *
	 * @return void
	 */
    protected function _initLogger()
    {
        $errorLogger = new Zend_Log(new Zend_Log_Writer_Stream(BASE_PATH . '/data/logs/error_log.txt'));
		Zend_Registry::set('errorLogger', $errorLogger);
    }
	
	/**
	 * Initializing database adapter.
	 *
	 * @return void
	 */
	protected function _initDB()
    {
		$options = $this->getOptions();
		
        if (isset($options['db'])) {
            $dbHandler = Zend_Db::factory('mysqli', $options['db']);
			
			Zend_Registry::set('dbHandler', $dbHandler);
            Zend_Db_Table_Abstract::setDefaultAdapter($dbHandler);    
        }
    }
	
	/**
	 * Initializing Zend_Layout.
	 *
	 * @return void
	 */
	protected function _initLayout()
	{
		Zend_Layout::startMvc(BASE_PATH . '/front-end/themes/' . Model_WebfolioSettings::getSettings('theme_dir'))->setLayout('layout.phtml')->disableInflector();
	}
	
	/**
	 * Adding custom action helpers.
	 *
	 * @return void
	 */
	protected function _initActionHelpers()
    {
		Zend_Controller_Action_HelperBroker::addHelper(new WebfolioCMS_Controller_Action_Helper_ModuleControllerInit());
		
		Zend_Controller_Action_HelperBroker::getStack()->offsetSet(189, new WebfolioCMS_Controller_Action_Helper_ThemeEntryRender());
		Zend_Controller_Action_HelperBroker::getStack()->offsetSet(190, new WebfolioCMS_Controller_Action_Helper_ContentParser());
		Zend_Controller_Action_HelperBroker::getStack()->offsetSet(200, new WebfolioCMS_Controller_Action_Helper_WFEntryFinder());
    }
	
	/**
	 * Adding webfolio route.
	 *
	 * @return void
	 */
	protected function _initWebfolioRoute()
    {
		$wfPageName = 'webfolio';
		
		if (Model_WebfolioSettings::getSettings('use_webfolio_page') == true) {
			$sql = "SELECT title_url_format FROM wf_entries WHERE type = 'page' AND id = 2";
			$result = Zend_Registry::get('dbHandler')->fetchRow($sql);
			
			$wfPageName = $result['title_url_format'];
		}
		
		$router = Zend_Controller_Front::getInstance()->getRouter()->addRoute(
			'wf_item', 
			new Zend_Controller_Router_Route_Regex(
				$wfPageName . '([a-zA-Z0-9\-\/]*)\/([a-zA-Z0-9\-]+)',
				array(
					'module' 	 => 'default',
					'controller' => 'index',
					'action' 	 => 'index',
					1 	 		 => ''
				),
				array(1 => 'parents', 2 => 'item'),
				$wfPageName . '%s/%s'
			)
		);
    }
	
	/**
	 * Initializing navigation.
	 *
	 * @return void
	 */
	protected function _initWFNavigation()
    {
		$this->bootstrap('cachemanager');
		
		$webfolioMenu = new Model_WebfolioMenu();
		Zend_Registry::set(Zend_Application_Resource_Navigation::DEFAULT_REGISTRY_KEY, new Zend_Navigation($webfolioMenu->getPages()));
    }
}
?>