<?php
/**
 * Webfolio CMS
 *
 * Copyright (C) 2009 Nikola Posa (http://www.nikolaposa.in.rs)
 *
 * This file is part of Webfolio CMS.
 *
 * Webfolio CMS is free software: you can redistribute it and/or modify 
 * it under the terms of the GNU General Public License as published by 
 * the Free Software Foundation, either version 3 of the License, or 
 * (at your option) any later version.
 *
 * Webfolio CMS is distributed in the hope that it will be useful, but 
 * WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU 
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License 
 * along with Webfolio CMS. If not, see <http://www.gnu.org/licenses/>.
 */
 
/**
 * Controller for handling errors/exceptions in Webfolio CMS.
 *
 * @author Nikola Posa <posa.nikola@gmail.com>
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License
 */
class ErrorController extends Zend_Controller_Action 
{ 
    /**
	 * This action that will be called by the "ErrorHandler" plugin. 
	 * When an error/exception has been encountered in this 
	 * application, Errorhandler will set the next dispatchable 
	 * action to come here.
     *
     * @return void
	 */
    public function errorAction() 
    { 
		$this->_helper->layout->disableLayout();
		
        //Getting error object from the request.
        $errors = $this->_getParam('error_handler'); 

        switch ($errors->type) { 
            case Zend_Controller_Plugin_ErrorHandler::EXCEPTION_NO_CONTROLLER: 
            case Zend_Controller_Plugin_ErrorHandler::EXCEPTION_NO_ACTION: 
                //404 error - controller or action not found.
                $this->getResponse()->setHttpResponseCode(404); 
                $this->view->message = 'Error 404 - Page not found'; 
				
                break; 
            default: 
                //Some application error.
                $this->getResponse()->setHttpResponseCode(500); 
                $this->view->message = 'Application error'; 
				
                break; 
        } 
        
        //Passing actual exception object to the view.
        $this->view->exception = $errors->exception; 
        
        //Pass the request to the view.
        $this->view->request   = $errors->request; 
    } 
}
?>