<?php
/**
 * Webfolio CMS
 *
 * Copyright (C) 2009 Nikola Posa (http://www.nikolaposa.in.rs)
 *
 * This file is part of Webfolio CMS.
 *
 * Webfolio CMS is free software: you can redistribute it and/or modify 
 * it under the terms of the GNU General Public License as published by 
 * the Free Software Foundation, either version 3 of the License, or 
 * (at your option) any later version.
 *
 * Webfolio CMS is distributed in the hope that it will be useful, but 
 * WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU 
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License 
 * along with Webfolio CMS. If not, see <http://www.gnu.org/licenses/>.
 */
 
/**
 * Controller for handling requests for RSS feeds.
 *
 * @author Nikola Posa <posa.nikola@gmail.com>
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License
 */
class FeedController extends Zend_Controller_Action 
{
	const DEFAULT_FEED_FORMAT = 'rss';
	
	/**
	 * Default action.
	 * 
	 * @return void
	 */
	public function indexAction()
	{		
		$format = ($formatParam = $this->_request->getParam('format')) ? $formatParam : self::DEFAULT_FEED_FORMAT;
		
		$this->_helper->layout->disableLayout();
		$this->_helper->viewRenderer->setNoRender();
		
		Zend_Feed::importArray($this->getData(), $format)->send();
	}
	
	/**
	 * Retrieves and prepares data that will be used as feed source.
	 * 
	 * @return array
	 */
	protected function getData()
	{
		$webfolioEntries = new Model_WebfolioEntries('item');
		
		$data = array(
			'title'		=> html_entity_decode(Model_WebfolioSettings::getSettings('site_title'), ENT_COMPAT, 'UTF-8') . ' - webfolio', 
			'link'		=> Model_WebfolioSettings::getSettings('site_url'),
			'charset'   => 'utf8',
			'language'  => Zend_Registry::get('Zend_Locale')->getLanguage(),
			'webmaster' => Model_WebfolioSettings::getSettings('admin_email'),
			'entries'   => array()
		);
		
		if ($wfItems = $webfolioEntries->fetchAll('status = \'published\'', 'datetime DESC')) {
			$data['lastUpdate'] = strtotime($wfItems[0]['datetime']);
			
			$siteUrl = Zend_Uri::factory(Model_WebfolioSettings::getSettings('site_url'));
			
			foreach ($wfItems as $wfItem) {
				$data['entries'][] = array(
					'title'		  => strip_tags(html_entity_decode($wfItem['title'], ENT_QUOTES, 'UTF-8')),
					'link'  	  => $siteUrl->getScheme() . '://' . $siteUrl->getHost() . Zend_Registry::get(Zend_Application_Resource_Navigation::DEFAULT_REGISTRY_KEY)->findOneBy('id', $wfItem['id'])->getHref(),
					'description' => $wfItem['teaser'],
					'lastUpdate'  => strtotime($wfItem['datetime'])
				);
			}
		}
		
		return $data;
	}
}
?>