<?php
/**
 * Webfolio CMS
 *
 * Copyright (C) 2009 Nikola Posa (http://www.nikolaposa.in.rs)
 *
 * This file is part of Webfolio CMS.
 *
 * Webfolio CMS is free software: you can redistribute it and/or modify 
 * it under the terms of the GNU General Public License as published by 
 * the Free Software Foundation, either version 3 of the License, or 
 * (at your option) any later version.
 *
 * Webfolio CMS is distributed in the hope that it will be useful, but 
 * WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU 
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License 
 * along with Webfolio CMS. If not, see <http://www.gnu.org/licenses/>.
 */
 
/**
 * Comments form model.
 *
 * @author Nikola Posa <posa.nikola@gmail.com>
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License
 */
class Form_Comment extends Zend_Form
{
	/**
	 * Constructor.
	 *
	 * @param array Custom validation error messages.
	 * @return Zend_Form
	 */
	public function __construct()
	{
		$authorName = new Zend_Form_Element_Text('authorName', array('required'=>true, 'disableLoadDefaultDecorators'=>true));
		$authorName->addFilters(array('StringTrim', new Zend_Filter_HtmlEntities(array('quotestyle'=>ENT_QUOTES, 'charset'=>'UTF-8'))));
		$authorName->addErrorMessage('nameErrMsg');
				
		$authorEmail = new Zend_Form_Element_Text('authorEmail', array('required'=>true, 'disableLoadDefaultDecorators'=>true));
		$authorEmail->addFilter('StringTrim');
		$authorEmail->addValidator(new Zend_Validate_EmailAddress());
		$authorEmail->addErrorMessage('emailErrMsg');
		
		$authorUrl = new Zend_Form_Element_Text('authorUrl', array('required'=>false, 'disableLoadDefaultDecorators'=>true));
		$authorUrl->addFilter('StringTrim');
		$authorUrl->addValidator(new Zend_Validate_Regex('/^https?:\/\/(www\.)?[a-z0-9\.\-]+\.[a-z]{2,6}(\/?[a-z0-9_\-\.%\?&=]*)*$/i'));
		$authorUrl->addErrorMessage('urlErrMsg');
		
		$text = new Zend_Form_Element_Textarea('text', array('required'=>true, 'disableLoadDefaultDecorators'=>true));
		$text->addFilters(array('StringTrim', new Zend_Filter_HtmlEntities(array('quotestyle'=>ENT_QUOTES, 'charset'=>'UTF-8')), new WebfolioCMS_Filter_PrepareCommentsText()));
		$text->addErrorMessage('textErrMsg');
		
		$WFEntryId = new Zend_Form_Element_Hidden('WFEntryId', array('disableLoadDefaultDecorators'=>true));
		
		$this->setDisableLoadDefaultDecorators(true);
		$this->addElements(array($authorName, $authorEmail, $authorUrl, $text, $WFEntryId));
	}
}
?>