<?php
/**
 * Webfolio CMS
 *
 * Copyright (C) 2009 Nikola Posa (http://www.nikolaposa.in.rs)
 *
 * This file is part of Webfolio CMS.
 *
 * Webfolio CMS is free software: you can redistribute it and/or modify 
 * it under the terms of the GNU General Public License as published by 
 * the Free Software Foundation, either version 3 of the License, or 
 * (at your option) any later version.
 *
 * Webfolio CMS is distributed in the hope that it will be useful, but 
 * WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU 
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License 
 * along with Webfolio CMS. If not, see <http://www.gnu.org/licenses/>.
 */
 
/**
 * Contact form model.
 *
 * @author Nikola Posa <posa.nikola@gmail.com>
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License
 */
class Form_Contact extends Zend_Form
{
    /**
     * Should we disable loading the default decorators?
	 *
     * @var bool
     */
    protected $_disableLoadDefaultDecorators = true;
    
	/**
	 * Initializing form.
	 *
	 * @return Zend_Form
	 */
	public function init()
	{
		$name = new Zend_Form_Element_Text('name', array('label'=>'nameLabel', 'required'=>true, 'disableLoadDefaultDecorators'=>true));
		$name->addFilters(array('StringTrim', new Zend_Filter_HtmlEntities(array('quotestyle'=>ENT_QUOTES, 'charset'=>'UTF-8'))));
		$name->addErrorMessage('nameErrMsg');
		$name->addDecorator('Label')
			->addDecorator(array('errorTag'=>'HtmlTag'), array('tag'=>'span', 'placement'=>'APPEND', 'id'=>'err_name', 'class'=>'error_message'))
			->addDecorator('ViewHelper', array('separator'=>'<br />'))
			->addDecorator(array('pTag'=>'HtmlTag'), array('tag'=>'p'));
				
		$email = new Zend_Form_Element_Text('email', array('label'=>'emailLabel', 'required'=>true, 'disableLoadDefaultDecorators'=>true));
		$email->addFilter('StringTrim');
		$email->addValidator(new Zend_Validate_EmailAddress());
		$email->addErrorMessage('emailErrMsg');
        $email->addDecorator('Label')
			->addDecorator(array('errorTag'=>'HtmlTag'), array('tag'=>'span', 'placement'=>'APPEND', 'id'=>'err_email', 'class'=>'error_message'))
			->addDecorator('ViewHelper', array('separator'=>'<br />'))
			->addDecorator(array('pTag'=>'HtmlTag'), array('tag'=>'p'));
		
		$subject = new Zend_Form_Element_Text('subject', array('label'=>'subjectLabel', 'required'=>true, 'disableLoadDefaultDecorators'=>true));
		$subject->addFilters(array('StringTrim', new Zend_Filter_HtmlEntities(array('quotestyle'=>ENT_QUOTES, 'charset'=>'UTF-8'))));
		$subject->addErrorMessage('subjectErrMsg');
        $subject->addDecorator('Label')
			->addDecorator(array('errorTag'=>'HtmlTag'), array('tag'=>'span', 'placement'=>'APPEND', 'id'=>'err_subject', 'class'=>'error_message'))
			->addDecorator('ViewHelper', array('separator'=>'<br />'))
			->addDecorator(array('pTag'=>'HtmlTag'), array('tag'=>'p'));
		
		$text = new Zend_Form_Element_Textarea('text', array('label'=>'textLabel', 'required'=>true, 'disableLoadDefaultDecorators'=>true, 'rows'=>7, 'cols'=>30));
		$text->addFilters(array('StringTrim', new Zend_Filter_HtmlEntities(array('quotestyle'=>ENT_QUOTES, 'charset'=>'UTF-8'))));
		$text->addErrorMessage('textErrMsg');
        $text->addDecorator('Label')
			->addDecorator(array('errorTag'=>'HtmlTag'), array('tag'=>'span', 'placement'=>'APPEND', 'id'=>'err_text', 'class'=>'error_message'))
			->addDecorator('ViewHelper', array('separator'=>'<br />'))
			->addDecorator(array('pTag'=>'HtmlTag'), array('tag'=>'p'));

		$captcha = new Zend_Form_Element_Captcha('captcha', array('captcha'=>new Zend_Captcha_Figlet(array('font'=>BASE_PATH . '/data/starwars.flf', 'wordLen'=>4)), 'label'=>'captchaLabel', 'size'=>5, 'disableLoadDefaultDecorators'=>true));
        $captcha->addDecorator('Label')
			->addDecorator(array('pTag'=>'HtmlTag'), array('tag'=>'p'))
            ->addDecorator(array('errorTag'=>'HtmlTag'), array('tag'=>'span', 'placement'=>'APPEND', 'id'=>'err_captcha', 'class'=>'error_message'));
        $captcha->getCaptcha()->setMessage('captchaErrMsg', Zend_Captcha_Word::BAD_CAPTCHA);

        $send = new Zend_Form_Element_Button('send', array('label'=>'sendButton', 'disableLoadDefaultDecorators'=>true, 'class'=>'button'));
		$send->addDecorator('ViewHelper')
            ->addDecorator(array('spanTag'=>'HtmlTag'), array('tag'=>'span', 'placement'=>'APPEND', 'id'=>'progressImg', 'style'=>'margin-left: 7px;'))
            ->addDecorator(array('pTag'=>'HtmlTag'), array('tag'=>'p', 'style'=>'margin-top: 10px;'));

		$this->addElements(array($name, $email, $subject, $text, $captcha, $send));

        $this->setAttrib('id', 'contact_form')
			->addDecorator('FormElements')
            ->addDecorator('HtmlTag', array('tag'=>'div', 'placement'=>'APPEND', 'id'=>'message'))
			->addDecorator('Form');

        $this->getView()->headScript(
			Zend_View_Helper_HeadScript::FILE,
			$this->getView()->baseUrl('front-end/js/wf_contact_form.js')
		);
	}
}
?>