<?php
/**
 * Webfolio CMS
 *
 * Copyright (C) 2009 Nikola Posa (http://www.nikolaposa.in.rs)
 *
 * This file is part of Webfolio CMS.
 *
 * Webfolio CMS is free software: you can redistribute it and/or modify 
 * it under the terms of the GNU General Public License as published by 
 * the Free Software Foundation, either version 3 of the License, or 
 * (at your option) any later version.
 *
 * Webfolio CMS is distributed in the hope that it will be useful, but 
 * WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU 
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License 
 * along with Webfolio CMS. If not, see <http://www.gnu.org/licenses/>.
 */
 
/**
 * Model for parsing smileys.
 *
 * @author Nikola Posa <posa.nikola@gmail.com>
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License
 */
class Model_ContentParser_Smileys implements WebfolioCMS_ContentParser_Interface
{
	/**
	 * Smiley pattern - image combination.
	 *
	 * @var array
	 */
	protected $smileysImgs = array(
		'/(:D)/i' 		  => 'biggrin.gif',
		'/(:s)/i' 		  => 'confused.gif',
		'/(:8)/' 		  => 'cool.gif',
		'/(:cry:)/i' 	  => 'cry.gif',
		'/(:eek:)/i' 	  => 'eek.gif',
		'/(:lol:)/i' 	  => 'lol.gif',
		'/(:mad:)/i' 	  => 'mad.gif',
		'/(:\|)/' 		  => 'neutral.gif',
		'/(:p)/i' 		  => 'razz.gif',
		'/(:redface:)/i'  => 'redface.gif',
		'/(:rolleyes:)/i' => 'rolleyes.gif',
		'/(:\()/' 		  => 'sad.gif',
		'/(:\))/' 		  => 'smile.gif',
		'/(:o)/i' 		  => 'surprised.gif',
		'/(?<!&[a-z0-9]{2}&[a-z0-9]{3}|&[a-z0-9]{4}|&[a-z0-9]{5}|&[a-z0-9]{6})(;\))/i' => 'wink.gif' //Omitting HTML entities.
	);
	
	/**
	 * Flag which tells whether user choose to use smileys in 
	 * his/her site.
	 *
	 * @var bool
	 */
	protected $useSmileys;
	
	/**
	 * Constructor.
	 *
	 * @return Model_Parser_SmileysParser
	 */
	public function __construct()
	{	
		//Converting smiley images to <img /> tag.
		foreach ($this->smileysImgs as &$img) {
			$img = '<img src = "' . WebfolioCMS_Common::baseUrl() . '/front-end/img/smileys/' . $img . '" alt = "\1" />';
		}
	
		$this->useSmileys = (bool)Model_WebfolioSettings::getSettings('use_smileys');
	}
	
	/**
	 * Defined by WebfolioCMS_ContentParser_Interface.
	 *
	 * Parses smileys.
	 *
	 * @param string Text that will be parsed.
	 * @return string
	 */
	public function parse($text)
	{
		if ($this->useSmileys == true) {
			$text = preg_replace(array_keys($this->smileysImgs), array_values($this->smileysImgs), $text);
		}
		
		return $text;
	}
}
?>