<?php
/**
 * Webfolio CMS
 *
 * Copyright (C) 2009 Nikola Posa (http://www.nikolaposa.in.rs)
 *
 * This file is part of Webfolio CMS.
 *
 * Webfolio CMS is free software: you can redistribute it and/or modify 
 * it under the terms of the GNU General Public License as published by 
 * the Free Software Foundation, either version 3 of the License, or 
 * (at your option) any later version.
 *
 * Webfolio CMS is distributed in the hope that it will be useful, but 
 * WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU 
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License 
 * along with Webfolio CMS. If not, see <http://www.gnu.org/licenses/>.
 */
 
/**
 * Hook that holds registered content parsers.
 *
 * @author Nikola Posa <posa.nikola@gmail.com>
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License
 */
class Model_ContentParsers extends WebfolioCMS_HookContainer_Abstract
{
	/**
	 * Singleton instance.
	 *
	 * @var Model_ContentParsers
	 */
    protected static $_instance = null;
	
	/**
	 * Defined by WebfolioCMS_Singleton_Interface.
     *
	 * Singleton pattern implementation.
	 *
	 * @return Model_ContentParsers
	 */
	public static function getInstance()
	{
		if (null === self::$_instance) {
            self::$_instance = new self();
        }

        return self::$_instance;
	}
	
	/**
	 * Defined by WebfolioCMS_HookContainer_Interface. 
	 *
	 * Retrieves registered content parsers.
	 *
	 * @return array
	 */
	public static function get()
	{
		$instance = self::getInstance();
		
		return $instance->data;
	}
	
	/**
	 * Defined by WebfolioCMS_HookContainer_Interface. 
	 *
	 * Adds content parser onto stack.
	 *
	 * @param string Content parser class name.
	 * @return void
	 */
	public static function add($className)
	{
		$className = (string)$className;
		
		if (class_exists($className)) {
			$contentParser = new $className();
			
			if ($contentParser instanceof WebfolioCMS_ContentParser_Interface) {
				$instance = self::getInstance();
				
				$instance->store($contentParser);
			}
		}
	}
}
?>