<?php
/**
 * Webfolio CMS
 *
 * Copyright (C) 2009 Nikola Posa (http://www.nikolaposa.in.rs)
 *
 * This file is part of Webfolio CMS.
 *
 * Webfolio CMS is free software: you can redistribute it and/or modify 
 * it under the terms of the GNU General Public License as published by 
 * the Free Software Foundation, either version 3 of the License, or 
 * (at your option) any later version.
 *
 * Webfolio CMS is distributed in the hope that it will be useful, but 
 * WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU 
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License 
 * along with Webfolio CMS. If not, see <http://www.gnu.org/licenses/>.
 */
 
/**
 * WebfolioEntries table data gateway.
 *
 * @author Nikola Posa <posa.nikola@gmail.com>
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License
 */
class Model_DbTable_WebfolioEntries extends NP_Db_Table_NestedSet
{
	/**
     * The table name.
     *
     * @var string
     */
	protected $_name = 'wf_entries';
	
	/**
     * The primary key column.
     *
     * @var string
     */
	protected $_primary = 'id';
	
	/**
     * Left column name in nested table.
     *
     * @var string
     */
	protected $_left = 'lft';
	
	/**
     * Right column name in nested table.
     *
     * @var string
     */
	protected $_right = 'rgt';
	
	/**
     * Simple array of class names of tables that are "children" of 
	 * the current table.
     *
     * @var array
     */
	protected $_dependentTables = array('Model_DbTable_WebfolioComments');
	
	/**
     * Hardcoding metadata because of performance.
     *
     * @var array
     */
	protected $_metadata  = array(
		'id' => array(
			'SCHEMA_NAME'      => null,
			'TABLE_NAME'       => 'wf_entries',
			'COLUMN_NAME'      => 'id',
			'COLUMN_POSITION'  => 1,
			'DATA_TYPE'        => 'int',
			'DEFAULT'          => null,
			'NULLABLE'         => false,
			'LENGTH'           => 10,
			'SCALE'            => null,
			'PRECISION'        => null,
			'UNSIGNED'         => true,
			'PRIMARY'          => true,
			'PRIMARY_POSITION' => 1,
			'IDENTITY'         => true
		),
        'user_id' => array(
			'SCHEMA_NAME'      => null,
			'TABLE_NAME'       => 'wf_entries',
			'COLUMN_NAME'      => 'user_id',
			'COLUMN_POSITION'  => 2,
			'DATA_TYPE'        => 'int',
			'DEFAULT'          => 0,
			'NULLABLE'         => false,
			'LENGTH'           => 10,
			'SCALE'            => null,
			'PRECISION'        => null,
			'UNSIGNED'         => true,
			'PRIMARY'          => false,
			'PRIMARY_POSITION' => null,
			'IDENTITY'         => false
		),
		'lft' => array(
			'SCHEMA_NAME'      => null,
			'TABLE_NAME'       => 'wf_entries',
			'COLUMN_NAME'      => 'lft',
			'COLUMN_POSITION'  => 3,
			'DATA_TYPE'        => 'int',
			'DEFAULT'          => null,
			'NULLABLE'         => false,
			'LENGTH'           => 10,
			'SCALE'            => null,
			'PRECISION'        => null,
			'UNSIGNED'         => true,
			'PRIMARY'          => false,
			'PRIMARY_POSITION' => null,
			'IDENTITY'         => false
		),
		'rgt' => array(
			'SCHEMA_NAME'      => null,
			'TABLE_NAME'       => 'wf_entries',
			'COLUMN_NAME'      => 'rgt',
			'COLUMN_POSITION'  => 4,
			'DATA_TYPE'        => 'int',
			'DEFAULT'          => null,
			'NULLABLE'         => false,
			'LENGTH'           => 10,
			'SCALE'            => null,
			'PRECISION'        => null,
			'UNSIGNED'         => true,
			'PRIMARY'          => false,
			'PRIMARY_POSITION' => null,
			'IDENTITY'         => false
		),
		'title' => array(
			'SCHEMA_NAME'      => null,
			'TABLE_NAME'       => 'wf_entries',
			'COLUMN_NAME'      => 'title',
			'COLUMN_POSITION'  => 5,
			'DATA_TYPE'        => 'varchar',
			'DEFAULT'          => null,
			'NULLABLE'         => false,
			'LENGTH'           => 100,
			'SCALE'            => null,
			'PRECISION'        => null,
			'UNSIGNED'         => null,
			'PRIMARY'          => false,
			'PRIMARY_POSITION' => null,
			'IDENTITY'         => false
		),
		'text' => array(
			'SCHEMA_NAME'      => null,
			'TABLE_NAME'       => 'wf_entries',
			'COLUMN_NAME'      => 'text',
			'COLUMN_POSITION'  => 6,
			'DATA_TYPE'        => 'text',
			'DEFAULT'          => null,
			'NULLABLE'         => false,
			'LENGTH'           => null,
			'SCALE'            => null,
			'PRECISION'        => null,
			'UNSIGNED'         => null,
			'PRIMARY'          => false,
			'PRIMARY_POSITION' => null,
			'IDENTITY'         => false
		),
		'datetime' => array(
			'SCHEMA_NAME'      => null,
			'TABLE_NAME'       => 'wf_entries',
			'COLUMN_NAME'      => 'datetime',
			'COLUMN_POSITION'  => 7,
			'DATA_TYPE'        => 'datetime',
			'DEFAULT'          => null,
			'NULLABLE'         => false,
			'LENGTH'           => null,
			'SCALE'            => null,
			'PRECISION'        => null,
			'UNSIGNED'         => null,
			'PRIMARY'          => false,
			'PRIMARY_POSITION' => null,
			'IDENTITY'         => false
		),
		'title_url_format' => array(
			'SCHEMA_NAME'      => null,
			'TABLE_NAME'       => 'wf_entries',
			'COLUMN_NAME'      => 'title_url_format',
			'COLUMN_POSITION'  => 8,
			'DATA_TYPE'        => 'varchar',
			'DEFAULT'          => null,
			'NULLABLE'         => false,
			'LENGTH'           => 100,
			'SCALE'            => null,
			'PRECISION'        => null,
			'UNSIGNED'         => null,
			'PRIMARY'          => false,
			'PRIMARY_POSITION' => null,
			'IDENTITY'         => false
		),
		'use_comments' => array(
			'SCHEMA_NAME'      => null,
			'TABLE_NAME'       => 'wf_entries',
			'COLUMN_NAME'      => 'use_comments',
			'COLUMN_POSITION'  => 9,
			'DATA_TYPE'        => 'tinyint',
			'DEFAULT'          => 0,
			'NULLABLE'         => false,
			'LENGTH'           => 4,
			'SCALE'            => null,
			'PRECISION'        => null,
			'UNSIGNED'         => null,
			'PRIMARY'          => false,
			'PRIMARY_POSITION' => null,
			'IDENTITY'         => false
		),
		'type' => array(
			'SCHEMA_NAME'      => null,
			'TABLE_NAME'       => 'wf_entries',
			'COLUMN_NAME'      => 'type',
			'COLUMN_POSITION'  => 10,
			'DATA_TYPE'        => 'varchar',
			'DEFAULT'          => 'item',
			'NULLABLE'         => false,
			'LENGTH'           => 40,
			'SCALE'            => null,
			'PRECISION'        => null,
			'UNSIGNED'         => null,
			'PRIMARY'          => false,
			'PRIMARY_POSITION' => null,
			'IDENTITY'         => false
		),
		'status' => array(
			'SCHEMA_NAME'      => null,
			'TABLE_NAME'       => 'wf_entries',
			'COLUMN_NAME'      => 'status',
			'COLUMN_POSITION'  => 11,
			'DATA_TYPE'        => "enum('published','ready','draft')",
			'DEFAULT'          => null,
			'NULLABLE'         => false,
			'LENGTH'           => null,
			'SCALE'            => null,
			'PRECISION'        => null,
			'UNSIGNED'         => null,
			'PRIMARY'          => false,
			'PRIMARY_POSITION' => null,
			'IDENTITY'         => false
		)
	);

    /**
     * Associative array map of declarative referential integrity rules.
     * This array has one entry per foreign key in the current table.
     * Each key is a mnemonic name for one reference rule.
     *
     * @var array
     */
	protected $_referenceMap = array(
        'WFUsers' => array(
            'columns'       => array('user_id'),
            'refTableClass' => 'Model_DbTable_WebfolioUsers',
            'refColumns'    => array('id')
        )
    );
	
	/**
	 * Retrieves title of entry with supplied id.
	 * 
	 * @param int Id of a webfolio entry.
	 * @return string|null
	 */
	public function getTitleById($id)
	{
		$id = (int)$id;
		
		$sql = "SELECT title FROM $this->_name WHERE id = " . $this->getAdapter()->quote($id, Zend_Db::INT_TYPE);
		
		if ($result = $this->getAdapter()->fetchRow($sql)) {
			return $result['title'];
		}
		else {
			return null;
		}
	}
}
?>