<?php
/**
 * Webfolio CMS
 *
 * Copyright (C) 2009 Nikola Posa (http://www.nikolaposa.in.rs)
 *
 * This file is part of Webfolio CMS.
 *
 * Webfolio CMS is free software: you can redistribute it and/or modify 
 * it under the terms of the GNU General Public License as published by 
 * the Free Software Foundation, either version 3 of the License, or 
 * (at your option) any later version.
 *
 * Webfolio CMS is distributed in the hope that it will be useful, but 
 * WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU 
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License 
 * along with Webfolio CMS. If not, see <http://www.gnu.org/licenses/>.
 */
 
/**
 * WebfolioGroupAcl table data gateway.
 *
 * @author Nikola Posa <posa.nikola@gmail.com>
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License
 */
class Model_DbTable_WebfolioGroupAcl extends Zend_Db_Table
{
	/**
     * The table name.
     *
     * @var string
     */
	protected $_name = 'wf_group_acl';
	
	/**
     * The primary key column.
     *
     * @var string
     */
	protected $_primary = 'id';
	
	/**
     * Hardcoding metadata because of performance.
     *
     * @var array
     */
	protected $_metadata  = array(
		'id' => array(
			'SCHEMA_NAME'      => null,
			'TABLE_NAME'       => 'wf_group_acl',
			'COLUMN_NAME'      => 'id',
			'COLUMN_POSITION'  => 1,
			'DATA_TYPE'        => 'int',
			'DEFAULT'          => null,
			'NULLABLE'         => false,
			'LENGTH'           => 10,
			'SCALE'            => null,
			'PRECISION'        => null,
			'UNSIGNED'         => true,
			'PRIMARY'          => true,
			'PRIMARY_POSITION' => 1,
			'IDENTITY'         => true
		),
		'group_id' => array(
			'SCHEMA_NAME'      => null,
			'TABLE_NAME'       => 'wf_group_acl',
			'COLUMN_NAME'      => 'group_id',
			'COLUMN_POSITION'  => 2,
			'DATA_TYPE'        => 'int',
			'DEFAULT'          => null,
			'NULLABLE'         => true,
			'LENGTH'           => 10,
			'SCALE'            => null,
			'PRECISION'        => null,
			'UNSIGNED'         => true,
			'PRIMARY'          => false,
			'PRIMARY_POSITION' => null,
			'IDENTITY'         => false
		),
        'resource' => array(
			'SCHEMA_NAME'      => null,
			'TABLE_NAME'       => 'wf_group_acl',
			'COLUMN_NAME'      => 'resource',
			'COLUMN_POSITION'  => 3,
			'DATA_TYPE'        => 'varchar',
			'DEFAULT'          => null,
			'NULLABLE'         => false,
			'LENGTH'           => 200,
			'SCALE'            => null,
			'PRECISION'        => null,
			'UNSIGNED'         => null,
			'PRIMARY'          => false,
			'PRIMARY_POSITION' => null,
			'IDENTITY'         => false
		),
        'privilege' => array(
			'SCHEMA_NAME'      => null,
			'TABLE_NAME'       => 'wf_group_acl',
			'COLUMN_NAME'      => 'privilege',
			'COLUMN_POSITION'  => 4,
			'DATA_TYPE'        => 'varchar',
			'DEFAULT'          => null,
			'NULLABLE'         => true,
			'LENGTH'           => 200,
			'SCALE'            => null,
			'PRECISION'        => null,
			'UNSIGNED'         => null,
			'PRIMARY'          => false,
			'PRIMARY_POSITION' => null,
			'IDENTITY'         => false
		),
        'assert' => array(
			'SCHEMA_NAME'      => null,
			'TABLE_NAME'       => 'wf_group_acl',
			'COLUMN_NAME'      => 'assert',
			'COLUMN_POSITION'  => 5,
			'DATA_TYPE'        => 'text',
			'DEFAULT'          => null,
			'NULLABLE'         => true,
			'LENGTH'           => null,
			'SCALE'            => null,
			'PRECISION'        => null,
			'UNSIGNED'         => null,
			'PRIMARY'          => false,
			'PRIMARY_POSITION' => null,
			'IDENTITY'         => false
		)
	);

    /**
     * Associative array map of declarative referential integrity rules.
     * This array has one entry per foreign key in the current table.
     * Each key is a mnemonic name for one reference rule.
     *
     * @var array
     */
	protected $_referenceMap = array(
        'WFGroups' => array(
            'columns'       => array('group_id'),
            'refTableClass' => 'Model_DbTable_WebfolioGroups',
            'refColumns'    => array('id'),
            'onDelete'      => self::CASCADE
        )
    );

    /**
     * Default group ACLs.
     *
     * @var array
     */
    private static $_defaultGroupACLs = array(
        array('resource'=>'admin_login'), //Every user has access to LoginController.
        array('resource'=>'admin_logout'), //... and LogoutController, too.
        array('resource'=>'admin_index'), //Everyone has access to the start page of admin panel.
        array('resource'=>'admin_users', 'privilege'=>'edit', 'assert'=>'WebfolioCMS_Acl_Assert_UserProfile'), //Every user can edit his/her own profile.
        //Every user should have access to taxonomy add/edit actions, and then additional modules
        //can override those rules, as taxonomy admin controller does checking againsta supplied
        //taxonomy name.
        array('resource'=>'taxonomy_admin', 'privilege'=>'add-term'),
        array('resource'=>'taxonomy_admin', 'privilege'=>'edit-term')
    );

    /**
     * Gets default group ACLs.
     *
     * @var array
     */
    public static function getDefaultGroupACLs()
    {
        return self::$_defaultGroupACLs;
    }
}
?>