<?php
/**
 * Webfolio CMS
 *
 * Copyright (C) 2009 Nikola Posa (http://www.nikolaposa.in.rs)
 *
 * This file is part of Webfolio CMS.
 *
 * Webfolio CMS is free software: you can redistribute it and/or modify 
 * it under the terms of the GNU General Public License as published by 
 * the Free Software Foundation, either version 3 of the License, or 
 * (at your option) any later version.
 *
 * Webfolio CMS is distributed in the hope that it will be useful, but 
 * WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU 
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License 
 * along with Webfolio CMS. If not, see <http://www.gnu.org/licenses/>.
 */
 
/**
 * WebfolioUsers table data gateway.
 *
 * @author Nikola Posa <posa.nikola@gmail.com>
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License
 */
class Model_DbTable_WebfolioUsers extends Zend_Db_Table
{
    const USERS_TABLE_ALIAS = 'u';
	const GROUP_TABLE_ALIAS = 'g';
    const USER_META_TABLE_ALIAS = 'um';

	/**
     * The table name.
     *
     * @var string
     */
	protected $_name = 'wf_users';
	
	/**
     * The primary key column.
     *
     * @var string
     */
	protected $_primary = 'id';

    /**
     * Simple array of class names of tables that are "children" of
	 * the current table.
     *
     * @var array
     */
	protected $_dependentTables = array('Model_DbTable_WebfolioEntries', 'Model_DbTable_WebfolioUserMeta');
	
	/**
     * Hardcoding metadata because of performance.
     *
     * @var array
     */
	protected $_metadata  = array(
		'id' => array(
			'SCHEMA_NAME'      => null,
			'TABLE_NAME'       => 'wf_users',
			'COLUMN_NAME'      => 'id',
			'COLUMN_POSITION'  => 1,
			'DATA_TYPE'        => 'int',
			'DEFAULT'          => null,
			'NULLABLE'         => false,
			'LENGTH'           => 10,
			'SCALE'            => null,
			'PRECISION'        => null,
			'UNSIGNED'         => true,
			'PRIMARY'          => true,
			'PRIMARY_POSITION' => 1,
			'IDENTITY'         => true
		),
        'group_id' => array(
			'SCHEMA_NAME'      => null,
			'TABLE_NAME'       => 'wf_users',
			'COLUMN_NAME'      => 'group_id',
			'COLUMN_POSITION'  => 2,
			'DATA_TYPE'        => 'int',
			'DEFAULT'          => 0,
			'NULLABLE'         => false,
			'LENGTH'           => 10,
			'SCALE'            => null,
			'PRECISION'        => null,
			'UNSIGNED'         => true,
			'PRIMARY'          => false,
			'PRIMARY_POSITION' => null,
			'IDENTITY'         => false
		),
		'username' => array(
			'SCHEMA_NAME'      => null,
			'TABLE_NAME'       => 'wf_users',
			'COLUMN_NAME'      => 'username',
			'COLUMN_POSITION'  => 3,
			'DATA_TYPE'        => 'varchar',
			'DEFAULT'          => null,
			'NULLABLE'         => false,
			'LENGTH'           => 40,
			'SCALE'            => null,
			'PRECISION'        => null,
			'UNSIGNED'         => null,
			'PRIMARY'          => false,
			'PRIMARY_POSITION' => null,
			'IDENTITY'         => false
		),
		'password' => array(
			'SCHEMA_NAME'      => null,
			'TABLE_NAME'       => 'wf_users',
			'COLUMN_NAME'      => 'password',
			'COLUMN_POSITION'  => 4,
			'DATA_TYPE'        => 'varchar',
			'DEFAULT'          => null,
			'NULLABLE'         => false,
			'LENGTH'           => 40,
			'SCALE'            => null,
			'PRECISION'        => null,
			'UNSIGNED'         => null,
			'PRIMARY'          => false,
			'PRIMARY_POSITION' => null,
			'IDENTITY'         => false
		),
		'password_salt' => array(
			'SCHEMA_NAME'      => null,
			'TABLE_NAME'       => 'wf_users',
			'COLUMN_NAME'      => 'password_salt',
			'COLUMN_POSITION'  => 5,
			'DATA_TYPE'        => 'varchar',
			'DEFAULT'          => null,
			'NULLABLE'         => false,
			'LENGTH'           => 10,
			'SCALE'            => null,
			'PRECISION'        => null,
			'UNSIGNED'         => null,
			'PRIMARY'          => false,
			'PRIMARY_POSITION' => null,
			'IDENTITY'         => false
		),
		'email' => array(
			'SCHEMA_NAME'      => null,
			'TABLE_NAME'       => 'wf_users',
			'COLUMN_NAME'      => 'email',
			'COLUMN_POSITION'  => 6,
			'DATA_TYPE'        => 'varchar',
			'DEFAULT'          => null,
			'NULLABLE'         => false,
			'LENGTH'           => 100,
			'SCALE'            => null,
			'PRECISION'        => null,
			'UNSIGNED'         => null,
			'PRIMARY'          => false,
			'PRIMARY_POSITION' => null,
			'IDENTITY'         => false
		),
		'registration_datetime' => array(
			'SCHEMA_NAME'      => null,
			'TABLE_NAME'       => 'wf_users',
			'COLUMN_NAME'      => 'registration_datetime',
			'COLUMN_POSITION'  => 7,
			'DATA_TYPE'        => 'datetime',
			'DEFAULT'          => null,
			'NULLABLE'         => false,
			'LENGTH'           => null,
			'SCALE'            => null,
			'PRECISION'        => null,
			'UNSIGNED'         => null,
			'PRIMARY'          => false,
			'PRIMARY_POSITION' => null,
			'IDENTITY'         => false
		),
        'public_name' => array(
			'SCHEMA_NAME'      => null,
			'TABLE_NAME'       => 'wf_users',
			'COLUMN_NAME'      => 'public_name',
			'COLUMN_POSITION'  => 8,
			'DATA_TYPE'        => 'varchar',
			'DEFAULT'          => null,
			'NULLABLE'         => false,
			'LENGTH'           => 250,
			'SCALE'            => null,
			'PRECISION'        => null,
			'UNSIGNED'         => null,
			'PRIMARY'          => false,
			'PRIMARY_POSITION' => null,
			'IDENTITY'         => false
		)
	);

    /**
     * Associative array map of declarative referential integrity rules.
     * This array has one entry per foreign key in the current table.
     * Each key is a mnemonic name for one reference rule.
     *
     * @var array
     */
	protected $_referenceMap = array(
        'WFGroups' => array(
            'columns'       => array('group_id'),
            'refTableClass' => 'Model_DbTable_WebfolioGroups',
            'refColumns'    => array('id')
        )
    );

    /**
	 * Retrieves users along with related group and meta info.
	 *
	 * @param string|array|Zend_Db_Table_Select|null $where An SQL WHERE clause or Zend_Db_Table_Select object.
     * @param string|array|null                      $order An SQL ORDER clause.
	 * @param int|null                               $count OPTIONAL An SQL LIMIT count.
     * @param int|null                           	 $offset OPTIONAL An SQL LIMIT offset.
	 * @return Zend_Db_Table_Rowset|Zend_Db_Table_Row
	 */
    public function getManyWithMetaGroup($where = null, $order = null, $count = null, $offset = null)
    {
        $result = $this->prepareWithMetaGroupSelect($this->fetchAll($this->getMetaGroupSelect($where, $order, $count, $offset)));

        $data  = array(
            'table'    => $this,
            'data'     => $result,
            'readOnly' => false,
            'rowClass' => $this->getRowClass(),
            'stored'   => true
        );

        $rowsetClass = $this->getRowsetClass();
        
        return new $rowsetClass($data);
    }

    /**
	 * Retrieves users along with related group and meta info.
	 *
	 * @param string|array|Zend_Db_Table_Select|null $where An SQL WHERE clause or Zend_Db_Table_Select object.
     * @param string|array|null                      $order An SQL ORDER clause.
	 * @param int|null                               $count OPTIONAL An SQL LIMIT count.
     * @param int|null                           	 $offset OPTIONAL An SQL LIMIT offset.
	 * @return Zend_Db_Table_Row|null
	 */
    public function getOneWithMetaGroup($where = null, $order = null)
    {
        $result = $this->prepareWithMetaGroupSelect($this->fetchAll($this->getMetaGroupSelect($where, $order)));

        if (count($result) == 0) { //No results?
            return null;
        }
        else {
             $data = array(
                'table'   => $this,
                'data'     => $result[0],
                'readOnly' => false,
                'stored'  => true
            );

            $rowClass = $this->getRowClass();

            return new $rowClass($data);
        }
    }

    /**
	 * Generates and returns select that is used for
     * getManyWithMetaGroup() and getOneWithMetaGroup() methods.
     * 
     * This query will contain information about the group
     * related to some user, including meta info, gathered from
     * wf_user_meta db table.
	 *
	 * @param string|array|Zend_Db_Table_Select|null $where An SQL WHERE clause or Zend_Db_Table_Select object.
     * @param string|array                           $order An SQL ORDER clause.
	 * @param int|null                               $count OPTIONAL An SQL LIMIT count.
     * @param int|null                           	 $offset OPTIONAL An SQL LIMIT offset.
     * @return Zend_Db_Table_Select
	 */
	protected function getMetaGroupSelect($where, $order, $count = null, $offset = null)
	{
		$select = $this->select()->setIntegrityCheck(false)
			->from(array(self::USERS_TABLE_ALIAS => $this->_name), array(self::USERS_TABLE_ALIAS . '.*'))
			->joinLeft(array(self::GROUP_TABLE_ALIAS=>'wf_groups'), '(' . self::GROUP_TABLE_ALIAS . '.id = ' . self::USERS_TABLE_ALIAS . '.group_id)', array('g_id'=>self::GROUP_TABLE_ALIAS . '.id','g_name'=>self::GROUP_TABLE_ALIAS . '.name'))
			->joinLeft(array(self::USER_META_TABLE_ALIAS=>'wf_user_meta'), self::USER_META_TABLE_ALIAS . '.user_id = ' . self::USERS_TABLE_ALIAS . '.id', array('meta_key'=>self::USER_META_TABLE_ALIAS . '.key','meta_value'=>self::USER_META_TABLE_ALIAS . '.value'));

		if ($where !== null) {
			$this->_where($select, $where);
		}

		if ($order !== null) {
			$this->_order($select, $order);
		}

		if ($count !== null || $offset !== null) {
			$select->limit($count, $offset);
		}
        
		return $select;
	}

    /**
	 * Because wf_users and wf_groups db tables share some column
	 * names, this functions stores all groups and user-meta related
     * data that was fetched with query from getMetaGroupSelect()
     * method, into StdClass objects, and adds those objects as new
     * elements of the returing array, withcategory/meta as their
     * keys.
	 *
	 * @param Zend_Db_Table_Rowset Results containing user and its group/meta info.
	 * @return array
	 */
	protected function prepareWithMetaGroupSelect($result)
	{
        $users = array();
        
        $resultRows = $result->toArray();

        $meta = array();

        foreach ($resultRows as $key => $row) {
            if ($row['meta_key'] != null) { //Has some meta info?
                $meta[$row['meta_key']] = $row['meta_value'];
            }
            
            if ($resultRows[$key+1]['id'] != $row['id']) { //Different user?
                //Creating group data.
                $group = new StdClass();
                $group->id = $row['g_id'];
                $group->name = $row['g_name'];

                unset($row['g_id']);
                unset($row['g_name']);

                $row['group'] = $group;
                
                unset($row['meta_key']);
                unset($row['meta_value']);

                 if (!empty($meta)) { //We should store gathered meta at this point.
                    $userMeta = new StdClass();
                    foreach ($meta as $metaKey => $metaValue) {
                        $userMeta->$metaKey = $metaValue;
                    }

                    $row['meta'] = $userMeta;
                    $meta = array(); //Reseting $meta array.
                }
                
                $users[] = $row;
            }
        }

		return $users;
	}
}
?>