<?php
/**
 * Webfolio CMS
 *
 * Copyright (C) 2009 Nikola Posa (http://www.nikolaposa.in.rs)
 *
 * This file is part of Webfolio CMS.
 *
 * Webfolio CMS is free software: you can redistribute it and/or modify 
 * it under the terms of the GNU General Public License as published by 
 * the Free Software Foundation, either version 3 of the License, or 
 * (at your option) any later version.
 *
 * Webfolio CMS is distributed in the hope that it will be useful, but 
 * WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU 
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License 
 * along with Webfolio CMS. If not, see <http://www.gnu.org/licenses/>.
 */
 
/**
 * Hook that holds registered sidebar items.
 *
 * @author Nikola Posa <posa.nikola@gmail.com>
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License
 */
class Model_WFSidebar extends WebfolioCMS_HookContainer_HelperBased_Abstract
{	
	/**
	 * Singleton instance.
	 *
	 * @var Model_WFSidebar
	 */
    protected static $_instance = null;
	
	/**
	 * Defined by WebfolioCMS_Singleton_Interface.
     *
	 * Singleton pattern implementation.
	 *
	 * @return Model_WFSidebar
	 */
	public static function getInstance()
	{
		if (null === self::$_instance) {
            self::$_instance = new self();
        }

        return self::$_instance;
	}
	
	/**
	 * Defined by WebfolioCMS_HookContainer_Interface. 
	 * 
	 * Retrieves registered sidebar items.
	 *
	 * @return array
	 */
	public static function get()
	{
		$instance = self::getInstance();
		
		return $instance->data;
	}
	
	/**
	 * Defined by WebfolioCMS_HookContainer_Interface. 
	 *
	 * Adds sidebar item onto stack.
	 *
	 * Supported params for $sidebarItem are:
     *   helperName - Name of the view helper that will be used for rendering sidebar item (string),
	 *   title - Title that will be set by default, and that is rendered at the top of every sidebar block (string) - optional.
	 *
	 * @param array Sidebar item data.
	 * @return void
	 */
	public static function add($sidebarItem)
	{
		$instance = self::getInstance();
		
		$instance->_doAdd($sidebarItem);
	}
	
	/**
	 * Defined by WebfolioCMS_HookContainer_Abstract.
	 *
	 * Prepares data of some sidebar item, before adding it into 
	 * sidebar items stack.
	 *
	 * @param array Sidebar item data.
	 * @return array
	 */
	protected function prepare($sidebarItem)
	{
		$sidebarItem['title'] = '';
		
		if (!array_key_exists('userFriendlyName', $sidebarItem)) {
			$sidebarItem['userFriendlyName'] = $this->getUserFriendlyName($sidebarItem['helperName']);
		}
		
		return $sidebarItem;
	}
	
	/**
	 * Generates user friendly name of some sidebar ViewHelper name.
	 *
	 * @param string ViewHelper name.
	 * @return string
	 */
	protected function getUserFriendlyName($helperFileName)
	{
		$helperFileName = preg_replace('/(wf)?sidebar/i', '', $helperFileName);
		
		$cc2s = new Zend_Filter_Word_CamelCaseToSeparator();
		
		return $cc2s->filter($helperFileName);
	}
}
?>