<?php
/**
 * Webfolio CMS
 *
 * Copyright (C) 2009 Nikola Posa (http://www.nikolaposa.in.rs)
 *
 * This file is part of Webfolio CMS.
 *
 * Webfolio CMS is free software: you can redistribute it and/or modify 
 * it under the terms of the GNU General Public License as published by 
 * the Free Software Foundation, either version 3 of the License, or 
 * (at your option) any later version.
 *
 * Webfolio CMS is distributed in the hope that it will be useful, but 
 * WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU 
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License 
 * along with Webfolio CMS. If not, see <http://www.gnu.org/licenses/>.
 */
 
/**
 * WebfolioComments model.
 *
 * Utilizes the Data Mapper pattern to persist data. Represents 
 * a single comments entry.
 * 
 * @author Nikola Posa <posa.nikola@gmail.com>
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License
 */
class Model_WebfolioComments extends Model_Base
{
	/**
	 * Comment's id.
	 *
	 * @var int
	 */
	protected $id;
	
	/**
	 * Id of webfolio item in which this comment is posted.
	 *
	 * @var int
	 */
	protected $WFEntryId;
	
	/**
	 * Name of the comment's author.
	 *
	 * @var string
	 */
	protected $authorName;
	
	/**
	 * Email of the comment's author.
	 *
	 * @var string
	 */
	protected $authorEmail;
	
	/**
	 * Website url of the comment's author.
	 *
	 * @var string
	 */
	protected $authorUrl;
	
	/**
	 * IP address of the comment's author.
	 * 
	 * @var string
	 */
	protected $authorIp;
	
	/**
	 * Browser info of the comment's author.
	 *
	 * @var string
	 */
	protected $authorBrowser;
	
	/**
	 * Comment's text.
	 *
	 * @var string
	 */
	protected $text;
	
	/**
	 * Datetime of comments creation.
	 *
	 * @var string
	 */
	protected $datetime;
	
	/**
	 * Comment's status.
	 *
	 * @var string
	 */
	protected $status;

	/**
	 * Sets comment's id.
	 * 
	 * @param int Comment's id.
	 * @return Model_WebfolioComments
	 */
    public function setId($id)
    {
        $this->id = (int) $id;
		
        return $this;
    }

    /**
	 * Retrieves comment's id.
	 * 
	 * @return null|int
	 */
    public function getId()
    {
        return $this->id;
    }
	
	/**
	 * Sets webofilio entry id.
	 * 
	 * @param int Webofilio entry id.
	 * @return Model_WebfolioComments
	 */
    public function setWFEntryId($WFEntryId)
    {
        $this->WFEntryId = (int) $WFEntryId;
		
        return $this;
    }

    /**
	 * Retrieves webofilio entry id.
	 * 
	 * @return null|int
	 */
    public function getWFEntryId()
    {
        return $this->WFEntryId;
    }
	
	/**
	 * Sets comment's author name.
	 * 
	 * @param string Comment's author name.
	 * @return Model_WebfolioComments
	 */
    public function setAuthorName($authorName)
    {
        $this->authorName = $authorName;
		
        return $this;
    }

    /**
	 * Retrieves comment's author name.
	 * 
	 * @return null|string
	 */
    public function getAuthorName()
    {
        return $this->authorName;
    }
	
	/**
	 * Sets comment's author email.
	 * 
	 * @param string Comment's author email.
	 * @return Model_WebfolioComments
	 */
    public function setAuthorEmail($authorEmail)
    {
        $this->authorEmail = $authorEmail;
		
        return $this;
    }

    /**
	 * Retrieves comment's author email.
	 * 
	 * @return null|string
	 */
    public function getAuthorEmail()
    {
        return $this->authorEmail;
    }
	
	/**
	 * Sets comment's author url.
	 * 
	 * @param string Comment's author url.
	 * @return Model_WebfolioComments
	 */
    public function setAuthorUrl($authorUrl)
    {
        $this->authorUrl = $authorUrl;
		
        return $this;
    }

    /**
	 * Retrieves comment's author url.
	 * 
	 * @return null|string
	 */
    public function getAuthorUrl()
    {
        return $this->authorUrl;
    }
	
	/**
	 * Sets comment's author IP address.
	 * 
	 * @param string Comment's author IP address.
	 * @return Model_WebfolioComments
	 */
    public function setAuthorIp($authorIp)
    {
        $this->authorIp = $authorIp;
		
        return $this;
    }

    /**
	 * Retrieves comment's author IP address.
	 * 
	 * @return null|string
	 */
    public function getAuthorIp()
    {
        return $this->authorIp;
    }
	
	/**
	 * Sets comment's author browser information.
	 * 
	 * @param string Comment's author IP address.
	 * @return Model_WebfolioComments
	 */
    public function setAuthorBrowser($authorBrowser)
    {
        $this->authorBrowser = $authorBrowser;
		
        return $this;
    }

    /**
	 * Retrieves comment's author browser information.
	 * 
	 * @return null|string
	 */
    public function getAuthorBrowser()
    {
        return $this->authorBrowser;
    }
	
	/**
	 * Sets comment's text.
	 * 
	 * @param string Comment's text.
	 * @return Model_WebfolioComments
	 */
    public function setText($text)
    {	
        $this->text = $text;
		
        return $this;
    }

    /**
	 * Retrieves comment's text.
	 * 
	 * @return null|string
	 */
    public function getText()
    {
        return $this->text;
    }
	
	/**
	 * Sets comment's datetime.
	 * 
	 * @param string Comment's datetime.
	 * @return Model_WebfolioComments
	 */
    public function setDatetime($datetime)
    {
        $this->datetime = $datetime;
		
        return $this;
    }

    /**
	 * Retrieves comment's datetime.
	 * 
	 * @return null|string
	 */
    public function getDatetime()
    {
        return $this->datetime;
    }
	
	/**
	 * Sets comment's status.
	 * 
	 * @param string Comment's status.
	 * @return Model_WebfolioComments
	 */
    public function setStatus($status)
    {
        $this->status = $status;
		
        return $this;
    }

    /**
	 * Retrieves comment's status.
	 * 
	 * @return null|string
	 */
    public function getStatus()
    {
        return $this->status;
    }
	
	/**
	 * Saves current comments entry.
	 * 
	 * @return mixed
	 */
	public function save()
    {
		//Getting additional data about user who submitted comment.
		$this->authorIp 	 = $_SERVER['REMOTE_ADDR']; 
		$this->authorBrowser = $_SERVER['HTTP_USER_AGENT']; 
		
		//Setting datetime.
		$this->datetime = new Zend_DB_Expr('NOW()'); 
		
		$this->status = 'approved'; 
		
		$limit = (int)Model_WebfolioSettings::getSettings('comments_visitor_limit');
		
		if (!WebfolioCMS_Common::isUserLoggedIn() && strlen($limit) > 0 && (int)$this->getMapper()->isOverLimit($limit, $this->WFEntryId, $this->authorIp) >= $limit) {
			$this->status = 'overLimit';
			return;
		}
		
		//Storing data about user who posted comment.
		$commentAuthor = new Zend_Session_Namespace('commentAuthor');
		$commentAuthor->name  = $this->authorName;
		$commentAuthor->email = $this->authorEmail;
		$commentAuthor->url   = $this->authorUrl;
		
		//Notifying comment pre-save hook.
		WebfolioCMS_Events_Broker::notifyEventHandlers(WebfolioCMS_Events_Broker::WF_COMMENT_PRE_SAVE, array($this));
		
		$retval = $this->getMapper()->save($this);	
		
		//Notifying comment post-save hook.
		WebfolioCMS_Events_Broker::notifyEventHandlers(WebfolioCMS_Events_Broker::WF_COMMENT_POST_SAVE, array($this));
		
		return $retval;
    }
}
?>