<?php
/**
 * Webfolio CMS
 *
 * Copyright (C) 2009 Nikola Posa (http://www.nikolaposa.in.rs)
 *
 * This file is part of Webfolio CMS.
 *
 * Webfolio CMS is free software: you can redistribute it and/or modify 
 * it under the terms of the GNU General Public License as published by 
 * the Free Software Foundation, either version 3 of the License, or 
 * (at your option) any later version.
 *
 * Webfolio CMS is distributed in the hope that it will be useful, but 
 * WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU 
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License 
 * along with Webfolio CMS. If not, see <http://www.gnu.org/licenses/>.
 */
 
/* DEPRECATED FROM VERSION 1.0.2 */

/**
 * Main model that retrieves data of all pages (home, 
 * webfolio, contact and webfolio items).
 *
 * @author Nikola Posa <posa.nikola@gmail.com>
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License
 */
class Model_WebfolioMain extends Model_WebfolioBase
{	
	/**
	 * Whether user selected to use webfolio page.
	 *
	 * @var bool
	 */
	protected $useWebfolioPage;
	
	/**
	 * Constructor.
	 *
	 * @return Model_WebfolioBase
	 */
	public function __construct()
	{
		parent::__construct();
		
		$this->useWebfolioPage = Model_WebfolioSettings::getSettings('use_webfolio_page');
	}

	/**
	 * Property for getting useWebfolioPage flag.
	 *
	 * @return bool
	 */
	public function getUseWebfolioPage()
	{
		return $this->useWebfolioPage;
	}
	
	/**
	 * Getting data of custom page.
	 *
	 * @param string|null Webfolio page name (url format).
	 * @return array
	 */
	public function getWebfolioPage($page = null)
	{	
		if ($page == null) { //Home page?
			$sql = "SELECT * FROM wf_entries WHERE id = 1 AND type = 'page' AND status = 'published'";
		}
		else {
			$page = (string)$page;
			
			$sql = $this->dbHandler->quoteInto("SELECT * FROM wf_entries WHERE title_url_format = ? AND type = 'page' AND status = 'published'", $page);
		}
		
		$page = $this->dbHandler->fetchRow($sql);
	
		return $page;
	}
	
	/**
	 * Getting data of one webfolio item.
	 *
	 * @param string Webfolio item name (url format).
	 * @return array
	 */
	public function getWebfolioItem($name)
	{
		$pageAddWhere = '';	
		if ($this->useWebfolioPage == true) {
			$pageAddWhere = "OR (i.type = 'page' AND i.id = 2)";
		}
		
		$sql = $this->dbHandler->quoteInto("SELECT i.id, i.title, i.text, i.short_desc, i.title_url_format, i.datetime AS 'date', i.use_comments, i.type, (IF(i.type = 'item',COUNT(parent.id) - (sub_tree.depth + 1),-100)) AS depth
			FROM wf_entries AS i,
				wf_entries AS parent,
				(
					SELECT i.id, i.lft, i.rgt, (COUNT(parent.id) - 1) AS depth
					FROM wf_entries AS i,
					wf_entries AS parent
					WHERE i.lft BETWEEN parent.lft AND parent.rgt
					AND i.title_url_format = ? AND i.type = 'item' AND i.status = 'published'
					GROUP BY i.id
					ORDER BY i.lft
				) AS sub_tree
			WHERE i.lft BETWEEN parent.lft AND parent.rgt
				AND ((sub_tree.lft BETWEEN i.lft AND i.rgt) $pageAddWhere)
				AND i.status = 'published'
			GROUP BY i.id
			HAVING depth <= 1
			ORDER BY i.lft", $name);
			
		$result = $this->dbHandler->fetchAll($sql);
		
		$webfolioItem = null;
		
		if (!empty($result)) {
			$parents = array();
		
			foreach ($result as $row) {
				if ((int)$row['depth'] < 0) { //Parents?
					$parents[] = array('title'=>$row['title'], 'title_url_format'=>$row['title_url_format'], 'type'=>$row['type']);
				}
				else { //Wanted item.
					$webfolioItem = $row;
				}
			}
			
			if (count($parents) > 0) {
				$webfolioItem['parents'] = $parents;
			}
		}
		
		return $webfolioItem;
	}
}
?>