<?php
/**
 * Webfolio CMS
 *
 * Copyright (C) 2009 Nikola Posa (http://www.nikolaposa.in.rs)
 *
 * This file is part of Webfolio CMS.
 *
 * Webfolio CMS is free software: you can redistribute it and/or modify 
 * it under the terms of the GNU General Public License as published by 
 * the Free Software Foundation, either version 3 of the License, or 
 * (at your option) any later version.
 *
 * Webfolio CMS is distributed in the hope that it will be useful, but 
 * WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU 
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License 
 * along with Webfolio CMS. If not, see <http://www.gnu.org/licenses/>.
 */
 
/**
 * Model for getting data that will be used for generating 
 * menus (navbar and sidebar).
 *
 * @author Nikola Posa <posa.nikola@gmail.com>
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License
 */
class Model_WebfolioMenu extends Model_WebfolioBase
{
	const CACHE_ID = 'wf_menu';
	
	/**
	 * Getts all available pages, including webfolio items.
	 *
	 * @return array
	 */
	public function getPages()
	{
		$pages = array();
		
		if (!$pages = Zend_Registry::get('CacheManager')->getCache('default')->load(self::CACHE_ID)) {
			$sql = "(SELECT entry.id, entry.title, entry.title_url_format, entry.status, (COUNT(parent.id) - 1) AS 'depth'
			FROM wf_entries entry, wf_entries parent
			WHERE (entry.lft BETWEEN parent.lft AND parent.rgt) AND (entry.type = 'page' OR entry.type = 'item')
			GROUP BY entry.id)
			ORDER BY entry.lft";
			
			$menuItems = $this->dbHandler->fetchAll($sql);
			
			if (!empty($menuItems)) {
			
				//Home page.
				$pages[] = array(
					'label'  => $menuItems[0]['title'],
					'route'  => 'wf_page',
					'params' => array('page'=>false)
				);
				
				$webfolioItems = $this->nestedToArray(array_slice($menuItems, 3));
				
				if (Model_WebfolioSettings::getSettings('use_webfolio_page') == true) { //Using webfolio page? 
					$pages[] = array(
						'label'  => $menuItems[1]['title'],
						'route'  => 'wf_page',
						'params' => array('page'=>$menuItems[1]['title_url_format']),
						'pages'	 => $webfolioItems
					);
				}
				else {
					$pages = array_merge($pages, $webfolioItems);
				}
				
				//Contact page.
				$pages[] = array(
					'label'  => $menuItems[2]['title'],
					'route'  => 'wf_page',
					'params' => array('page'=>$menuItems[2]['title_url_format'])
				);
			}
			
			Zend_Registry::get('CacheManager')->getCache('default')->save($pages, self::CACHE_ID, array('wf_item', 'wf_page'));
		}
		
		return $pages;
	}
	
	/**
	 * Generate nested array from the webfolio items array, utilizing 
	 * WebfolioCMS_NestedSetManipulation class.
	 *
	 * @param array Webfolio items array, in form of nested model.
	 * @return array
	 */
	protected function nestedToArray($items)  
	{  
		$nestedSetManipulation = new WebfolioCMS_NestedSetManipulation();
		
		$items = $nestedSetManipulation->addParentsInfo($items, 'parents', 'title_url_format');
		
		$itemPages = array();
		
		foreach ($items as $key=>$item) {
			$data = array(
				'depth'      => $item['depth'],
				'type'		 => 'WebfolioCMS_Navigation_Page_Mvc',
				'id'		 => $item['id'],
				'visible'	 => ($item['status'] == 'published'),
				'label'  	 => $item['title'],
				'route'  	 => 'wf_item',
				'controller' => 'index',
				'action' 	 => 'index',
				'params' 	 => array('item'=>$item['title_url_format'], 'parents'=>'')
			); 
			
			if (isset($item['parents'])) {
				$data['params']['parents'] = '/' . implode('/', $item['parents']);
			}
			
			$itemPages[] = $data;
		}
		
		return $nestedSetManipulation->nestedToArray($itemPages, 'pages');
	}  
}
?>