<?php
/**
 * Webfolio CMS
 *
 * Copyright (C) 2009 Nikola Posa (http://www.nikolaposa.in.rs)
 *
 * This file is part of Webfolio CMS.
 *
 * Webfolio CMS is free software: you can redistribute it and/or modify 
 * it under the terms of the GNU General Public License as published by 
 * the Free Software Foundation, either version 3 of the License, or 
 * (at your option) any later version.
 *
 * Webfolio CMS is distributed in the hope that it will be useful, but 
 * WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU 
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License 
 * along with Webfolio CMS. If not, see <http://www.gnu.org/licenses/>.
 */
 
/**
 * WebfolioUsers model.
 *
 * Utilizes the Data Mapper pattern to persist data. Represents 
 * a single user.
 * 
 * @author Nikola Posa <posa.nikola@gmail.com>
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License
 */
class Model_WebfolioUsers extends Model_Base
{
	/**
	 * User's id.
	 *
	 * @var int
	 */
	protected $id;

    /**
	 * Id of a group in which user belongs to.
	 *
	 * @var int
	 */
	protected $groupId;
	
	/**
	 * Username.
	 *
	 * @var string
	 */
	protected $username;
	
	/**
	 * Password.
	 *
	 * @var string
	 */
	protected $password;
	
	/**
	 * Password salt (used in salting mechanism).
	 *
	 * @var string
	 */
	protected $passwordSalt;
	
	/**
	 * User's email address.
	 *
	 * @var string
	 */
	protected $email;
	
	/**
	 * Date and time when user was registered.
	 *
	 * @var string
	 */
	protected $registrationDateTime;

    /**
	 * Name that is publicly displayed.
	 *
	 * @var string
	 */
	protected $publicName;
	
	/**
	 * Sets id.
	 * 
	 * @param int User id.
	 * @return Model_WebfolioUsers
	 */
    public function setId($id)
    {
        $this->id = (int) $id;
		
        return $this;
    }

    /**
	 * Retrieves user's id.
	 * 
	 * @return null|int
	 */
    public function getId()
    {
        return $this->id;
    }

    /**
	 * Sets group id.
	 *
	 * @param int Group id.
	 * @return Model_WebfolioUsers
	 */
    public function setGroupId($groupId)
    {
        $this->groupId = (int) $groupId;

        return $this;
    }

    /**
	 * Retrieves user's group id.
	 *
	 * @return null|int
	 */
    public function getGroupId()
    {
        return $this->groupId;
    }
	
	/**
	 * Sets username.
	 * 
	 * @param string Username.
	 * @return Model_WebfolioUsers
	 */
    public function setUsername($username)
    {
        $this->username = $username;
		
        return $this;
    }

    /**
	 * Retrieves username.
	 * 
	 * @return null|string
	 */
    public function getUsername()
    {
        return $this->username;
    }
	
	/**
	 * Sets password.
	 * 
	 * @param string Password.
	 * @return Model_WebfolioUsers
	 */
    public function setPassword($password)
    {
		$this->password = $password;
		
        return $this;
    }

    /**
	 * Retrieves password.
	 * 
	 * @return null|string
	 */
    public function getPassword()
    {
        return $this->password;
    }
	
	/**
	 * Sets password salt.
	 * 
	 * @param string Password salt.
	 * @return Model_WebfolioUsers
	 */
    public function setPasswordSalt($passwordSalt)
    {
		$this->passwordSalt = $passwordSalt;
		
        return $this;
    }

    /**
	 * Retrieves password salt.
	 * 
	 * @return null|string
	 */
    public function getPasswordSalt()
    {
        return $this->passwordSalt;
    }
	
	/**
	 * Sets user's email.
	 * 
	 * @param string Email address.
	 * @return Model_WebfolioUsers
	 */
    public function setEmail($email)
    {
		$this->email = $email;
		
        return $this;
    }

    /**
	 * Retrieves user's email.
	 * 
	 * @return null|string
	 */
    public function getEmail()
    {
        return $this->email;
    }
	
	/**
	 * Sets registration date-time.
	 * 
	 * @param string Registration date and time.
	 * @return Model_WebfolioUsers
	 */
    public function setRegistrationDateTime($registrationDateTime)
    {
		$this->registrationDateTime = $registrationDateTime;
		
        return $this;
    }

    /**
	 * Retrieves registration date-time.
	 * 
	 * @return null|string
	 */
    public function getRegistrationDateTime()
    {
        return $this->registrationDateTime;
    }

    /**
	 * Sets public name.
	 *
	 * @param string Public name.
	 * @return Model_WebfolioUsers
	 */
    public function setPublicName($publicName)
    {
		$this->publicName = $publicName;

        return $this;
    }

    /**
	 * Retrieves public name.
	 *
	 * @return null|string
	 */
    public function getPublicName()
    {
        return $this->publicName;
    }

	/**
	 * Saves current user.
	 * 
	 * @return mixed
	 */
	public function save()
    {
		if ($this->id == null) { //Insert mode? We should generate password salt, password and registration datetime.
			$this->passwordSalt = Text_Password::create(10, 'unpronounceable');
			
			//Making sure that there are no duplicate password salts.
			while ($this->fetchRow(array('password_salt = ?'=>$this->passwordSalt)) != null) {
				$this->passwordSalt = Text_Password::create(10, 'unpronounceable');
			}
			
			$this->password = sha1($this->password . $this->passwordSalt);
			$this->registrationDateTime = new Zend_DB_Expr('NOW()');
            $this->publicName = $this->username; //Public name should be same as username by default.
		}

		return $this->getMapper()->save($this);
    }
}
?>