<?php
/**
 * Webfolio CMS
 *
 * Copyright (C) 2009 Nikola Posa (http://www.nikolaposa.in.rs)
 *
 * This file is part of Webfolio CMS.
 *
 * Webfolio CMS is free software: you can redistribute it and/or modify 
 * it under the terms of the GNU General Public License as published by 
 * the Free Software Foundation, either version 3 of the License, or 
 * (at your option) any later version.
 *
 * Webfolio CMS is distributed in the hope that it will be useful, but 
 * WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU 
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License 
 * along with Webfolio CMS. If not, see <http://www.gnu.org/licenses/>.
 */
 
/**
 * WebfolioComments data mapper.
 *
 * Implements the Data Mapper design pattern.
 * 
 * @author Nikola Posa <posa.nikola@gmail.com>
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License
 */
class Model_Mapper_WebfolioComments extends Model_Mapper_Base
{
	/**
	 * Defined by Model_Mapper_Base.
	 *
	 * We must alter authorIp value to be stored using INET_ATON() 
	 * MySQL function.
	 * 
	 * @param Model_Base Model instance.
	 * @return array
	 */
	protected function prepareData($model)
	{
		$data  = parent::prepareData($model);
		
		$data['author_ip'] = new Zend_Db_Expr('INET_ATON(' . $this->getDbTable()->getAdapter()->quote($data['author_ip']) . ')');
		
		return $data;
	}
	
	/**
	 * Defined by Model_Mapper_Base.
	 * 
	 * @param string|array|Zend_Db_Table_Select An SQL WHERE clause or Zend_Db_Table_Select object. (optional)
     * @param string|array OPTIONAL An SQL ORDER clause. (optional)
     * @param int OPTIONAL An SQL LIMIT count. (optional)
     * @param int OPTIONAL An SQL LIMIT offset. (optional)
	 * @return array
	 */
	public function fetchAll($where, $order, $count, $offset)
    {
		return parent::fetchAll($this->getSelectQuery($where, $order, $count, $offset));
    }
	
	/**
	 * Defined by Model_Mapper_Base.
	 * 
	 * @param string|array|Zend_Db_Table_Select An SQL WHERE clause or Zend_Db_Table_Select object. (optional)
     * @param string|array OPTIONAL An SQL ORDER clause. (optional)
	 * @return Model_Base|null
	 */
	public function fetchRow($where, $order)
    {
		return parent::fetchRow($this->getSelectQuery($where, $order));
    }
	
	/**
	 * Generates and returns Zend_Db_Table_Select object, that will 
	 * have author_ip column value returned using INET_NTOA() MySQL 
	 * function.
	 * 
	 * @param string|array|Zend_Db_Table_Select An SQL WHERE clause or Zend_Db_Table_Select object.
     * @param string|array OPTIONAL An SQL ORDER clause.
     * @param int OPTIONAL An SQL LIMIT count. (optional)
     * @param int OPTIONAL An SQL LIMIT offset. (optional)
	 * @return Zend_Db_Table_Select
	 */
	protected function getSelectQuery($where, $order, $count = null, $offset = null)
	{
		$select = $this->getDbTable()->select();
		
		$select->from($this->getDbTable()->info(Zend_Db_Table_Abstract::NAME), array(
			'id',
			'wf_entry_id',
			'author_name',
			'author_email',
			'author_url',
			'author_ip'=>new Zend_Db_Expr('INET_NTOA(author_ip)'),
			'author_browser',
			'text',
			'datetime',
			'status'
		));
		
		if ($where != null) {	
			if (!is_array($where)) {
				$where = array($where);
			}
				
			foreach ($where as $key => $val) {
				if (is_int($key)) {
					$select->where($val);
				} 
				else {
					$select->where($key, $val);
				}
			}
		}
		
		if ($order !== null) {
			if (!is_array($order)) {
				$order = array($order);
			}

			foreach ($order as $val) {
				$select->order($val);
			}
		}
		
		if ($count !== null || $offset !== null) {
			$select->limit($count, $offset);
		}
		
		return $select;
	}
}
?>