<?php
/**
 * Webfolio CMS
 *
 * Copyright (C) 2009 Nikola Posa (http://www.nikolaposa.in.rs)
 *
 * This file is part of Webfolio CMS.
 *
 * Webfolio CMS is free software: you can redistribute it and/or modify 
 * it under the terms of the GNU General Public License as published by 
 * the Free Software Foundation, either version 3 of the License, or 
 * (at your option) any later version.
 *
 * Webfolio CMS is distributed in the hope that it will be useful, but 
 * WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU 
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License 
 * along with Webfolio CMS. If not, see <http://www.gnu.org/licenses/>.
 */
 
/**
 * Admin panel controller for user's site appearance (themes, 
 * sidebar, content plugins).
 *
 * @author Nikola Posa <posa.nikola@gmail.com>
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License
 */
class Admin_AppearanceController extends Zend_Controller_Action 
{		
	/**
	 * Overloading pre-dispatch hook.
	 *
	 * @return void
	 */
	public function preDispatch()
	{
		//Index action should be automatically routed to either categories or items action.
		if ($this->_request->getActionName() == 'index') {
			$this->_forward('themes');
		}
	}
	
	/**
	 * Default action.
	 * 
	 * @return void
	 */
	public function indexAction()
	{	
	}
	
	/**
	 * Manages themes.
	 * 
	 * @return void
	 */
	public function themesAction()
	{	
		if ($themeDir = $this->_request->getParam('theme-dir')) { //Editing some theme?
            if (!WebfolioCMS_Common::isUserAllowed(WebfolioCMS_Auth::getInstance()->getIdentity()->group_id, 'admin_appearance_themes', 'edit')) {
                throw new Exception('You are not allowed to access requested resource.');
            }

			$this->view->dirName = $themeDir;
		
			try {
				$themesDir = new Admin_Model_DirContent_Themes();
				
				$this->view->themeContent = $themesDir->getThemeContent($themeDir);
			}
			catch (Exception $ex) {
				$this->view->message = $ex->getMessage();
				$this->view->ok = false;
			}
		}
	}
	
	/**
	 * Manages sidebar items.
	 * 
	 * @return void
	 */
	public function sidebarAction()
	{	
	}
	
	/**
	 * Manages content plugins.
	 * 
	 * @return void
	 */
	public function contentPluginsAction()
	{	
	}
}
?>