<?php
/**
 * Webfolio CMS
 *
 * Copyright (C) 2009 Nikola Posa (http://www.nikolaposa.in.rs)
 *
 * This file is part of Webfolio CMS.
 *
 * Webfolio CMS is free software: you can redistribute it and/or modify 
 * it under the terms of the GNU General Public License as published by 
 * the Free Software Foundation, either version 3 of the License, or 
 * (at your option) any later version.
 *
 * Webfolio CMS is distributed in the hope that it will be useful, but 
 * WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU 
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License 
 * along with Webfolio CMS. If not, see <http://www.gnu.org/licenses/>.
 */
 
/**
 * Admin panel controller for handling requests for managing 
 * comments.
 *
 * @author Nikola Posa <posa.nikola@gmail.com>
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License
 */
class Admin_CommentsController extends Zend_Controller_Action 
{		
	/**
	 * Webfolio comments model instance.
	 * 
	 * @var Admin_Model_WebfolioComments
	 */
	protected $webfolioComments;
	
	/**
	 * Initialize object.
	 * 
	 * @return void
	 */
	public function init()
    {
		$this->webfolioComments = new Admin_Model_WebfolioComments();
    }
	
	/**
	 * Default action. Displays grid for managing comments.
	 * 
	 * @return void
	 */
	public function indexAction()
	{	
	}
	
	/**
	 * Action for editing comment.
	 * 
	 * @return void
	 */
	public function editAction()
	{	
		if ($id = $this->_request->getParam('comment')) { 
			$commentForm = new Admin_Form_Comment();
			
			$where = $this->webfolioComments->getMapper()->getDbTable()->getAdapter()->quoteInto('id = ?', $id);
			
			$webfolioComment = $this->webfolioComments->fetchRow($where);
				
			if ($this->_request->isPost()) { //Form submitted?
				$formData = $this->_request->getPost();
				
				if ($commentForm->isValid($formData)) { //Valid data?	
					$data = $commentForm->getValues();
					
					try {		
						$webfolioComment->setOptions($data);
						$webfolioComment->save();

						$this->_helper->flashMessenger('Comment data has been saved.');
							
						$this->_helper->redirector->gotoRoute(array('comment'=>$webfolioComment->getId()), 'admin_comments_edit', true);
					}
					catch (Exception $ex) {
						$this->view->message = $ex->getMessage();
						$this->view->ok = false;
					}
				}
			}
			else { //Display form for editing page.
				if ($webfolioComment == null) {
					$this->view->error = 'Unexisting comment.';
				}
				else {
					$commentForm->populate($webfolioComment->toArray());
					
					if ($this->_helper->flashMessenger->hasMessages()) {
						$this->view->message = current($this->_helper->flashMessenger->getMessages());
						$this->view->ok = true;
					}
				}
			}
			
			$this->view->form = $commentForm;
		}
	}
	
	/**
	 * Displays grid for managing comments that are marked as spam.
	 * 
	 * @return void
	 */
	public function spamAction()
	{	
	}
}
?>