<?php
/**
 * Webfolio CMS
 *
 * Copyright (C) 2009 Nikola Posa (http://www.nikolaposa.in.rs)
 *
 * This file is part of Webfolio CMS.
 *
 * Webfolio CMS is free software: you can redistribute it and/or modify 
 * it under the terms of the GNU General Public License as published by 
 * the Free Software Foundation, either version 3 of the License, or 
 * (at your option) any later version.
 *
 * Webfolio CMS is distributed in the hope that it will be useful, but 
 * WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU 
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License 
 * along with Webfolio CMS. If not, see <http://www.gnu.org/licenses/>.
 */
 
/**
 * Controller for managing users groups.
 *
 * @author Nikola Posa <posa.nikola@gmail.com>
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License
 */
class Admin_GroupsController extends Zend_Controller_Action
{
    protected $_groupsForm;

    protected $_groupsDbTable;

    /**
	 * Initializing controller.
	 *
	 * @return void
	 */
    public function init()
    {
        $this->_groupsForm = new Admin_Form_Groups();

        $this->_groupsDbTable = new Model_DbTable_WebfolioGroups();
    }

    /**
	 * Overloading pre-dispatch hook.
	 *
	 * @return void
	 */
    public function preDispatch()
    {
        if (in_array($this->_request->getActionName(), array('add', 'edit'))) {
            $this->_helper->layout->setLayoutPath(APPLICATION_PATH . '/modules/admin/layouts/basic');
        }
    }

	/**
	 * Default action.
	 * 
	 * @return void
	 */
	public function indexAction()
	{	
		
	}

    /**
	 * Action for adding new group.
	 *
	 * @return void
	 */
	public function addAction()
	{
        if ($this->_request->isPost()) {
            $formData = $this->_request->getPost();

            if ($this->_groupsForm->isValid($formData)) {
                $this->_groupsDbTable->insert($this->_groupsForm->getValues());

                $this->view->ok = true;
            }
            else {
                $this->view->formData = $this->_groupsForm->getValues();
                $this->view->errorMessages = $this->_groupsForm->getMessages();
            }
        }
	}

    /**
	 * Action for editing some group.
	 *
	 * @return void
	 */
	public function editAction()
	{
        if ($id = (int)$this->_request->getParam('id')) {
            $where = array('id = ?'=>$id);

            if (array_key_exists($id, Model_DbTable_WebfolioGroups::getReadOnlyGroups())) {
                $readOnlyGroups = Model_DbTable_WebfolioGroups::getReadOnlyGroups();
                $this->view->error = $readOnlyGroups[$id] . ' group can not be edited or deleted.';
            }
            else {
                if ($this->_request->isPost()) {
                    $formData = $this->_request->getPost();

                    if ($this->_groupsForm->isValid($formData)) {
                        $this->_groupsDbTable->update($this->_groupsForm->getValues(), $where);

                        $this->view->ok = true;
                    }
                    else {
                        $this->view->formData = $this->_groupsForm->getValues();
                        $this->view->errorMessages = $this->_groupsForm->getMessages();
                    }
                }
                else {
                    $this->view->formData = $this->_groupsDbTable->fetchRow($where);
                }
            }
        }
	}
}
?>