<?php
/**
 * Webfolio CMS
 *
 * Copyright (C) 2009 Nikola Posa (http://www.nikolaposa.in.rs)
 *
 * This file is part of Webfolio CMS.
 *
 * Webfolio CMS is free software: you can redistribute it and/or modify 
 * it under the terms of the GNU General Public License as published by 
 * the Free Software Foundation, either version 3 of the License, or 
 * (at your option) any later version.
 *
 * Webfolio CMS is distributed in the hope that it will be useful, but 
 * WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU 
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License 
 * along with Webfolio CMS. If not, see <http://www.gnu.org/licenses/>.
 */
 
/**
 * Controller for handling login requests.
 *
 * @author Nikola Posa <posa.nikola@gmail.com>
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License
 */
class Admin_LoginController extends Zend_Controller_Action 
{
	/**
	 * Default action (login).
	 * 
	 * @return void
	 */
	public function indexAction()
	{
		$redirectTo = $this->_helper->Url('', 'index', 'admin');
		
		$WFAdminSession = new Zend_Session_Namespace('WFAdmin');
		if ($WFAdminSession->__isset('redirectTo')) {
			$redirectTo = $WFAdminSession->__get('redirectTo');
		}
		
		if ($this->_request->isPost()) { //Login request either from AJAX or HTTP.
			$message = '';
			
			$loginForm = new Admin_Form_Login();
			
			$formData = $this->_request->getPost();
			
			if ($loginForm->isValid($formData)) {	
				try {
					if ($this->authenticate($loginForm->getValues())) { //If user exists in database.
						$message = 'ok';
					}
					else { //... and if not, return error message.
						$message = Zend_Registry::get('Zend_Translate')->translate('incorrectUserPass');
					}
				}
				catch (Exception $ex) {
					$message = 'An error occured. Please try later.';
				}
			}
			else {
				$message = Zend_Registry::get('Zend_Translate')->translate('fillBothUserAndPass');
			}
		
			if ($this->_request->isXmlHttpRequest()) { //Login request from AJAX.
				$this->_helper->layout->disableLayout();
				$this->_helper->viewRenderer->setNoRender();
				
				if ($message == 'ok') {
					$WFAdminSession->__unset('redirectTo');
					
					echo '#ok#' . $redirectTo;
				}
				else {
					echo $message;
				}
			}
			else { //Request from login form.
				if ($message == 'ok') {
					$WFAdminSession->__unset('redirectTo');
					
					$this->_redirect(str_replace(Zend_Controller_Front::getInstance()->getBaseUrl(), '', $redirectTo));
				}
				else {
					$this->view->message = $message;
				}
			}
		}
	}
	
	/**
	 * Handler requests for password recovery.
	 * 
	 * @return void
	 */
	public function passwordRecoveryAction()
	{
		if ($key = $this->_request->getParam('key')) {
			$webfolioUsers = new Model_WebfolioUsers();

			//Checking whether key is valid.
			$where = $webfolioUsers->getMapper()->getDbTable()->getAdapter()->quoteInto('SHA1(password_salt) = ?', $key);
			$user = $webfolioUsers->fetchRow($where);
			
			if ($user != null) {
				$newPassword = Text_Password::create(12, 'unpronounceable');
				
				try {
					$user->setPassword(sha1($newPassword . $user->passwordSalt));
					$user->save();
					
					$text = 'Here is your new password: <b>' . $newPassword . '</b>';
				
					$webfolioMail = new WebfolioCMS_Mail('utf-8');
					@ $webfolioMail->addTo($user->email)->setSubject('Password recovery')->setBodyHtml($text)->send();
					
					$this->view->message = 'New password has been sent to your email.';
					$this->view->ok = true;
				}
				catch (Zend_Mail_Exception $ex) {
					$this->view->message = 'Your password is changed, but email with new password could not have been sent to you. You should try doing password recovery process one more time.';
					$this->view->ok = false;
					$this->view->messageWidth = 400;
				}
				catch (Exception $ex) {
					$this->view->message = 'An error occurred. Please try later.';
					$this->view->ok = false;
				}
			}
			else {
				$this->view->message = 'Invalid key.';
				$this->view->ok = false;
			}
		}
		else {
			$this->view->message = 'Incomplete request.';
			$this->view->ok = false;
		}
	}
	
	/**
	 * Does the authentication process by utilizing WebfolioCMS_Auth 
	 * class.
	 * 
	 * @param array Data from the login form.
	 * @return bool
	 */
	protected function authenticate($data)
	{
		$adapter = new WebfolioCMS_Auth_Adapter_DbTable();
		$adapter->setIdentity($data['username']);
		$adapter->setCredential($data['password']);
		
		$retval = WebfolioCMS_Auth::getInstance()->authenticate($adapter)->isValid();

        if ($retval === true && $data['staySignedIn'] == '1')
        {
            Model_WebfolioSettings::updateSetting('remember_me_marker', '1');
        }
        else {
            Model_WebfolioSettings::updateSetting('remember_me_marker', '0');
        }

        return $retval;
	}
}
?>