<?php
/**
 * Webfolio CMS
 *
 * Copyright (C) 2009 Nikola Posa (http://www.nikolaposa.in.rs)
 *
 * This file is part of Webfolio CMS.
 *
 * Webfolio CMS is free software: you can redistribute it and/or modify 
 * it under the terms of the GNU General Public License as published by 
 * the Free Software Foundation, either version 3 of the License, or 
 * (at your option) any later version.
 *
 * Webfolio CMS is distributed in the hope that it will be useful, but 
 * WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU 
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License 
 * along with Webfolio CMS. If not, see <http://www.gnu.org/licenses/>.
 */
 
/**
 * Admin panel controller for handling requests for managing 
 * webfolio pages.
 *
 * @author Nikola Posa <posa.nikola@gmail.com>
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License
 */
class Admin_PagesController extends Zend_Controller_Action 
{		
	/**
	 * Webfolio pages model instance.
	 * 
	 * @var Admin_Model_WebfolioEntries
	 */
	protected $webfolioPages;
	
	/**
	 * Initialize object.
	 * 
	 * @return void
	 */
	public function init()
    {
		$this->webfolioPages = new Admin_Model_WebfolioEntries('page');
    }
	
	/**
	 * Default action. Displays all webfolio pages.
	 * 
	 * @return void
	 */
	public function indexAction()
	{	
		$this->view->allPages = $this->webfolioPages->fetchAll();
	}
	
	/**
	 * Action for editing webfolio page.
	 * 
	 * @return void
	 */
	public function editAction()
	{	
		if ($page = $this->_request->getParam('page')) { 
			$pageForm = new Admin_Form_Page();
			
			$where = $this->webfolioPages->getMapper()->getDbTable()->getAdapter()->quoteInto('title_url_format = ?', $page);
			
			$webfolioPage = $this->webfolioPages->fetchRow($where);
				
			if ($this->_request->isPost()) { //Form submitted?
				$formData = $this->_request->getPost();
				
				if ($pageForm->isValid($formData)) { //Valid data?	
					$data = $pageForm->getValues();
					
					try {		
						$webfolioPage->setOptions($data);
						$webfolioPage->save();

						$this->_helper->flashMessenger('Your page data has been saved.');
							
						$this->_helper->redirector->gotoRoute(array('page'=>$webfolioPage->getTitleUrlFormat()), 'admin_pages_edit', true);
					}
					catch (Exception $ex) {
						$this->view->message = $ex->getMessage();
						$this->view->ok = false;
					}
				}
			}
			else { //Display form for editing page.
				if ($webfolioPage == null) {
					$this->view->error = 'Unexisting page.';
				}
				else {
					$pageForm->populate($webfolioPage->toArray());
					
					if ($this->_helper->flashMessenger->hasMessages()) {
						$this->view->message = current($this->_helper->flashMessenger->getMessages());
						$this->view->ok = true;
					}
				}
			}
			
			$this->view->form = $pageForm;
		}
	}
}
?>