<?php
/**
 * Webfolio CMS
 *
 * Copyright (C) 2009 Nikola Posa (http://www.nikolaposa.in.rs)
 *
 * This file is part of Webfolio CMS.
 *
 * Webfolio CMS is free software: you can redistribute it and/or modify 
 * it under the terms of the GNU General Public License as published by 
 * the Free Software Foundation, either version 3 of the License, or 
 * (at your option) any later version.
 *
 * Webfolio CMS is distributed in the hope that it will be useful, but 
 * WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU 
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License 
 * along with Webfolio CMS. If not, see <http://www.gnu.org/licenses/>.
 */
 
/**
 * Admin panel settings controller.
 *
 * @author Nikola Posa <posa.nikola@gmail.com>
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License
 */
class Admin_SettingsController extends Zend_Controller_Action 
{		
	/**
	 * Model for handling appropriate settings.
	 *
	 * @var Admin_Model_WebfolioSettings_Abstract
	 */
	protected $model;
	
	/**
	 * Appropriate settings form (if any exists).
	 *
	 * @var Zend_Form
	 */
	protected $form = null;
	
	/**
	 * Overloading pre-dispatch hook.
	 *
	 * @return void
	 */
	public function preDispatch()
	{
		//Index action should be automatically routed to "general" action.
		if ($this->_request->getActionName() == 'index') {
			$this->_forward('general');
		}
	}
	
	/**
	 * Initialize object.
	 * 
	 * @return void
	 */
	public function init()
    {
		$action = (($actionName = $this->_request->getActionName()) == 'index') ? 'general' : $actionName;
		$action = ucfirst($action);
		
		//Initializing model and form instances.
		
		$modelName = 'Admin_Model_WebfolioSettings_' . $action;
		$formName = 'Admin_Form_' . $action . 'Settings';
		
		$this->model = new $modelName();
		
		if (Zend_Loader::isReadable(APPLICATION_PATH . '/modules/admin/forms/' . $action . 'Settings.php')) {
			$this->form = new $formName();
		}
    }
	
	/**
	 * Default action.
	 * 
	 * @return void
	 */
	public function indexAction()
	{	
	}
	
	/**
	 * General setting action.
	 * 
	 * @return void
	 */
	public function generalAction()
	{	
		$this->whatToDo();
	}
	
	/**
	 * Application setting action.
	 * 
	 * @return void
	 */
	public function appAction()
	{	
		$this->whatToDo();
	}
	
	/**
	 * Comments setting action.
	 * 
	 * @return void
	 */
	public function commentsAction()
	{	
		$this->whatToDo();
	}
	
	/**
	 * Common code for all actions of this controller. Does the 
	 * validation of form and saves submitted data.
	 * 
	 * @return void
	 */
	protected function whatToDo()
	{
		if ($this->_request->isPost()) { //Form submitted?
			$formData = $this->_request->getPost();
			
			$settingsSaved = true;
			
			if ($this->form !== null) {
				if ($this->form->isValid($formData)) {
					$this->saveSettings($this->form->getValues());
				}
				else {
					$settingsSaved = false;
					$this->view->errorMessages = $this->form->getMessages();
				}
			}
			else {
				unset($formData['save']); //We don't need "save" button.
				$this->saveSettings($formData);
			}
			
			//Cleaning default cache if user is editting app settings form, because of "Use webfolio page" setting.
			if ($settingsSaved == true && $this->_request->getActionName() == 'app') {
				Zend_Registry::get('CacheManager')->getCache('default')->clean(Zend_Cache::CLEANING_MODE_MATCHING_ANY_TAG, array('wf_page', 'wf_item'));
			}
			
			$this->view->fieldValues = $formData;
		}
		else {
			$this->view->fieldValues = $this->model->getValues();
		}
	}
	
	/**
	 * Does the saving of submitted settings form data.
	 * 
	 * @param array Data from the form.
	 * @return void
	 */
	protected function saveSettings($data)
	{
		try {
			$this->model->save($data);
					
			$this->view->message = 'Your settings have been saved.';
			$this->view->ok = true;
		}
		catch (Exception $ex) {
			$this->view->message = $ex->getMessage(); //'An error occured. Your settings could not have been saved.';
			$this->view->ok = false;
		}
	}
}
?>