<?php
/**
 * Webfolio CMS
 *
 * Copyright (C) 2009 Nikola Posa (http://www.nikolaposa.in.rs)
 *
 * This file is part of Webfolio CMS.
 *
 * Webfolio CMS is free software: you can redistribute it and/or modify 
 * it under the terms of the GNU General Public License as published by 
 * the Free Software Foundation, either version 3 of the License, or 
 * (at your option) any later version.
 *
 * Webfolio CMS is distributed in the hope that it will be useful, but 
 * WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU 
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License 
 * along with Webfolio CMS. If not, see <http://www.gnu.org/licenses/>.
 */
 
/**
 * Admin panel UsersController for managing user profiles.
 *
 * @author Nikola Posa <posa.nikola@gmail.com>
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License
 */
class Admin_UsersController extends Zend_Controller_Action
{
    protected $_userProfileForm;

    protected $_webfolioUsersModel;

    protected $_webfolioUserMetaDbTable;

    /**
	 * Initializing controller.
	 *
	 * @return void
	 */
    public function init()
    {
        $this->_userProfileForm = new Admin_Form_UserProfile();

        $this->_webfolioUsersModel = new Model_WebfolioUsers();

        $this->_webfolioUserMetaDbTable = new Model_DbTable_WebfolioUserMeta();
    }

    /**
	 * Displays grid for managing users.
	 * 
	 * @return void
	 */
    public function indexAction()
    {
    }

    /**
	 *  Action for adding new user.
	 *
	 * @return void
	 */
    public function addAction()
    {
        if ($this->_request->isPost()) {
			$formData = $this->_request->getPost();

			$this->_userProfileForm->user->password->setRequired(true); //Password is required when adding new user.
            $this->_userProfileForm->user->removeElement('id'); //Id element is not needed at this point.
            $this->_userProfileForm->user->removeElement('publicName'); //Public name picker is not needed at this point.
            $this->_userProfileForm->user_meta->removeElement('website');
            $this->_userProfileForm->addElement(new Zend_Form_Element_Checkbox('send_email', array('disableLoadDefaultDecorators'=>true, 'autoInsertNotEmptyValidator'=>false)));
            
			if ($this->_userProfileForm->isValid($formData)) { //Valid data?
				try {
					$data = $this->_userProfileForm->getValues();
					
                    //Adding user.
                    $this->_webfolioUsersModel->setOptions($data['user']);
					$this->_webfolioUsersModel->save();

                    $lastInsertId = $this->_webfolioUsersModel->id;

                    //Inserting meta data.
                    foreach ($data['user_meta'] as $key => $value) {
                        if ($value != '') {
                            $this->_webfolioUserMetaDbTable->insert(array(
                                'user_id' => $lastInsertId,
                                'key'     => $key,
                                'value'   => $value
                            ));
                        }
                    }

                    if ((bool)$data['send_email'] == true) {
                        $siteTitle = html_entity_decode(Model_WebfolioSettings::getSettings('site_title'), ENT_COMPAT, 'UTF-8');

                        $text = 'You have been successfully registered on "' . $siteTitle . '" website (' . Model_WebfolioSettings::getSettings('site_url') . ').' . "\r\n\r\n";
                        $text .= 'Username: ' . $this->_webfolioUsersModel->username . "\r\n";
                        $text .= 'Password: ' . $data['user']['password'] . "\r\n";

                        $webfolioMail = new WebfolioCMS_Mail('utf-8');
                        $webfolioMail->addTo($this->_webfolioUsersModel->email)->setSubject(sprintf('Registration on "%s" website', $siteTitle))->setBodyText($text)->send();
                    }

                    $this->_helper->redirector('index', 'users', 'admin');
				}
				catch (Exception $ex) {
					$this->view->message = $ex->getMessage();
					$this->view->ok = false;
				}
			}
            else {
                $this->view->errorMessages = $this->_userProfileForm->getMessages();
            }
            
            $this->view->fieldValues = $this->_userProfileForm->getValues();
		}
    }

	/**
	 * Action for editing some user.
	 * 
	 * @return void
	 */
	public function editAction()
	{	
		$id = ($requestId = $this->_request->getParam('id')) ? $requestId : WebfolioCMS_Auth::getInstance()->getIdentity()->id;
			
		$webfolioUser = $this->_webfolioUsersModel->getOneWithMetaGroup(array(Model_DbTable_WebfolioUsers::USERS_TABLE_ALIAS . '.id = ?'=>(int)$id));
        
		if ($this->_request->isPost()) {
			$formData = $this->_request->getPost();
            
            $this->_userProfileForm->getSubForm('user')->removeElement('username'); //Username can not be changed.
            $this->_userProfileForm->getSubForm('user')->removeElement('groupId');
            
			if ($this->_userProfileForm->isValid($formData)) { //Valid data?
				try {
					$data = $this->_userProfileForm->getValues();
                    
					if (strlen($data['user']['password']) > 0) { //User changed his/her password?
						$webfolioUser->setPassword(sha1($data['user']['password'] . $webfolioUser->getPasswordSalt())); //Salting mechanism.
					}
					unset($data['user']['password']);

                    //Saving changes in wf_users db table.
                    $webfolioUser->setOptions($data['user']);
					$webfolioUser->save();

                    //Saving meta data.
                    foreach ($data['user_meta'] as $key=>$value) {                 
                        if (isset($webfolioUser->meta->$key)) { //Meta already exists?
                            $metaKeyCol = $this->_webfolioUserMetaDbTable->getAdapter()->quoteIdentifier('key');
                            $where = array($metaKeyCol . ' = ?'=>$key, 'user_id = ?'=>(int)$webfolioUser->id);

                            if ($value == '') { //Meta exists and user supplied empty value? We should delete row containing that meta.
                                $this->_webfolioUserMetaDbTable->delete($where);
                            }
                            elseif ($value != $webfolioUser->meta->$key) { //Meta exists and its value differs? We should run update.
                                $this->_webfolioUserMetaDbTable->update(array('value'=>$value), $where);
                            }
                        }
                        elseif ($value != '') { //Meta does not exist and user supplied some value? We should insert new meta.
                             $this->_webfolioUserMetaDbTable->insert(array('user_id'=>$webfolioUser->id, 'key'=>$key, 'value'=>$value));
                        }
                    }

                    //Editing possible changes in session.
					$identity = WebfolioCMS_Auth::getInstance()->getIdentity();
					
					if ($identity->id == $webfolioUser->id) { //User is editing his profile?
                        $changes = false;

                        if ($identity->username != $webfolioUser->username) { //User changed his username?
                            //Storing new username in auth session storage.
                            $identity->username = $webfolioUser->username;
                            $changes = true;
                        }
                        
                        if ($identity->public_name != $webfolioUser->publicName) { //User changed his public name?
                            $identity->public_name = $webfolioUser->publicName;
                            $changes = true;
                        }

                        if ($changes == true) {
                            WebfolioCMS_Auth::getInstance()->getStorage()->write($identity);
                        }
                    }
					
					$this->view->message = 'Your profile has been saved.';
					$this->view->ok = true;
				}
				catch (Exception $ex) {
					$this->view->message = $ex->getMessage();
					$this->view->ok = false;
				}
			}
            else {
                $this->view->errorMessages = $this->_userProfileForm->getMessages();
            }

            $values = $this->_userProfileForm->getValues();
            $values['user']['username'] = $webfolioUser->username; //Because of PublicNamePicker.
            $this->view->fieldValues = $values;
		}
		else {
			if ($webfolioUser != null) { //Requested user exists?
                $this->view->fieldValues = $this->_prepareUserData($webfolioUser);
			}
			else {
				$this->view->error = 'Unexisting user.';
			}
        }
	}

    /**
     * Extracts and prepares data from $webfolioUser, that
     * will be assigned to the edit form.
     *
     * @param Model_WebfolioUsers Webfolio user that is being edited.
     * @return array
     */
    protected function _prepareUserData($webfolioUser)
    {
        $data = array('user'=>array());
        
        $userData = $webfolioUser->toArray();
        
        //We don't need these.
        unset($userData['password']);
        unset($userData['passwordSalt']);
        unset($userData['group']);

        if (isset($userData['meta'])) {
            foreach ($userData['meta'] as $key=>$value) {
                $data['user_meta'][$key] = $value;
            }
            
            unset($userData['meta']);
        }

		$data['user'] = $userData;
        
        return $data;
    }
}
?>