<?php
/**
 * Webfolio CMS
 *
 * Copyright (C) 2009 Nikola Posa (http://www.nikolaposa.in.rs)
 *
 * This file is part of Webfolio CMS.
 *
 * Webfolio CMS is free software: you can redistribute it and/or modify 
 * it under the terms of the GNU General Public License as published by 
 * the Free Software Foundation, either version 3 of the License, or 
 * (at your option) any later version.
 *
 * Webfolio CMS is distributed in the hope that it will be useful, but 
 * WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU 
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License 
 * along with Webfolio CMS. If not, see <http://www.gnu.org/licenses/>.
 */
 
/**
 * Abstract form for all admin panel forms. Idea is to disable 
 * translation for all those forms.
 *
 * @author Nikola Posa <posa.nikola@gmail.com>
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License
 */
abstract class Admin_Form_AbstractForm extends ZendX_JQuery_Form
{
	/**
     * is the translator disabled?
	 * 
     * @var bool
     */
    protected $_translatorDisabled = true;
	
	/**
     * Defined by Zend_Form.
     *
     * @param  string|Zend_Form_Element $element
     * @param  string $name
     * @param  array|Zend_Config $options
     * @return Zend_Form
     */
    public function addElement($element, $name = null, $options = null)
	{
		if (is_string($element) && $options !== null) {
			if ($options instanceof Zend_Config) {
				$options = $options->toArray();
			}
			
			if (is_array($options)) {
				$options['disableTranslator'] = true;
			}
		}
		elseif ($element instanceof Zend_Form_Element) {
			$element->setDisableTranslator(true);
		}
		
		return parent::addElement($element, $name, $options);
	}
	
	/**
	 * Defined by Zend_Form.
	 *
	 * Injecting custom pre-render logic which will remove 
	 * HtmlEntities from all fields of Zend_Form_Element_Text type, 
	 * as that filter shouldn't be executed when rendering form.
	 *
	 * @param Zend_View_Interface $view 
	 * @return string
	 */
	public function render(Zend_View_Interface $view = null)
	{
		foreach ($this->_elements as $element) {
			if ($element instanceof Zend_Form_Element_Text && $element->getFilter('HtmlEntities') && strlen($value = $element->getUnfilteredValue()) > 0) {
				$element->setValue(html_entity_decode($value, ENT_QUOTES, 'UTF-8'));
                $element->removeFilter('HtmlEntities');
			}
		}
		
		return parent::render($view);
	}
}
?>