<?php
/**
 * Webfolio CMS
 *
 * Copyright (C) 2009 Nikola Posa (http://www.nikolaposa.in.rs)
 *
 * This file is part of Webfolio CMS.
 *
 * Webfolio CMS is free software: you can redistribute it and/or modify 
 * it under the terms of the GNU General Public License as published by 
 * the Free Software Foundation, either version 3 of the License, or 
 * (at your option) any later version.
 *
 * Webfolio CMS is distributed in the hope that it will be useful, but 
 * WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU 
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License 
 * along with Webfolio CMS. If not, see <http://www.gnu.org/licenses/>.
 */
 
/**
 * Form for editing comments.
 *
 * @author Nikola Posa <posa.nikola@gmail.com>
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License
 */
class Admin_Form_Comment extends Admin_Form_AbstractForm
{
	/**
	 * Initializing form.
	 *
	 * @return Zend_Form
	 */
	public function init()
	{
		$authorName = new Zend_Form_Element_Text('authorName', array('label'=>'Name:', 'size'=>40, 'required'=>true, 'disableLoadDefaultDecorators'=>true));
		$authorName->addFilters(array('StringTrim', new Zend_Filter_HtmlEntities(array('quotestyle'=>ENT_QUOTES, 'charset'=>'UTF-8', 'doublequote'=>false))));
		$authorName->addErrorMessage('Please supply author\'s name.');
		$authorName->addDecorator('Label')
			->addDecorator(new WebfolioCMS_Form_Decorator_Errors())
			->addDecorator('ViewHelper', array('separator'=>'<br />'))
			->addDecorator('HtmlTag', array('tag' => 'p'));
		$this->addElement($authorName);
				
		$authorEmail = new Zend_Form_Element_Text('authorEmail', array('label'=>'Email:', 'required'=>true, 'disableLoadDefaultDecorators'=>true));
		$authorEmail->addFilter('StringTrim');
		$authorEmail->addValidator(new Zend_Validate_EmailAddress());
		$authorEmail->addErrorMessage('Invalid email address.');
		$authorEmail->addDecorator('Label')
			->addDecorator(new WebfolioCMS_Form_Decorator_Errors())
			->addDecorator('ViewHelper', array('separator'=>'<br />'))
			->addDecorator('HtmlTag', array('tag' => 'p'));
		$this->addElement($authorEmail);
		
		$authorUrl = new Zend_Form_Element_Text('authorUrl', array('label'=>'Website:', 'required'=>false, 'disableLoadDefaultDecorators'=>true));
		$authorUrl->addFilter('StringTrim');
		$authorUrl->addValidator(new Zend_Validate_Regex('/^https?:\/\/(www\.)?[a-z0-9\.\-]+\.[a-z]{2,6}(\/?[a-z0-9_\-\.%\?&=]*)*$/i'));
		$authorUrl->addErrorMessage('Invalid website url.');
		$authorUrl->addDecorator('Label')
			->addDecorator(new WebfolioCMS_Form_Decorator_Errors())
			->addDecorator('ViewHelper', array('separator'=>'<br />'))
			->addDecorator('HtmlTag', array('tag' => 'p'));
		$this->addElement($authorUrl);
		
		$text = new Zend_Form_Element_Textarea('text', array('label'=>'Text:', 'required'=>false, 'helper'=>'tinyMCEeditor', 'disableLoadDefaultDecorators'=>true));
		$text->addFilter('StringTrim');
		$text->addErrorMessage('Please supply some text.');
		$text->addDecorator('Label')
			->addDecorator(new WebfolioCMS_Form_Decorator_Errors())
			->addDecorator('ViewHelper', array('separator'=>'<br />'))
			->addDecorator('HtmlTag', array('tag' => 'p'));
		$this->addElement($text);
		
		$webfolioEntriesDbTable = new Model_DbTable_WebfolioEntries();
		$where = 'node.use_comments = 1';
		$webfolioEntries = $webfolioEntriesDbTable->getTree($where);
		
		$options = array();
		foreach ($webfolioEntries as $entry) {
			$options['Content type: ' . $entry['type']][$entry['id']] = str_repeat('-', $entry['depth']) . ' ' . $entry['title']; 
		}
		
		$webfolioEntry = new Zend_Form_Element_Select('WFEntryId', array('label'=>'Webfolio entry:', 'multiOptions'=>$options, 'required'=>true, 'disableLoadDefaultDecorators'=>true));
		$webfolioEntry->addErrorMessage('Please choose some webfolio item.');
		$webfolioEntry->addDecorator('Label')
			->addDecorator(new WebfolioCMS_Form_Decorator_Errors())
			->addDecorator('ViewHelper')
			->addDecorator('HtmlTag', array('tag' => 'p'));
		$this->addElement($webfolioEntry);
			
		$status = new Zend_Form_Element_Select('status', array('label'=>'Status:', 'required'=>true, 'disableLoadDefaultDecorators'=>true));
		$status->addMultiOptions(array('approved'=>'Approved', 'ready'=>'Unapproved'));
		if (Model_WebfolioSettings::getSettings('use_akismet') == true) {
			$status->addMultiOption('Spam', 'spam');
		}
		$status->addDecorator('Label')
			->addDecorator(new WebfolioCMS_Form_Decorator_Errors())
			->addDecorator('ViewHelper')
			->addDecorator('HtmlTag', array('tag'=>'p'));
		$this->addElement($status);
		
		$save = new Zend_Form_Element_Submit('save', array('label'=>'Save', 'class'=>'button', 'disableLoadDefaultDecorators'=>true));
		$save->addDecorator('ViewHelper')->addDecorator('HtmlTag', array('tag' => 'p'));
		$this->addElement($save);
		
		$this->setDisableLoadDefaultDecorators(true);
		$this->addDecorator('FormElements')
             ->addDecorator('Form');
		$this->setAttrib('id', 'form_comment');
		$this->setAttrib('class', 'alert_form');
		$this->setAction($_SERVER['REQUEST_URI']);
	}
}
?>