<?php
/**
 * Webfolio CMS
 *
 * Copyright (C) 2009 Nikola Posa (http://www.nikolaposa.in.rs)
 *
 * This file is part of Webfolio CMS.
 *
 * Webfolio CMS is free software: you can redistribute it and/or modify 
 * it under the terms of the GNU General Public License as published by 
 * the Free Software Foundation, either version 3 of the License, or 
 * (at your option) any later version.
 *
 * Webfolio CMS is distributed in the hope that it will be useful, but 
 * WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU 
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License 
 * along with Webfolio CMS. If not, see <http://www.gnu.org/licenses/>.
 */
 
/**
 * Form for editing comments settings.
 *
 * @author Nikola Posa <posa.nikola@gmail.com>
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License
 */
class Admin_Form_CommentsSettings extends Admin_Form_AbstractForm
{
	/**
	 * Initializing form.
	 *
	 * @return Zend_Form
	 */
	public function init()
	{
		$adminModerateComment = new Zend_Form_Element_Checkbox('admin_moderate_comment', array('disableLoadDefaultDecorators'=>true, 'autoInsertNotEmptyValidator'=>false));
		
		$commentsNotify = new Zend_Form_Element_Checkbox('comments_notify', array('disableLoadDefaultDecorators'=>true, 'autoInsertNotEmptyValidator'=>false));
		
		$commentsVisitorLimit = new Zend_Form_Element_Text('comments_visitor_limit', array('disableLoadDefaultDecorators'=>true, 'required'=>false));
		$commentsVisitorLimit->addFilter(new Zend_Filter_StringTrim());
		$commentsVisitorLimit->addValidator(new Zend_Validate_GreaterThan(0));
		$commentsVisitorLimit->addErrorMessage('Please supply integer value greater than 0.');
		
		$commentsPerPage = new Zend_Form_Element_Text('comments_count_per_page', array('disableLoadDefaultDecorators'=>true, 'required'=>false));
		$commentsPerPage->addFilter(new Zend_Filter_StringTrim());
		$commentsPerPage->addValidator(new Zend_Validate_GreaterThan(0));
		$commentsPerPage->addErrorMessage('Please supply integer value greater than 0.');
		
		$useAkismet = new Zend_Form_Element_Checkbox('use_akismet', array('disableLoadDefaultDecorators'=>true, 'autoInsertNotEmptyValidator'=>false));
				
		$akismetApiKey = new Zend_Form_Element_Text('akismet_api_key', array('disableLoadDefaultDecorators'=>true, 'autoInsertNotEmptyValidator'=>false));
		$akismetApiKey->addFilter('StringTrim');
		$akismetApiKey->addValidator(new WebfolioCMS_Validate_AkismetApiKey());
		$akismetApiKey->addErrorMessage('Supplied Akismet API key is not valid.');
		
		$this->setDisableLoadDefaultDecorators(true);
		$this->addElements(array($adminModerateComment, $commentsNotify, $commentsVisitorLimit, $commentsPerPage, $useAkismet, $akismetApiKey));
	}
	
	public function isValid($data)
	{
		if (isset($data['use_akismet']) && $data['use_akismet'] == '1') {
			$this->getElement('akismet_api_key')->setRequired(true)->setAutoInsertNotEmptyValidator(true);
		}
		
		return parent::isValid($data);
	}
}
?>