<?php
/**
 * Webfolio CMS
 *
 * Copyright (C) 2009 Nikola Posa (http://www.nikolaposa.in.rs)
 *
 * This file is part of Webfolio CMS.
 *
 * Webfolio CMS is free software: you can redistribute it and/or modify 
 * it under the terms of the GNU General Public License as published by 
 * the Free Software Foundation, either version 3 of the License, or 
 * (at your option) any later version.
 *
 * Webfolio CMS is distributed in the hope that it will be useful, but 
 * WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU 
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License 
 * along with Webfolio CMS. If not, see <http://www.gnu.org/licenses/>.
 */
 
/**
 * Form for editing general settings.
 *
 * @author Nikola Posa <posa.nikola@gmail.com>
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License
 */
class Admin_Form_GeneralSettings extends Admin_Form_AbstractForm
{
	/**
	 * Initializing form.
	 *
	 * @return Zend_Form
	 */
	public function init()
	{
		$siteTitle = new Zend_Form_Element_Text('site_title', array('required'=>true, 'disableLoadDefaultDecorators'=>true));
		$siteTitle->addFilters(array('StringTrim', new Zend_Filter_HtmlEntities(array('quotestyle'=>ENT_QUOTES, 'charset'=>'UTF-8'))));
		$siteTitle->addErrorMessage('Please supply some name of your site.');
				
		$adminEmail = new Zend_Form_Element_Text('admin_email', array('required'=>true, 'disableLoadDefaultDecorators'=>true));
		$adminEmail->addFilter('StringTrim');
		$adminEmail->addValidator(new Zend_Validate_EmailAddress());
		$adminEmail->addErrorMessage('Invalid email address.');
		
		$dateFormat = new Zend_Form_Element_Text('date_format', array('required'=>true, 'disableLoadDefaultDecorators'=>true));
		$dateFormat->addFilter('StringTrim');
		$dateFormat->addErrorMessage('Please supply date format.');
		
		$timeFormat = new Zend_Form_Element_Text('time_format', array('required'=>true, 'disableLoadDefaultDecorators'=>true));
		$timeFormat->addFilter('StringTrim');
		$timeFormat->addErrorMessage('Please supply date and time format.');
		
		$this->setDisableLoadDefaultDecorators(true);
		$this->addElements(array($siteTitle, $adminEmail, $dateFormat, $timeFormat));
	}
}
?>