<?php
/**
 * Webfolio CMS
 *
 * Copyright (C) 2009 Nikola Posa (http://www.nikolaposa.in.rs)
 *
 * This file is part of Webfolio CMS.
 *
 * Webfolio CMS is free software: you can redistribute it and/or modify 
 * it under the terms of the GNU General Public License as published by 
 * the Free Software Foundation, either version 3 of the License, or 
 * (at your option) any later version.
 *
 * Webfolio CMS is distributed in the hope that it will be useful, but 
 * WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU 
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License 
 * along with Webfolio CMS. If not, see <http://www.gnu.org/licenses/>.
 */
 
/**
 * Form for installing Webfolio CMS.
 *
 * @author Nikola Posa <posa.nikola@gmail.com>
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License
 */
class Admin_Form_Install extends Zend_Form
{
	/**
	 * Initializing form.
	 *
	 * @return Zend_Form
	 */
	public function init()
	{
		$siteTitle = new Zend_Form_Element_Text('site_title', array('required'=>true, 'disableLoadDefaultDecorators'=>true));
		$siteTitle->addFilters(array('StringTrim', new Zend_Filter_HtmlEntities(array('quotestyle'=>ENT_QUOTES, 'charset'=>'UTF-8'))));
		$siteTitle->addErrorMessage('Please supply some name of your site.');
				
		$userEmail = new Zend_Form_Element_Text('email', array('required'=>true, 'disableLoadDefaultDecorators'=>true));
		$userEmail->addFilter('StringTrim');
		$userEmail->addValidator(new Zend_Validate_EmailAddress());
		$userEmail->addErrorMessage('Email address that you\'ve entered is not valid.');
		
		$username = new Zend_Form_Element_Text('username', array('required'=>true, 'disableLoadDefaultDecorators'=>true));
		$username->addFilter('StringTrim');
		$username->addValidator(new Zend_Validate_Regex('/^[a-z0-9\-_\.@\s]{3,}$/i'));
		$username->addErrorMessage('Username must be at least 3 characters long, and it should contain only alfanumeric characters, including these signs: \'-\', \'_\', \'.\' and \'@\'.');
		
		$password = new Zend_Form_Element_Text('password', array('required'=>true, 'autoInsertNotEmptyValidator'=>false, 'disableLoadDefaultDecorators'=>true));
		$notEmpty = new Zend_Validate_NotEmpty();
		$notEmpty->setMessage('Please enter both password and re-password.');
		$strLength = new Zend_Validate_StringLength(6);
		$strLength->setMessage('Password must be at least 6 characters long.', 'stringLengthTooShort');
		$password->addValidators(array($notEmpty, $strLength));
		
		$rePassword = new Zend_Form_Element_Text('re_password', array('required'=>false, 'autoInsertNotEmptyValidator'=>false, 'disableLoadDefaultDecorators'=>true));
		
		$this->setDisableLoadDefaultDecorators(true);
		$this->addElements(array($siteTitle, $userEmail, $username, $password, $rePassword));
	}
	
	public function isValid($data)
	{
		if (isset($data['re_password'])) { //User decided to change password?
			$this->getElement('re_password')->setRequired(true)->addValidator(new Zend_Validate_Identical($data['password']));
		}
		
		return parent::isValid($data);
	}
}
?>