<?php
/**
 * Webfolio CMS
 *
 * Copyright (C) 2009 Nikola Posa (http://www.nikolaposa.in.rs)
 *
 * This file is part of Webfolio CMS.
 *
 * Webfolio CMS is free software: you can redistribute it and/or modify 
 * it under the terms of the GNU General Public License as published by 
 * the Free Software Foundation, either version 3 of the License, or 
 * (at your option) any later version.
 *
 * Webfolio CMS is distributed in the hope that it will be useful, but 
 * WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU 
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License 
 * along with Webfolio CMS. If not, see <http://www.gnu.org/licenses/>.
 */
 
/**
 * Model that represents base class for all directory-related 
 * models.
 *
 * @author Nikola Posa <posa.nikola@gmail.com>
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License
 */
abstract class Admin_Model_DirContent_Abstract
{
	/**
	 * Path to some directory.
	 *
	 * @var string
	 */
	protected $path;
	
	/**
	 * Constructor.
	 *
	 * @return Admin_Model_DirContent_Abstract
	 */
	public function __construct()
	{
		$this->setupPath();
	}
	
	/**
	 * Setting up correct path, without trailing slash.
	 *
	 * @return void
	 */
	protected function setupPath()
	{
		$this->path = rtrim($this->path, '/\\');
		
		if (!is_dir($this->path)) {
			throw new Exception('Invalid directory path.');
		}
	}
	
	/**
	 * Sets path to directory.
	 *
	 * @param string Path to directory.
	 * @return void
	 */
	public function setPath($path)
	{
		$this->path = (string) $path;
	}
	
	/**
	 * Gets path to directory.
	 *
	 * @return string
	 */
	public function getPath()
	{
		return $this->path;
	}
}
?>