<?php
/**
 * Webfolio CMS
 *
 * Copyright (C) 2009 Nikola Posa (http://www.nikolaposa.in.rs)
 *
 * This file is part of Webfolio CMS.
 *
 * Webfolio CMS is free software: you can redistribute it and/or modify 
 * it under the terms of the GNU General Public License as published by 
 * the Free Software Foundation, either version 3 of the License, or 
 * (at your option) any later version.
 *
 * Webfolio CMS is distributed in the hope that it will be useful, but 
 * WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU 
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License 
 * along with Webfolio CMS. If not, see <http://www.gnu.org/licenses/>.
 */
 
/**
 * Model that contains logic for installing Webfolio CMS.
 *
 * @author Nikola Posa <posa.nikola@gmail.com>
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License
 */
class Admin_Model_Install extends Model_WebfolioBase
{
	/**
	 * SQL queries for creating database tables.
	 *
	 * @var string
	 */
	protected static $_tablesSchema = array(
	"CREATE TABLE IF NOT EXISTS `wf_comments` (
		`id` int(10) unsigned NOT NULL AUTO_INCREMENT,
		`wf_entry_id` int(10) unsigned NOT NULL,
		`author_name` varchar(70) NOT NULL,
		`author_email` varchar(100) NOT NULL,
		`author_url` varchar(200) DEFAULT NULL,
		`author_ip` int unsigned DEFAULT NULL,
		`author_browser` varchar(255) NOT NULL,
		`text` text NOT NULL,
		`datetime` datetime NOT NULL,
		`status` enum('approved','ready','awaiting','spam') NOT NULL,
		PRIMARY KEY (`id`)
	)",
	"CREATE TABLE IF NOT EXISTS `wf_entries` (
	  `id` int(10) unsigned NOT NULL AUTO_INCREMENT,
      `user_id` int(10) unsigned NOT NULL DEFAULT 0,
	  `lft` int(10) unsigned NOT NULL,
	  `rgt` int(10) unsigned NOT NULL,
	  `title` varchar(100) NOT NULL,
	  `text` text NOT NULL,
	  `datetime` datetime NOT NULL,
	  `title_url_format` varchar(100) NOT NULL,
	  `use_comments` tinyint(4) NOT NULL DEFAULT '0',
	  `type` varchar(40) NOT NULL DEFAULT 'item',
	  `status` enum('published','ready','draft') NOT NULL,
	  PRIMARY KEY (`id`),
	  KEY `title_url_format` (`title_url_format`)
	) ENGINE=InnoDB",
	"CREATE TABLE IF NOT EXISTS `wf_settings` (
		`id` int(10) unsigned NOT NULL AUTO_INCREMENT,
		`name` varchar(70) NOT NULL,
		`value` text NOT NULL,
		`autoload` tinyint(4) NOT NULL,
		PRIMARY KEY (`id`),
		UNIQUE KEY `name` (`name`)
	)",
	"CREATE TABLE IF NOT EXISTS `wf_terms` (
	  `id` int(10) unsigned NOT NULL AUTO_INCREMENT,
	  `lft` int(10) unsigned NOT NULL,
	  `rgt` int(10) unsigned NOT NULL,
	  `name` varchar(200) NOT NULL,
	  `name_url_format` varchar(200) NOT NULL,
	  `taxonomy` varchar(70) NOT NULL,
	  PRIMARY KEY (`id`),
	  UNIQUE KEY `name_url_format` (`name_url_format`)
	) ENGINE=InnoDB",
	"CREATE TABLE IF NOT EXISTS `wf_term_relations` (
	  `content_id` int(10) unsigned NOT NULL,
	  `term_id` int(10) unsigned NOT NULL,
	  PRIMARY KEY (`content_id`,`term_id`)
	) ENGINE=MyISAM",
	"CREATE TABLE IF NOT EXISTS `wf_users` (
		`id` int(10) unsigned NOT NULL AUTO_INCREMENT,
        `group_id` int(10) unsigned NOT NULL DEFAULT 0,
		`username` varchar(40) NOT NULL,
		`password` varchar(40) NOT NULL,
		`password_salt` varchar(10) NOT NULL,
		`email` varchar(100) NOT NULL,
		`registration_datetime` datetime NOT NULL,
        `public_name` varchar(250) NOT NULL,
		PRIMARY KEY (`id`)
	)",
    "CREATE TABLE IF NOT EXISTS `wf_user_meta` (
		`id` int(10) unsigned NOT NULL AUTO_INCREMENT,
		`user_id` int(10) unsigned NOT NULL,
		`key` varchar(100) NOT NULL,
		`value` text NOT NULL,
		PRIMARY KEY (`id`)
	)",
    "CREATE TABLE IF NOT EXISTS `wf_groups` (
		`id` int(10) unsigned NOT NULL AUTO_INCREMENT,
		`name` varchar(100) NOT NULL,
		PRIMARY KEY (`id`)
	)",
    "CREATE TABLE IF NOT EXISTS `wf_group_acl` (
        `id` int(10) unsigned NOT NULL AUTO_INCREMENT,
        `group_id` int(10) unsigned,
        `resource` varchar(200) NOT NULL,
        `privilege` varchar(200) DEFAULT NULL,
        `assert` text DEFAULT NULL,
        PRIMARY KEY (`id`)
    )"
	);
	
	/**
	 * Default Webfolio CMS settings.
	 *
	 * @var array
	 */
	protected static $_webfolioSettings = array(
		'site_title' 			  => array('value'=>'', 'autoload'=>1),
		'site_url' 				  => array('value'=>'', 'autoload'=>1),
		'base_url' 				  => array('value'=>'', 'autoload'=>1),
		'admin_email' 			  => array('value'=>'', 'autoload'=>1),
		'date_format' 			  => array('value'=>'d.m.Y.', 'autoload'=>1),
		'time_format' 			  => array('value'=>'H:i', 'autoload'=>1),
		'use_webfolio_page' 	  => array('value'=>'1', 'autoload'=>1),
		'use_smileys' 			  => array('value'=>'1', 'autoload'=>1),
		'theme_dir' 			  => array('value'=>'coolwater', 'autoload'=>1),
		'enable_rss_wf_items' 	  => array('value'=>'1', 'autoload'=>1),
		'update_core_info'		  => array('value'=>array('last_checked'=>0, 'version'=>WebfolioCMS_Version::VERSION), 'autoload'=>0),
		'db_revision' 			  => array('value'=>'', 'autoload'=>0),
		'active_modules'    	  => array('value'=>array('admin', 'taxonomy'), 'autoload'=>1),
		'installed_modules'    	  => array('value'=>array(), 'autoload'=>0),
		'sidebar_items'	    	  => array('value'=>array(array('helperName'=>'WFSidebarMenu', 'userFriendlyName'=>'Menu', 'module'=>'default', 'title'=>'', 'settings'=>array('make_collapsible'=>1,'collapse_from_level'=>1,'event_type'=>'click')), array('helperName'=>'WFSidebarLoginBox', 'userFriendlyName'=>'Login Box', 'module'=>'admin', 'title'=>'')), 'autoload'=>1),
		'content_plugins'	      => array('value'=>array('preContent'=>array(), 'postContent'=>array(array('helperName'=>'WFComments', 'userFriendlyName'=>'Webfolio comments', 'module'=>'default', 'settings'=>array('selections'=>array('page'=>array(), 'item'=>array()), 'topSeparator'=>0)))), 'autoload'=>1),
		'remember_me_marker'   	  => array('value'=>'0', 'autoload'=>1),
        'upload_path' 			  => array('value'=>'data/uploads', 'autoload'=>0),
		'admin_moderate_comment'  => array('value'=>'0', 'autoload'=>0),
		'comments_notify'   	  => array('value'=>'0', 'autoload'=>0),
		'comments_visitor_limit'  => array('value'=>'5', 'autoload'=>0),
		'comments_count_per_page' => array('value'=>'10', 'autoload'=>0),
		'use_akismet' 			  => array('value'=>'0', 'autoload'=>0),
		'akismet_api_key'   	  => array('value'=>'', 'autoload'=>0)
	);

    /**
	 * Three default pages that will be inserted in wf_entries db
     * table during installation.
	 *
	 * @var array
	 */
    protected static $_pages = array(
        array(
            'user_id' => 1,
            'title'=>'Home',
            'text'=>'<p>This will be your home page.</p> <p>You can put some personal information on this page, some text about yourself, or something like that.</p>',
            'status'=>'published', 
			'use_comments' => 0
        ),
        array(
            'user_id' => 1,
            'title'=>'My work',
            'text'=>'<p>This is your webfolio page.</p> <p>After you add some content into your webfolio, all categories will be displayed below this text. And in case you decide not to use categories, your webfolio items will be displayed instead.</p>',
            'status'=>'published',
			'use_comments' => 0
        ),
        array(
            'user_id' => 1,
            'title'=>'Contact',
            'text'=>'[WF_ContactForm]',
            'status'=>'published',
			'use_comments' => 0
        )
    );

    /**
	 * Initial user groups.
	 *
	 * @var array
	 */
    protected static $_groups = array(
        'Administrator',
        'Moderator'
    );

    /**
	 * Initial group ACLs.
	 *
	 * @var array
	 */
    protected static $_groupACLs = array(
        array('group_id'=>1, 'resource'=>'admin_pages', 'privilege'=>'index'),
        array('group_id'=>1, 'resource'=>'admin_pages', 'privilege'=>'edit'),
        array('group_id'=>1, 'resource'=>'admin_items', 'privilege'=>'index'),
        array('group_id'=>1, 'resource'=>'admin_items', 'privilege'=>'new'),
        array('group_id'=>1, 'resource'=>'admin_items', 'privilege'=>'edit'),
        array('group_id'=>1, 'resource'=>'admin_items', 'privilege'=>'delete'),
        array('group_id'=>1, 'resource'=>'admin_comments', 'privilege'=>'index'),
        array('group_id'=>1, 'resource'=>'admin_comments', 'privilege'=>'edit'),
        array('group_id'=>1, 'resource'=>'admin_comments', 'privilege'=>'spam'),
        array('group_id'=>1, 'resource'=>'admin_comments', 'privilege'=>'manage'),
        array('group_id'=>1, 'resource'=>'admin_comments', 'privilege'=>'delete'),
        array('group_id'=>1, 'resource'=>'admin_appearance', 'privilege'=>'themes'),
        array('group_id'=>1, 'resource'=>'admin_appearance', 'privilege'=>'sidebar'),
        array('group_id'=>1, 'resource'=>'admin_appearance', 'privilege'=>'content-plugins'),
        array('group_id'=>1, 'resource'=>'admin_appearance_themes', 'privilege'=>'edit'),
        array('group_id'=>1, 'resource'=>'admin_appearance_themes', 'privilege'=>'change'),
        array('group_id'=>1, 'resource'=>'admin_appearance_sidebar', 'privilege'=>'manage'),
        array('group_id'=>1, 'resource'=>'admin_appearance_content-plugins', 'privilege'=>'manage'),
        array('group_id'=>1, 'resource'=>'admin_settings', 'privilege'=>'general'),
        array('group_id'=>1, 'resource'=>'admin_settings', 'privilege'=>'app'),
        array('group_id'=>1, 'resource'=>'admin_settings', 'privilege'=>'comments'),
        array('group_id'=>1, 'resource'=>'admin_modules', 'privilege'=>'index'),
        array('group_id'=>1, 'resource'=>'admin_modules', 'privilege'=>'manage'),
        array('group_id'=>1, 'resource'=>'admin_users', 'privilege'=>'index'),
        array('group_id'=>1, 'resource'=>'admin_users', 'privilege'=>'add'),
        array('group_id'=>1, 'resource'=>'admin_users', 'privilege'=>'edit'),
        array('group_id'=>1, 'resource'=>'admin_users', 'privilege'=>'delete'),
        array('group_id'=>1, 'resource'=>'admin_groups', 'privilege'=>'index'),
        array('group_id'=>1, 'resource'=>'admin_groups', 'privilege'=>'add'),
        array('group_id'=>1, 'resource'=>'admin_groups', 'privilege'=>'edit'),
        array('group_id'=>1, 'resource'=>'admin_groups', 'privilege'=>'delete'),
        array('group_id'=>1, 'resource'=>'admin_groups-permissions', 'privilege'=>'index'),
        array('group_id'=>1, 'resource'=>'admin_groups-permissions', 'privilege'=>'edit'),
        array('group_id'=>2, 'resource'=>'admin_comments', 'privilege'=>'index'),
        array('group_id'=>2, 'resource'=>'admin_comments', 'privilege'=>'edit'),
        array('group_id'=>2, 'resource'=>'admin_comments', 'privilege'=>'spam'),
        array('group_id'=>2, 'resource'=>'admin_comments', 'privilege'=>'manage'),
        array('group_id'=>2, 'resource'=>'admin_comments', 'privilege'=>'delete')
    );

    /**
     * Retrieves tables definitons.
     *
     * @return array
     */
    public static function getTablesDefinitions()
    {
        return self::$_tablesSchema;
    }

    /**
     * Retrieves default webfolio pages.
     *
     * @return array
     */
    public static function getDefaultWebfolioPages()
    {
        return self::$_pages;
    }

    /**
     * Retrieves initial users groups.
     *
     * @return array
     */
    public static function getInitialUsersGroups()
    {
        return self::$_groups;
    }

    /**
     * Retrieves initial group ACLS, including those defined in
     * WebfolioGroupAcl table data gateway.
     *
     * @return array
     */
    public static function getInitialGroupACLs()
    {
        return array_merge(Model_DbTable_WebfolioGroupAcl::getDefaultGroupACLs(), self::$_groupACLs);
    }
	
	/**
	 * Checks whether Webfolio CMS is already installed.
	 *
	 * @return bool
	 */
	public function isInstalled()
	{
		$dbConfig = $this->dbHandler->getConfig();
		
		if ($this->dbHandler->fetchRow('SHOW TABLES FROM ' . $dbConfig['dbname'] . ' LIKE \'wf_settings\'') != null && Model_WebfolioSettings::getSettings('base_url') !== null) {
			return true;
		}
		else {
			return false;
		}
	}
	
	/**
	 * Installs Webfolio CMS.
	 *
	 * @param array Data from the install form.
	 * @return void
	 */
	public function install($data)
	{	
		$this->prepareInitialWebfolioSettings($data);
		
		$this->createTables();
		$this->populateTables();
	}

    /**
	 * Preparing some of initial Webfolio CMS settings that
     * require additional handling.
	 *
	 * @param array Data from the install form.
	 * @return void
	 */
    protected function prepareInitialWebfolioSettings($data)
    {
        self::$_webfolioSettings['site_title']['value'] = $data['site_title'];
		self::$_webfolioSettings['admin_email']['value'] = $data['admin_email'];

        //Getting base url.
        $request = new Zend_Controller_Request_Http();
        $request->setBaseUrl();

        $baseUrl = str_replace('/install.php', '', $request->getBaseUrl());

        self::$_webfolioSettings['site_url']['value'] = $request->getScheme() . '://' . $request->getHttpHost() . $baseUrl;
        self::$_webfolioSettings['base_url']['value'] = $baseUrl;

        self::$_webfolioSettings['upload_path']['value'] = BASE_PATH . '/' . self::$_webfolioSettings['upload_path']['value'];

        $updateCore = new Admin_Model_Update_Core();
        self::$_webfolioSettings['db_revision']['value'] = $updateCore->getDbRevision();
    }
    
	/**
	 * Exectues queries for creating database tables.
	 *
	 * @return void
	 */
	protected function createTables()
	{
		foreach (self::$_tablesSchema as $sql) {
			$this->dbHandler->query($sql);
		}
	}

    /**
	 * Populates db tables that have some default data.
	 *
	 * @return void
	 */
	protected function populateTables()
	{
        $this->populatePages();
        $this->populateSettings();
        $this->populateGroups();
        $this->populateGroupACL();
	}

	/**
	 * Populates wf_entries database table with 3 default pages
	 * (home, webfolio and contact). 
	 *
	 * @return void
	 */
	protected function populatePages()
	{
        foreach (self::$_pages as $data) {
            $webfolioPage = new Model_WebfolioEntries('page', $data);
            $webfolioPage->save();
        }
	}
	
	/**
	 * Populates wf_settings database table with initial Webfolio 
	 * CMS settings.
	 *
	 * @return void
	 */
	protected function populateSettings()
	{
		foreach (self::$_webfolioSettings as $name=>$settings) {
			Model_WebfolioSettings::addSetting($name, $settings['value'], $settings['autoload']);
		}
	}

    /**
	 * Inserts administrator and moderator groups in wf_groups db
     * table.
	 *
	 * @return void
	 */
	protected function populateGroups()
	{
        $webfolioGroupsDbTable = new Model_DbTable_WebfolioGroups();
		foreach (self::$_groups as $name) {
            $webfolioGroupsDbTable->insert(array('name'=>$name));
		}
	}

    /**
	 * Inserts initial group ACLs.
	 *
	 * @return void
	 */
	protected function populateGroupACL()
	{
        $groupACLDbTable = new Model_DbTable_WebfolioGroupAcl();
        foreach (self::getInitialGroupACLs() as $acl) {
            $groupACLDbTable->insert($acl);
        }
	}
}
?>