<?php
/**
 * Webfolio CMS
 *
 * Copyright (C) 2009 Nikola Posa (http://www.nikolaposa.in.rs)
 *
 * This file is part of Webfolio CMS.
 *
 * Webfolio CMS is free software: you can redistribute it and/or modify 
 * it under the terms of the GNU General Public License as published by 
 * the Free Software Foundation, either version 3 of the License, or 
 * (at your option) any later version.
 *
 * Webfolio CMS is distributed in the hope that it will be useful, but 
 * WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU 
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License 
 * along with Webfolio CMS. If not, see <http://www.gnu.org/licenses/>.
 */
 
/**
 * Model for getting data that will be displayed in ExtJS 
 * grid, on pages for managing items and comments. Data is 
 * returned in JSON format, and in form that is required by 
 * ExtJS grid component.
 *
 * @author Nikola Posa <posa.nikola@gmail.com>
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License
 */
class Admin_Model_ManageGrids
{
	/**
	 * Database handler.
	 *
	 * @var Zend_Db_Adapter_Abstract
	 */
	protected $dbHandler;
	
	/**
	 * Constructor.
	 *
	 * @return Admin_Model_Manage
	 */
	public function __construct()
	{
		$this->dbHandler = Zend_Registry::get('dbHandler');
	}
	
	/**
	 * Getting webfolio items that will be displayed in ExtJS grid.
	 *
	 * @return string
	 */
	public function getItems()
	{
		$sql = "SELECT item.id, item.title, item.title_url_format, DATE_FORMAT(item.datetime, '%m/%d/%Y') AS 'date', item.status, (COUNT(parent.id) - 1) AS depth, u.public_name AS 'author'
			FROM wf_entries AS item,
			wf_entries AS parent,
            wf_users u
			WHERE item.lft BETWEEN parent.lft AND parent.rgt AND item.type = 'item' AND parent.type = 'item' AND item.user_id = u.id
			GROUP BY item.id
			ORDER BY item.lft";
			
		$allItems = $this->dbHandler->fetchAll($sql);
		
		$results = Zend_Json_Encoder::encode($allItems);
		
		return '{"results":' . $results . '}';
	}
	
	/**
	 * Getting comments that will be displayed in ExtJS grid.
	 *
	 * @param string Whether to get comments marked as spam, or all the other comments.
	 * @param string Limit start (sent by paging toolbar).
	 * @param string Limit offset (sent by paging toolbar).
	 * @return string
	 */
	public function getComments($cond, $start, $limit)
	{
		$where = '';
		if ($cond == 'not_spam') {
			$where = 'status != \'spam\'';
		}
		elseif ($cond == 'spam') {
			$where = 'status = \'spam\'';
		}
			
		$start = (int)$start;
		$limit = (int)$limit;
			
		$sql = "SELECT c.id, e.title, c.author_name, c.author_email, c.author_url, INET_NTOA(c.author_ip) AS 'author_ip', c.text, DATE_FORMAT(c.datetime, '%m/%d/%Y %H:%i') AS 'datetime', c.status, (SELECT COUNT(id) FROM wf_comments WHERE $where) AS 'comments_count'
				FROM wf_comments c, wf_entries e
				WHERE c.wf_entry_id = e.id AND c.$where 
				ORDER BY c.datetime DESC";
		$sql = $this->dbHandler->limit($sql, $limit, $start);
		
		$comments = $this->dbHandler->fetchAll($sql);
		
		$total = isset($comments[0]['comments_count']) ? $comments[0]['comments_count'] : 0;
		$results = Zend_Json_Encoder::encode($comments);
		
		return '({"total":"' . $total . '","results":' . $results . '})';
	}
}
?>