<?php
/** 
 * Webfolio CMS
 * 
 * Copyright (C) 2009 Nikola Posa (http://www.nikolaposa.in.rs)
 * 
 * This file is part of Webfolio CMS.
 * 
 * Webfolio CMS is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Webfolio CMS is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Webfolio CMS. If not, see <http://www.gnu.org/licenses/>.
 */

/**
 * Holds registered group permission data (acl rules, labels),
 * which are used for rendering group permission panel.
 *
 * @author Nikola Posa <posa.nikola@gmail.com>
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License
 */
class Admin_Model_WFAdminGroupPermissions extends WebfolioCMS_HookContainer_Abstract
{
    /**
	 * Singleton instance.
	 *
	 * @var Admin_Model_WFAdminACL
	 */
    protected static $_instance = null;

    /**
	 * Initial group permission data that is added by this (admin)
     * module.
	 *
	 * @var array
	 */
    protected $data = array(
        'admin'=>array(
            array(
                'rules'=>array('resource'=>'admin_pages', 'privilege'=>'index'),
                'label'=>'List pages'
            ),
            array(
                'rules'=>array('resource'=>'admin_pages', 'privilege'=>'edit'),
                'label'=>'Edit pages'
            ),
            array(
                'rules'=>array('resource'=>'admin_items', 'privilege'=>'index'),
                'label'=>'List webfolio items'
            ),
            array(
                'rules'=>array('resource'=>'admin_items', 'privilege'=>'new'),
                'label'=>'Add new webfolio items'
            ),
            array(
                'rules'=>array('resource'=>'admin_items', 'privilege'=>'edit'),
                'label'=>'Edit webfolio items'
            ),
            array(
                'rules'=>array('resource'=>'admin_items', 'privilege'=>'delete'),
                'label'=>'Delete webfolio items'
            ),

            array(
                'rules'=>array('resource'=>'admin_comments', 'privilege'=>'index'),
                'label'=>'List comments'
            ),
            array(
                'rules'=>array('resource'=>'admin_comments', 'privilege'=>'spam'),
                'label'=>'List comments marked as spam'
            ),
            array(
                'rules'=>array('resource'=>'admin_comments', 'privilege'=>'edit'),
                'label'=>'Edit comments'
            ),
            array(
                'rules'=>array('resource'=>'admin_comments', 'privilege'=>'manage'),
                'label'=>'Manage comments (approve, unapprove)'
            ),
            array(
                'rules'=>array('resource'=>'admin_comments', 'privilege'=>'delete'),
                'label'=>'Delete comments'
            ),

            array(
                'rules'=>array('resource'=>'admin_appearance', 'privilege'=>'themes'),
                'label'=>'List themes'
            ),
            array(
                'rules'=>array('resource'=>'admin_appearance', 'privilege'=>'sidebar'),
                'label'=>'List sidebar items'
            ),
            array(
                'rules'=>array('resource'=>'admin_appearance', 'privilege'=>'content-plugins'),
                'label'=>'List content plugins'
            ),
            array(
                'rules'=>array('resource'=>'admin_appearance_themes', 'privilege'=>'edit'),
                'label'=>'Edit themes'
            ),
            array(
                'rules'=>array('resource'=>'admin_appearance_themes', 'privilege'=>'change'),
                'label'=>'Change theme'
            ),
            array(
                'rules'=>array('resource'=>'admin_appearance_sidebar', 'privilege'=>'manage'),
                'label'=>'Manage sidebar items'
            ),
            array(
                'rules'=>array('resource'=>'admin_appearance_content-plugins', 'privilege'=>'manage'),
                'label'=>'Manage content plugins'
            ),

            array(
                'rules'=>array('resource'=>'admin_settings', 'privilege'=>'general'),
                'label'=>'Manage general settings'
            ),
            array(
                'rules'=>array('resource'=>'admin_settings', 'privilege'=>'app'),
                'label'=>'Manage application settings'
            ),
            array(
                'rules'=>array('resource'=>'admin_settings', 'privilege'=>'comments'),
                'label'=>'Manage comments-related settings'
            ),

            array(
                'rules'=>array('resource'=>'admin_modules', 'privilege'=>'index'),
                'label'=>'View modules'
            ),
            array(
                'rules'=>array('resource'=>'admin_modules', 'privilege'=>'manage'),
                'label'=>'Manage modules'
            ),

            array(
                'rules'=>array('resource'=>'admin_users', 'privilege'=>'index'),
                'label'=>'List users'
            ),
            array(
                'rules'=>array('resource'=>'admin_users', 'privilege'=>'add'),
                'label'=>'Add new users'
            ),
            array(
                'rules'=>array('resource'=>'admin_users', 'privilege'=>'edit'),
                'label'=>'Edit users'
            ),
            array(
                'rules'=>array('resource'=>'admin_users', 'privilege'=>'delete'),
                'label'=>'Delete users'
            ),

            array(
                'rules'=>array('resource'=>'admin_groups', 'privilege'=>'index'),
                'label'=>'List groups'
            ),
            array(
                'rules'=>array('resource'=>'admin_groups', 'privilege'=>'add'),
                'label'=>'Add groups'
            ),
            array(
                'rules'=>array('resource'=>'admin_groups', 'privilege'=>'edit'),
                'label'=>'Edit groups'
            ),
            array(
                'rules'=>array('resource'=>'admin_groups', 'privilege'=>'delete'),
                'label'=>'Delete groups'
            ),

            array(
                'rules'=>array('resource'=>'admin_groups-permissions', 'privilege'=>'index'),
                'label'=>'List groups permissions'
            ),
            array(
                'rules'=>array('resource'=>'admin_groups-permissions', 'privilege'=>'edit'),
                'label'=>'Edit groups permissions'
            ),
        )
    );

    /**
	 * Group permission data is grouped by module which added them.
	 *
	 * @var string|null
	 */
    protected $groupingIndex = 'module';

    /**
	 * Defined by WebfolioCMS_Singleton_Interface.
     *
	 * Singleton pattern implementation.
	 *
	 * @return Admin_Model_WFAdminACL
	 */
    public static function getInstance()
    {
        if (null === self::$_instance) {
            self::$_instance = new self();
        }

        return self::$_instance;
    }

    /**
	 * Defined by WebfolioCMS_HookContainer_Interface.
	 *
	 * @return array
	 */
	public static function get()
    {
        $instance = self::getInstance();

        return $instance->data;
    }

	/**
	 * Defined by WebfolioCMS_HookContainer_Interface.
	 *
	 * @param mixed Group permission data.
	 * @return void
	 */
	public static function add($groupPermData)
    {
        $instance = self::getInstance();

		$instance->_doAdd($groupPermData);
    }

    /**
	 * Defined by WebfolioCMS_HookContainer_Abstract.
	 *
	 * @param array Group permission data.
	 * @return void
	 */
    protected function isValid($groupPermData)
	{
		if (parent::isValid($groupPermData)
            && is_array($groupPermData)
            && isset($groupPermData['rules'])
            && is_array($groupPermData['rules'])
            && isset($groupPermData['label'])
        ) {
			return true;
		}

		return false;
    }
}
?>
