<?php
/**
 * Webfolio CMS
 *
 * Copyright (C) 2009 Nikola Posa (http://www.nikolaposa.in.rs)
 *
 * This file is part of Webfolio CMS.
 *
 * Webfolio CMS is free software: you can redistribute it and/or modify 
 * it under the terms of the GNU General Public License as published by 
 * the Free Software Foundation, either version 3 of the License, or 
 * (at your option) any later version.
 *
 * Webfolio CMS is distributed in the hope that it will be useful, but 
 * WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU 
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License 
 * along with Webfolio CMS. If not, see <http://www.gnu.org/licenses/>.
 */
 
/**
 * Model that stores menus (navBar and sub-navBar) information.
 *
 * @author Nikola Posa <posa.nikola@gmail.com>
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License
 */
class Admin_Model_WFAdminMenu extends WebfolioCMS_HookContainer_Abstract
{
	/**
	 * Pages are grouped by some unique name, so we're setting
	 * $groupingIndex to be used for grouping pages.
	 *
	 * @var string
	 */
    protected $groupingIndex = 'name';
	
	/**
	 * Singleton instance
	 *
	 * @var Admin_Model_WFAdminMenu
	 */
    protected static $_instance = null;
	
	/**
	 * Constructor.
	 *
	 * @return Admin_Model_WFAdminMenu
	 */
	protected function __construct()
	{
		$this->initMenuItems(); 
	}
	
	/**
	 * Defined by WebfolioCMS_Singleton_Interface.
     *
	 * Singleton pattern implementation.
	 *
	 * @return Admin_Model_WFAdminMenu
	 */
    public static function getInstance()
    {
        if (null === self::$_instance) {
            self::$_instance = new self();
        }

        return self::$_instance;
    }
	
	/**
	 * Initializing admin module menu scheme.
	 *
	 * @return array
	 */
	protected function initMenuItems()
	{
		$this->data = array(
			'manage'=>array (
				'label' 	 => 'Manage',
				'uri'        => 'javascript: void(0);',
                'id'         => 'manage',
                'class'      => 'primary parent',
				'pages'		 => array(
					array(
						'label' 	 => 'Pages',
                        'class'      => 'manage',
						'module'	 => 'admin',
						'controller' => 'pages',
						'action' 	 => 'index',
						'route' 	 => 'default',
                        'resource'   => 'admin_pages',
                        'privilege'  => 'index',
						'pages'		 => array(
							array (
								'module'	 => 'admin',
								'controller' => 'pages',
								'action' 	 => 'edit',
								'route' 	 => 'default',
                                'resource'   => 'admin_pages',
                                'privilege'  => 'edit'
							)
						)
					),
					array(
						'label' 	 => 'Webfolio items',
                        'class'      => 'manage',
						'module'	 => 'admin',
						'controller' => 'items',
						'action' 	 => 'index',
						'route' 	 => 'default',
                        'resource'   => 'admin_items',
                        'privilege'  => 'index',
						'pages'		 => array(
							array (
								'module'	 => 'admin',
								'controller' => 'items',
								'action' 	 => 'new',
								'route' 	 => 'default',
                                'resource'   => 'admin_items',
                                'privilege'  => 'new'
							),
							array (
								'module'	 => 'admin',
								'controller' => 'items',
								'action' 	 => 'edit',
								'route' 	 => 'default',
                                'resource'   => 'admin_items',
                                'privilege'  => 'edit'
							)
						)
					),
					array(
						'label' 	 => 'Comments ' . $this->awaitingCommentsCount(),
                        'class'      => 'manage',
						'module'	 => 'admin',
						'controller' => 'comments',
						'action' 	 => 'index',
						'route' 	 => 'default',
                        'resource'   => 'admin_comments',
                        'privilege'  => 'index',
						'pages'		 => array(
							array (
								'module'	 => 'admin',
								'controller' => 'comments',
								'action' 	 => 'edit',
								'route' 	 => 'default',
                                'resource'   => 'admin_comments',
                                'privilege'  => 'edit'
							),
							array (
								'module'	 => 'admin',
								'controller' => 'comments',
								'action' 	 => 'spam',
								'route' 	 => 'default',
                                'resource'   => 'admin_comments',
                                'privilege'  => 'spam'
							)
						)
					)
				)
			), 
			'appearance'=>array (
				'label' 	 => 'Appearance',
                'id'         => 'appearance',
                'class'      => 'primary parent',
				'uri'        => 'javascript: void(0);',
				'pages'		 => array( 
					array(
						'label' 	 => 'Themes',
						'module'	 => 'admin',
                        'class'      => 'appearance',
						'controller' => 'appearance',
						'action' 	 => 'themes',
						'route' 	 => 'default',
                        'resource'   => 'admin_appearance',
                        'privilege'  => 'themes'
					),
					array(
						'label' 	 => 'Sidebar',
                        'class'      => 'appearance',
						'module'	 => 'admin',
						'controller' => 'appearance',
						'action' 	 => 'sidebar',
						'route' 	 => 'default',
                        'resource'   => 'admin_appearance',
                        'privilege'  => 'sidebar'
					),
					array(
						'label' 	 => 'Content plugins',
                        'class'      => 'appearance',
						'module'	 => 'admin',
						'controller' => 'appearance',
						'action' 	 => 'content-plugins',
						'route' 	 => 'default',
                        'resource'   => 'admin_appearance',
                        'privilege'  => 'content-plugins'
					)
				)
			), 
			'settings'=>array (
				'label' 	 => 'Settings',
                'id'         => 'settings',
                'class'      => 'primary parent',
				'uri'        => 'javascript: void(0);',
				'pages' 	 => array(
					array(
						'label' 	 => 'General',
                        'class'      => 'settings',
						'module'	 => 'admin',
						'controller' => 'settings',
						'action' 	 => 'general',
						'route' 	 => 'default',
                        'resource'   => 'admin_settings',
                        'privilege'  => 'general'
					),
					array(
						'label' 	 => 'Application',
                        'class'      => 'settings',
						'module'	 => 'admin',
						'controller' => 'settings',
						'action' 	 => 'app',
						'route' 	 => 'default',
                        'resource'   => 'admin_settings',
                        'privilege'  => 'app'
					),
					array(
						'label' 	 => 'Comments',
                        'class'      => 'settings',
						'module'	 => 'admin',
						'controller' => 'settings',
						'action' 	 => 'comments',
						'route' 	 => 'default',
                        'resource'   => 'admin_settings',
                        'privilege'  => 'comments'
					)
				)
			), 
			'modules'=>array (
				'label' 	 => 'Modules',
                'class'      => 'primary',
                'id'         => 'modules',
				'module'	 => 'admin',
				'controller' => 'modules',
				'action' 	 => 'index',
				'route' 	 => 'default',
                'resource'   => 'admin_modules',
                'privilege'  => 'index'
			), 
			'users_group'=>array (
                'label' 	 => 'Users/groups',
                'id'         => 'users_group',
                'class'      => 'primary parent',
				'uri'        => 'javascript: void(0);',
                'pages' => array(
                     array (
                        'label' 	 => 'Users',
                        'class'      => 'users_group',
                        'module'	 => 'admin',
                        'controller' => 'users',
                        'action' 	 => 'index',
                        'route' 	 => 'default',
                        'resource'   => 'admin_users',
                        'privilege'  => 'index',
                        'pages'      => array(
                            array (
                                'label' 	 => 'Add new user',
                                'module'	 => 'admin',
                                'controller' => 'users',
                                'action' 	 => 'add',
                                'resource'   => 'admin_users',
                                'privilege'  => 'add'
                            ),
                            array (
                                'label' 	 => 'Edit user\'s profile',
                                'module'	 => 'admin',
                                'controller' => 'users',
                                'action' 	 => 'edit',
                                'resource'   => 'admin_users',
                                'privilege'  => 'edit'
                            )
                        )
                    ),
                    array (
                        'label' 	 => 'Groups',
                        'class'      => 'users_group',
                        'module'	 => 'admin',
                        'controller' => 'groups',
                        'action' 	 => 'index',
                        'route' 	 => 'default',
                        'resource'   => 'admin_groups',
                        'privilege'  => 'index',
                        'pages'      => array(
                            array (
                                'label' 	 => 'Add new group',
                                'module'	 => 'admin',
                                'controller' => 'groups',
                                'action' 	 => 'add',
                                'resource'   => 'admin_groups',
                                'privilege'  => 'add'
                            ),
                            array (
                                'label' 	 => 'Edit group',
                                'module'	 => 'admin',
                                'controller' => 'groups',
                                'action' 	 => 'edit',
                                'resource'   => 'admin_groups',
                                'privilege'  => 'edit'
                            )
                        )
                    ),
                    array(
                        'label' 	 => 'Groups permissions',
                        'class'      => 'users_group',
                        'module'	 => 'admin',
                        'controller' => 'groups-permissions',
                        'action' 	 => 'index',
                        'route' 	 => 'default',
                        'resource'   => 'admin_groups-permissions',
                        'privilege'  => 'index'
                    )
                )
			)
		);
	}
	
	/**
	 * Generates number of awaiting comments, that will be displayed 
	 * next to "Manage" -> "Comments" link.
	 *
	 * @return string
	 */
	protected function awaitingCommentsCount()
	{
		$output = '';
		
		$webfolioComments = new Model_DbTable_WebfolioComments();
		$awaitingCommentsCount = $webfolioComments->fetchAll('status = \'awaiting\'')->count();
		
		if ($awaitingCommentsCount > 0) {
			$output = ' (' . $awaitingCommentsCount . ')';
		}
		
		return $output;
	}
	
	/**
	 * Defined by WebfolioCMS_HookContainer_Interface. 
	 *
	 * Gets admin menu scheme.
	 *
	 * @return array
	 */
	public static function get()
	{
		$instance = self::getInstance();
		
		return $instance->data;
	}
	
	/**
	 * Defined by WebfolioCMS_HookContainer_Interface. 
	 *
	 * Adds new page into scheme.
	 *
	 * Supported params for $pageData are:
	 *	 name - Unique name of page, or name of some existing page if supplied page needs to be added as child of some page (string),
     *   See Zend_Navigation_Page::factory() method for more info.
	 *
	 * @param array Page data.
	 * @return void
	 */
	public static function add($pageData)
	{
		$instance = self::getInstance();
		
		$instance->_doAdd($pageData);
	}
	
	/**
	 * Defined by WebfolioCMS_HookContainer_Abstract.
	 *
	 * @param array Page data.
	 * @return array
	 */
	protected function prepare($pageData)
	{
		$pageData[$this->groupingIndex] = strtolower($pageData[$this->groupingIndex]);
		
		return $pageData;
	}
	
	/**
	 * Defined by WebfolioCMS_HookContainer_Abstract.
	 *
	 * @param array Hook data.
	 * @return void
	 */
	protected function store($pageData)
	{
		$name = $pageData[$this->groupingIndex];
        unset($pageData[$this->groupingIndex]);

        $pageData['class'] = $name; //CSS class should be automatically named of parent grouping index.

		if (!isset($this->data[$name])) {	
			$this->data[$name] = $pageData;
		}
		else { //Page already exists, then we should add page as a child of existing one.
			$this->data[$name]['pages'][] = $pageData;
		}
	}
}
?>