<?php
/**
 * Webfolio CMS
 *
 * Copyright (C) 2009 Nikola Posa (http://www.nikolaposa.in.rs)
 *
 * This file is part of Webfolio CMS.
 *
 * Webfolio CMS is free software: you can redistribute it and/or modify 
 * it under the terms of the GNU General Public License as published by 
 * the Free Software Foundation, either version 3 of the License, or 
 * (at your option) any later version.
 *
 * Webfolio CMS is distributed in the hope that it will be useful, but 
 * WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU 
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License 
 * along with Webfolio CMS. If not, see <http://www.gnu.org/licenses/>.
 */
 
/**
 * Hook that holds registered WFEntry form plugins data 
 * (additional form elements). This should be used by modules 
 * which want to add their own elements in forms of WFEntry 
 * type. This hook is used only for adding form elements, and 
 * all other events-related logic (populating, rendering, 
 * validating, etc.) should be registered with 
 * WebfolioCMS_Events_Broker hook.
 *
 * @author Nikola Posa <posa.nikola@gmail.com>
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License
 */
class Admin_Model_WFEntryFormPlugins extends WebfolioCMS_HookContainer_Abstract
{
	/**
	 * Singleton instance.
	 *
	 * @var Admin_Model_WFEntryFormPlugins
	 */
    protected static $_instance = null;
	
	/**
	 * Defined by WebfolioCMS_Singleton_Interface.
     *
	 * Singleton pattern implementation.
	 *
	 * @return Admin_Model_WFEntryFormPlugins
	 */
	public static function getInstance()
	{
		if (null === self::$_instance) {
            self::$_instance = new self();
        }

        return self::$_instance;
	}
	
	/**
	 * Defined by WebfolioCMS_HookContainer_Interface. 
	 *
	 * Retrieves registered WFEntry form plugins.
	 *
	 * @return array
	 */
	public static function get()
	{
		$instance = self::getInstance();
		
		return $instance->data;
	}
	
	/**
	 * Defined by WebfolioCMS_HookContainer_Interface. 
	 *
	 * Adds WFEntry form plugins data onto stack.
	 *
	 * @param array WFEntry plugins data.
	 * @return void
	 */
	public static function add($WFEntryFormPlugin)
	{
		$instance = self::getInstance();
		
		$instance->_doAdd($WFEntryFormPlugin);
	}
	
	/**
	 * Defined by WebfolioCMS_HookContainer_Abstract. 
	 *
	 * @param array WFEntry form plugins data.
	 * @return bool
	 */
	 protected function isValid($WFEntryFormPlugin)
	 {
		if (
			parent::isValid($WFEntryFormPlugin) 
			&& array_key_exists('elements', $WFEntryFormPlugin) 
			&& is_array($WFEntryFormPlugin['elements']) 
			&& $this->checkElements($WFEntryFormPlugin['elements'])
			&& array_key_exists('displayGroupName', $WFEntryFormPlugin) 
			&& array_key_exists('displayGroupLegend', $WFEntryFormPlugin) 		
		) {
			return true;
		}
		else {
			return false;
		}
	 }
	 
	/**
	 * Checks whther supplied elements array has valid structure. 
	 *
	 * @param array Elements array.
	 * @return bool
	 */
	 protected function checkElements($elements)
	 {
		foreach ($elements as $element) {
			if (is_array($element) && array_key_exists('type', $element) && array_key_exists('name', $element)) {
				continue;
			}
			else {
				return false;
			}
		}
		
		return true;
	 }
}
?>