<?php
/**
 * Webfolio CMS
 *
 * Copyright (C) 2009 Nikola Posa (http://www.nikolaposa.in.rs)
 *
 * This file is part of Webfolio CMS.
 *
 * Webfolio CMS is free software: you can redistribute it and/or modify 
 * it under the terms of the GNU General Public License as published by 
 * the Free Software Foundation, either version 3 of the License, or 
 * (at your option) any later version.
 *
 * Webfolio CMS is distributed in the hope that it will be useful, but 
 * WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU 
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License 
 * along with Webfolio CMS. If not, see <http://www.gnu.org/licenses/>.
 */
 
/**
 * WebfolioEntries model for admin panel. Extends 
 * WebfolioEntries from default module to add functionality 
 * for saving data from additional WFEntry form plugins.
 * 
 * @author Nikola Posa <posa.nikola@gmail.com>
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License
 */
class Admin_Model_WebfolioEntries extends Model_WebfolioEntries
{
	/**
	 * Constructor.
	 *
	 * @param string Type of an entry.
	 * @param array Data of some entry.
	 * @return Model_WebfolioEntries
	 */
	public function __construct($type, array $options = null)
    {
		parent::__construct($type, $options);
		
		$this->mapper = new Admin_Model_Mapper_WebfolioEntries($this->type);
    }
	
	/**
	 * Saves current webfolio entry, and also notifies WFEntry 
	 * form plugins save() method.
	 * 
	 * @return mixed
	 */
	public function save()
    {
		if (!isset($this->userId)) { //If we're saving entry for the first time, we should also retrieve id of a user who is submitting this entry.
			if (!WebfolioCMS_Common::isUserLoggedIn()) {
                throw new Exception('Only authenticated user can submit webfolio entries.');
            }

            $this->userId = WebfolioCMS_Auth::getInstance()->getIdentity()->id;
		}
		
		$retval = parent::save();
		
		//Notifying registered event handlers of save() method.
		if (Zend_Registry::isRegistered(Admin_Form_WFEntry::REGISTRY_KEY)) {
			$id = ($this->id) ? $this->id : $retval;
			
			WebfolioCMS_Events_Broker::notifyEventHandlers(WebfolioCMS_Events_Broker::WF_ENTRY_SAVE, array(Zend_Registry::get(Admin_Form_WFEntry::REGISTRY_KEY), $id));
		}
		
		return $retval;
    }
}
?>