<?php
/**
 * Webfolio CMS
 *
 * Copyright (C) 2009 Nikola Posa (http://www.nikolaposa.in.rs)
 *
 * This file is part of Webfolio CMS.
 *
 * Webfolio CMS is free software: you can redistribute it and/or modify 
 * it under the terms of the GNU General Public License as published by 
 * the Free Software Foundation, either version 3 of the License, or 
 * (at your option) any later version.
 *
 * Webfolio CMS is distributed in the hope that it will be useful, but 
 * WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU 
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License 
 * along with Webfolio CMS. If not, see <http://www.gnu.org/licenses/>.
 */
 
/**
 * Model for managing apllication Webofolio CMS settings.
 *
 * @author Nikola Posa <posa.nikola@gmail.com>
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License
 */
class Admin_Model_WebfolioSettings_App extends Admin_Model_WebfolioSettings_Abstract
{
	/**
	 * App settings.
	 *
	 * @var array
	 */
	protected $settings = array(
		'use_webfolio_page', 
		'use_smileys',
		'upload_path',
		'enable_rss_wf_items'
	);
	
	/**
	 * Defined by Admin_Model_WebfolioSettings_Abstract.
	 *
	 * @return mixed
	 */
	public function getValues()
	{
		$settings = parent::getValues();
		
		//Redefining getValues() method, because we should remove BASE_PATH from 
		//absoulte upload path.
		$settings['upload_path'] = str_replace(BASE_PATH, '', $settings['upload_path']);
		$settings['upload_path'] = ltrim($settings['upload_path'], '/');
		
		return $settings;
	}
	
	/**
	 * Defined by Admin_Model_WebfolioSettings_Abstract.
	 *
	 * @param array Array with settings and their values.
	 * @return void
	 */
	public function save($data)
	{
		//Redefining save() method, because we must prepend BASE_PATH onto 
		//path that user supplied in app settings form.
		if (isset($data['upload_path'])) {
			$data['upload_path'] = BASE_PATH . '/' . $data['upload_path'];
		}
		
		parent::save($data);
	}
}
?>