<?php
/**
 * Webfolio CMS
 *
 * Copyright (C) 2009 Nikola Posa (http://www.nikolaposa.in.rs)
 *
 * This file is part of Webfolio CMS.
 *
 * Webfolio CMS is free software: you can redistribute it and/or modify 
 * it under the terms of the GNU General Public License as published by 
 * the Free Software Foundation, either version 3 of the License, or 
 * (at your option) any later version.
 *
 * Webfolio CMS is distributed in the hope that it will be useful, but 
 * WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU 
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License 
 * along with Webfolio CMS. If not, see <http://www.gnu.org/licenses/>.
 */
 
/**
 * Controller plugin which checks whether user is
 * authenticated and whether he/she has appropriate
 * privileges for accessing some resource.This plugin is
 * made to "protect" admin module, or admincontroller of
 * some other module.
 *
 * @author Nikola Posa <posa.nikola@gmail.com>
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License
 */
class Admin_Plugin_AdminAuthChecker extends Zend_Controller_Plugin_Abstract
{
	/**
	 * Redefining routeShutdown hook.
	 *
	 * @return void
	 */
	public function routeShutdown(Zend_Controller_Request_Abstract $request)
    {
		$module = $request->getModuleName();
		$controller = $request->getControllerName();
        $action = $request->getActionName();

		//If user is accessing some page in admin module, or admin controller of some other module,
        //we should check whether he/she is authenticated.
		if ($module == 'admin' || $controller == 'admin') {		
			if (!WebfolioCMS_Common::isUserLoggedIn()) { //Not logged in? Redirect him/her to login page.
                if ($controller != 'login') {
                    $WFAdminSession = new Zend_Session_Namespace('WFAdmin');
                    $WFAdminSession->redirectTo = $request->getRequestUri();

                    $request->setModuleName('admin');
                    $request->setControllerName('login');
                    $request->setActionName('index');
                }
			}
			else { //User is logged in.
				if ($controller == 'login') { //He/she shouldn't go back to login page.
                    $request->setModuleName('admin');
                    $request->setControllerName('index');
                    $request->setActionName('index');
                }
                elseif (!WebfolioCMS_Common::isUserAllowed(WebfolioCMS_Auth::getInstance()->getIdentity()->group_id, $module . '_' . $controller, $action)) {
                    throw new Exception('You are not allowed to access requested resource.');
                }
			}
		}
	}
}
?>