<?php
/**
 * Webfolio CMS
 *
 * Copyright (C) 2009 Nikola Posa (http://www.nikolaposa.in.rs)
 *
 * This file is part of Webfolio CMS.
 *
 * Webfolio CMS is free software: you can redistribute it and/or modify 
 * it under the terms of the GNU General Public License as published by 
 * the Free Software Foundation, either version 3 of the License, or 
 * (at your option) any later version.
 *
 * Webfolio CMS is distributed in the hope that it will be useful, but 
 * WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU 
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License 
 * along with Webfolio CMS. If not, see <http://www.gnu.org/licenses/>.
 */
 
/**
 * Admin module ViewHelper that generates combo box, with 
 * available webfolio entries in it.
 *
 * @author Nikola Posa, www.nikolaposa.in.rs
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License
 */
class Zend_View_Helper_EntriesComboBox
{
	/**
	 * Generates combo box with webfolio entries in it.
	 *
	 * @param string|null Name of the combo box element.
	 * @param string|null Id of a entry that is currently selected.
	 *
	 * Supported params for $options:
	 *   'type' Entry type (string),
	 *   'emptyOption' Whether to generate starting empty option. (bool),
	 *   'excludeId' Id of a entry that should be excluded from listing, i.e. item that is currently being edited (int).
	 *
	 * @return string
	 */
	public function entriesComboBox($comboBoxName = null, $id = null, $options)
	{	
		$webfolioEntries = new Model_DbTable_WebfolioEntries();
		
		//Getting all entries as a tree.
		$where = null;
		$chooseText = 'Choose';
		if ($options['pickType']) {
			$where = 'node.type IN (' . $webfolioEntries->getAdapter()->quote($options['pickType']) . ')';
			
			if (count($options['pickType']) == 1) {
				$chooseText .= ' ' . current($options['pickType']);
			}
		}
		elseif ($options['omitType']) {
			$where = 'node.type NOT IN (' . $webfolioEntries->getAdapter()->quote($options['omitType']) . ')';
		}
		
		$allEntries = $webfolioEntries->getTree($where);
		
		$output = '';
		
		if ($comboBoxName != null) {
			$output = '<select name = "' . $comboBoxName . '" id = "' . $comboBoxName . '">';
		}
		
		if ($options['emptyOption']) {
			$output .= '<option value = "">' . $chooseText . '</option>';
		}
		
		foreach ($allEntries as $entry) {
			if (!$options['excludeId'] || $entry['id'] != $options['excludeId']) {
				$selected = '';
				if (isset($id) && $id == $entry['id']) {
					$selected = ' selected = "selected"';
				}
				
				$output .= '
							<option value = "' . $entry['id'] . '"' . $selected . ' style = "padding-left: ' . ((int)$entry['depth'] * 6) . 'px;">' . $entry['title'] . '</option>';
			}
		}
		
		if ($comboBoxName != null) {
			$output .= '
					</select>';
		}
		
		return $output;
	}
}
?>