<?php
/**
 * Webfolio CMS
 *
 * Copyright (C) 2009 Nikola Posa (http://www.nikolaposa.in.rs)
 *
 * This file is part of Webfolio CMS.
 *
 * Webfolio CMS is free software: you can redistribute it and/or modify 
 * it under the terms of the GNU General Public License as published by 
 * the Free Software Foundation, either version 3 of the License, or 
 * (at your option) any later version.
 *
 * Webfolio CMS is distributed in the hope that it will be useful, but 
 * WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU 
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License 
 * along with Webfolio CMS. If not, see <http://www.gnu.org/licenses/>.
 */
 
/**
 * ViewHelper for generating head section of admin module 
 * pages, using HeadSection class.
 *
 * @author Nikola Posa, www.nikolaposa.in.rs
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License
 */
class Zend_View_Helper_HeadSection extends WebfolioCMS_View_Helper_HeadSectionAbstract 
{
	/**
	 * Adding head section elements of pages in admin module, 
	 * based on action controller.
	 *
	 * @return WebfolioCMS_View_Helper_HeadSectionAbstract
	 */
	public function headSection() 
	{
		//Getting site name that will be appended/prepended to the title in the head section.
		$this->addTitle(
			Model_WebfolioSettings::getSettings('site_title') . ' | Admin panel | ' . strip_tags($this->view->navigation()->breadcrumbs()->setSeparator(' | ')->setMinDepth(0)->setUseTranslator(false)->render(new Zend_Navigation(Admin_Model_WFAdminMenu::get()))), 
			'PREPEND'
		);
		
		//Default resources.
		$this->addCss($this->view->baseUrl('front-end/css/admin/fieldsets.css'));
		$this->addJs(array(
			$this->view->baseUrl('libs/jQuery/jquery.js'),
			$this->view->baseUrl('libs/jQuery/plugins/jquery.json.js'),
			$this->view->baseUrl('libs/jQuery/plugins/jquery.protect-data.js'),
			$this->view->baseUrl('front-end/js/admin/common.js'),
			), 
			WebfolioCMS_View_Helper_HeadSectionAbstract::FILE,
			'PREPEND'
		);
		$this->view->headScript('FILE', $this->view->baseUrl('libs/jQuery/plugins/pngFix/jquery.pngFix.js'), 'APPEND', array('conditional'=>'IE'));
		$this->view->headScript('FILE', $this->view->baseUrl('front-end/js/png_fix.js'), 'APPEND', array('conditional'=>'IE'));
					
		//Adding head section elements depending on action controller.
		switch ($this->controller) 
		{
			case 'index':
			{
				$this->addTitle('Welcome');
				
				break;
			}
			case 'pages':
			{
				break;
			}
			case 'items':
			{
				if ($this->action == 'index') {
					$this->addJs(array(
						$this->view->baseUrl('libs/ExtJS/adapter/ext/ext-base.js'), 
						$this->view->baseUrl('libs/ExtJS/ext-all.js'),
                        $this->view->baseUrl('front-end/js/admin/basic_grid.js?param=' . mt_rand()),
						$this->view->baseUrl('front-end/js/admin/manage_grids.js?param=' . mt_rand())
					));
				}
				
				break;
			}
			case 'comments':
			{	
				if ($this->action == 'index' || $this->action == 'spam') {
					$this->addJs(array(
						$this->view->baseUrl('libs/ExtJS/adapter/ext/ext-base.js'), 
						$this->view->baseUrl('libs/ExtJS/ext-all.js'),
                        $this->view->baseUrl('front-end/js/admin/basic_grid.js?param=' . mt_rand()),
						$this->view->baseUrl('front-end/js/admin/manage_grids.js?param=' . mt_rand())
					));
				}
				
				break;
			}
			case 'appearance':
			{
				$this->addCss($this->view->baseUrl('front-end/css/admin/front-end.css'));
				
				$this->addJs(array(	
						$this->view->baseUrl('libs/ExtJS/adapter/ext/ext-base.js'), 
						$this->view->baseUrl('libs/ExtJS/ext-all.js')
					)
				);
				
				if ($this->action == 'themes') {
					$this->addCss($this->view->baseUrl('libs/shadowbox/shadowbox.css'));
					$this->addJs(array(
						$this->view->baseUrl('front-end/js/admin/themes_panel.js?param=' . mt_rand()),
						$this->view->baseUrl('libs/shadowbox/shadowbox.js'),
						$this->view->baseUrl('front-end/js/admin/edit_theme.js')
						)
					);
				}
				elseif ($this->action == 'sidebar') {
					$this->addJs(
						array(
							$this->view->baseUrl('front-end/js/admin/front_end_drag_drop.js'),
							$this->view->baseUrl('front-end/js/admin/sidebar_dd_panel.js?param=' . mt_rand())
						)
					);
				}
				elseif ($this->action == 'content-plugins') {
					$this->addJs(
						array(
							$this->view->baseUrl('front-end/js/admin/front_end_drag_drop.js'),
							$this->view->baseUrl('front-end/js/admin/content_plugins_panel.js?param=' . mt_rand())
						)
					);
				}
				
				break;
			}
			case 'settings':
			{
				if ($this->action == 'general') {
					$this->addJs($this->view->baseUrl('front-end/js/admin/date_time_preview.js'));
				}
				
				break;
			}	
			case 'modules':
			{
				$this->addJs(array(
						$this->view->baseUrl('libs/ExtJS/adapter/ext/ext-base.js'), 
						$this->view->baseUrl('libs/ExtJS/ext-all.js'),
						$this->view->baseUrl('front-end/js/admin/modules_grid.js?param=' . mt_rand())
					)
				);
				
				break;
			}
			case 'users':
			{
                if ($this->action == 'add' || $this->action == 'edit') {
                    $this->addCss($this->view->baseUrl('libs/jQuery/plugins/password_strength/style.css'));

                    $this->addJs($this->view->baseUrl('libs/jQuery/plugins/password_strength/password_strength_plugin.js'));
                    $this->addJs(
                        '$(document).ready( function() {
                            $(".password_test").passStrength({
                                userid:	"#user-username"
                            });
                        });'
                    , 'SCRIPT');
                }
                else {
                    $this->addJs(array(
                        $this->view->baseUrl('libs/ExtJS/adapter/ext/ext-base.js'),
                        $this->view->baseUrl('libs/ExtJS/ext-all.js'),
                        $this->view->baseUrl('front-end/js/admin/basic_grid.js'),
                        $this->view->baseUrl('front-end/js/admin/users_grid.js')
                    ));
                }
				
				break;
			}
            case 'groups':
			{
                if ($this->action == 'index') {
                    $this->addJs(array(
                        $this->view->baseUrl('libs/ExtJS/adapter/ext/ext-base.js'),
                        $this->view->baseUrl('libs/ExtJS/ext-all.js'),
                        $this->view->baseUrl('front-end/js/admin/basic_grid.js'),
                        $this->view->baseUrl('front-end/js/admin/groups_grid.js')
                    ));
                }

				break;
			}
            case 'groups-permissions':
			{
                $this->addCss($this->view->baseUrl('front-end/css/admin/css_table.css'));
                $this->addJs($this->view->baseUrl('front-end/js/admin/groups_permissions.js'));

				break;
			}
			case 'login':
			{
				$this->addTitle('Log in');
				
				$this->addCss($this->view->baseUrl('front-end/css/admin/login.css'), WebfolioCMS_View_Helper_HeadSectionAbstract::FILE, 'PREPEND');

                $this->addJs($this->view->baseUrl('front-end/js/admin/login.js'), WebfolioCMS_View_Helper_HeadSectionAbstract::FILE);
		
				break;
			}
		}
		
		return $this;
	}
}
?>