<?php
/* 
 * Webfolio CMS
 * 
 * Copyright (C) 2009 Nikola Posa (http://www.nikolaposa.in.rs)
 * 
 * This file is part of Webfolio CMS.
 * 
 * Webfolio CMS is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Webfolio CMS is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Webfolio CMS. If not, see <http://www.gnu.org/licenses/>.
 */

/**
 * Helper for rendering combo box with options for choosing
 * public name of some user, which are rendered based on
 * user's username,first and last name.
 *
 * @author Nikola Posa <posa.nikola@gmail.com>
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License
 */
class Zend_View_Helper_PublicNamePicker extends Zend_View_Helper_Abstract
{
    /**
	 * Renders combo box with options for choosing public name of
     * some user.
	 *
     * Supported params for $config are:
     *   username  - user's username,
     *   firstName - first name meta (optional),
     *   lastName  - last name meta (optional)
     *
     * @param string Name of the combo box that will be rendered.
     * @param array Data which will be used when generating options (username, firstName, lastName)
     * @param string Current public name. (optional)
	 * @return string
	 */
	public function publicNamePicker($name, $data, $value = null)
	{
        extract($data);

        if (!isset($username)) {
            throw new Exception('Username must be supplied in order to use this helper.');
        }
        
        $values = array('username'=>$username);
        
        if (isset($firstName)) {
            $values['firstName'] = $firstName;
        }

        if (isset($lastName)) {
            $values['lastName'] = $lastName;
        }

        if (isset($firstName) && isset($lastName)) {
            $values['firstName_lastName'] = $firstName . ' ' . $lastName;
            $values['lastName_firstName'] = $lastName . ' ' . $firstName;
        }

        $output = '<select name="' . $this->view->escape($name) . '" id="' . $this->view->escape(str_replace(array('[', ']['), '-', trim($name, ']'))) . '" style = "width: 140px;">';

        foreach ($values as $id=>$val) {
            $selected = ($val==$value) ? ' selected="selected"' : '';
            $output .= '
                        <option id="' . $id . '" value="' . $val . '"' . $selected . '>' . $val . '</option>';
        }

        $output .= '
                </select>';

        return $output;
	}
}
?>
