<?php
/**
 * Webfolio CMS
 *
 * Copyright (C) 2009 Nikola Posa (http://www.nikolaposa.in.rs)
 *
 * This file is part of Webfolio CMS.
 *
 * Webfolio CMS is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Webfolio CMS is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Webfolio CMS. If not, see <http://www.gnu.org/licenses/>.
 */

/**
 * View helper which is used for generating TinyMCE editor
 * textarea.
 *
 * @author Nikola Posa, www.nikolaposa.in.rs
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License
 */
class Zend_View_Helper_TinyMCEeditor extends Zend_View_Helper_FormTextarea
{
	const THEME_SIMPLE = 'simple';
	const THEME_ADVANCED = 'advanced';
	
	/**
	 * Buttons available in the advanced theme.
	 *
	 * @var array
	 */
	protected $advancedThemeButtons = array(
		'bold',
		'italic',
		'underline',
		'strikethrough',
		'justifyleft',
		'justifycenter',
		'justifyright',
		'justifyfull',
		'bullist',
		'numlist',
		'outdent',
		'indent',
		'cut',
		'copy',
		'paste',
		'undo',
		'redo',
		'link',
		'unlink',
		'image',
		'cleanup',
		'help',
		'code',
		'hr',
		'removeformat',
		'formatselect',
		'fontselect',
		'fontsizeselect',
		'styleselect',
		'sub',
		'sup',
		'forecolor',
		'backcolor',
		'forecolorpicker',
		'backcolorpicker',
		'charmap',
		'visualaid',
		'anchor',
		'newdocument',
		'blockquote',
		'separator',
		'|' 
	);
	
	/**
	 * List of plugins which have their buttons and/or valid 
	 * elements extensions.
	 *
	 * @var array
	 */
	protected $plugins = array(
		'advhr' 		 => array('buttons'=>array('advhr'), 'valid_elements'=>array('hr'=>array('class', 'width', 'size', 'noshade'))),
		'advimage' 		 => array('valid_elements'=>array('a'=>array('name', 'href', 'target', 'title', 'onclick', 'rel', 'class', 'style'))),
		'advlink' 		 => array('valid_elements'=>array('a'=>array('name', 'href', 'target', 'title', 'onclick', 'class', 'style', 'rel'))),
		'iespell' 		 => array('buttons'=>array('iespell')),
		'insertdatetime' => array('buttons'=>array('insertdate', 'inserttime')),
		'layer' 		 => array('buttons'=>array('moveforward', 'movebackward', 'absolute', 'insertlayer')),
		'media' 		 => array('buttons'=>array('media')),
		'nonbreaking' 	 => array('buttons'=>array('nonbreaking')),
		'paste' 	  	 => array('buttons'=>array('pastetext', 'pasteword', 'selectall')),
		'preview' 	  	 => array('buttons'=>array('preview')),
		'print' 	     => array('buttons'=>array('print')),
		'searchreplace'  => array('buttons'=>array('search', 'replace')),
		'style' 		 => array('buttons'=>array('styleprops')),
		'table' 		 => array('buttons'=>array('tablecontrols', 'table', 'row_props', 'cell_props', 'delete_col', 'delete_row', 'col_after', 'col_before', 'row_after', 'row_before', 'split_cells', 'merge_cells')),
		'visualchars' 	 => array('buttons'=>array('visualchars')),
		'xhtmlxtras' 	 => array('buttons'=>array('cite', 'abbr', 'acronym', 'ins', 'del', 'attribs'))
	);
	
	/**
	 * Default TinyMCE configuration.
	 *
	 * @var array
	 */
	protected $defaultOptions = array(
		'entities' => '160,nbsp,38,amp,34,quot,60,lt,62,gt',
		'entity_encoding' => 'named',
		'relative_urls' => false,
		'remove_script_host' => true,
		'cleanup_on_startup' => true,
		'theme_advanced_toolbar_location' => 'top',
		'theme_advanced_toolbar_align' => 'left',
		'theme_advanced_statusbar_location' => 'bottom',
		'theme' => self::THEME_ADVANCED,
		'theme_advanced_buttons' => array(
			1 => array('bold','italic','underline','strikethrough','|','justifyleft','justifycenter','justifyright','justifyfull','|','bullist','numlist','|','outdent','indent','|','styleselect','formatselect','fontselect','fontsizeselect'),
			array('cut','copy','paste','pastetext','pasteword','|','search','replace','|','undo','redo','|','link','unlink','anchor','image','media','cleanup','|','insertdate','inserttime','|','forecolor','backcolor'),
			array('tablecontrols','|','removeformat','visualaid','|','sub','sup','|','advhr','charmap','iespell','|','code','preview','print','help'),
			array('insertlayer','moveforward','movebackward','absolute','|','styleprops','|','blockquote','cite','abbr','acronym','del','ins','attribs')
		),
		'plugins' => array('advlink', 'advimage', 'advlist', 'contextmenu', 'inlinepopups')
	);
	
	/**
	 * Array which will be used as a option storage during setup and 
	 * rendering. This array will be reseted after generating JS code 
	 * in generateJS() method, to prevent persistance of this options 
	 * during one request and therefore to enable user to have 
	 * multiple editors on one page.
	 *
	 * @var array
	 */
	protected $options;

	/**
	 * Constructor.
	 *
	 * @return void
	 */
	public function __construct()
	{
		$this->defaultOptions['document_base_url'] = WebfolioCMS_Common::baseUrl() . '/';
		$this->defaultOptions['setup'] = new Zend_Json_Expr("function(ed) { ed.onKeyUp.add(function(ed, evt) { if ($('#' + ed.id).parents('form.alert_form').length > 0) { $.protectData.protect();  } });}");
	}

    /**
     * Generates TinyMCE editor textarea. This method utilize 
	 * formTextarea view helper to generate actual HTML code and 
	 * does the inclusion of necessary TinyMCE JS code in header of 
	 * a page.
     * 
	 * @param string Name of the form field.
	 * @param string Form field value. (optional)
	 * @param array TinyMCE configuration array together with some other options for the textarea element tag. (optional)
     * @return string
     */
	public function tinyMCEeditor($name, $value = '', $options = array())
    {
		$this->options = $this->defaultOptions;
		
		$options = $this->prepareOptions($options);
		if (!empty($options['tmce'])) {
			$this->setOptions($options['tmce']);
		}
		
		$this->setupOptions();
		
		$this->generateJS($name);
		
		return $this->formTextarea($name, $value, $options['other']);
    }
	
	/**
     * Prepares supplied options, by spliting those attended for 
	 * configuring TinyMCE editor, and some other options, which 
	 * are probably for setting atttibutes of textarea element.
     * 
	 * @param array TinyMCE configuration array together with some other options for the textarea element tag.
     * @return array
     */
	protected function prepareOptions(array $options)
	{
		$groupedOptions = array('tmce'=>array(), 'other'=>array());
		
		foreach ($options as $key=>$option) {	
			if (substr($key, 0, 5) == 'tmce_') {
				$newKey = substr($key, 5);
				if (!in_array($newKey, array('mode', 'plugins')) && strstr($newKey, 'theme_advanced_buttons') === false) { //Setting of mode, plugins and theme_advanced_buttons* options is not allowed.
					$groupedOptions['tmce'][$newKey] = $option;
				}
			}
			else {
				$groupedOptions['other'][$key] = $option;
			}
		}
		
		return $groupedOptions;
	}
	
	/**
     * Sets supplied options for configuring TinyMCE editor. All 
	 * supported TinyMCE can be supplied as key=>value pairs, except 
	 * that buttons and plugins are added through special keys:
	 *    buttonsReset - resets current "theme_advanced_buttons" array,
	 *    buttonsAdd   - replace those rows which keys correspond to those from this array,
	 *    nonButtonsPluginsReset - used for reseting list with plugins which don't have buttons,
	 *    nonButtonsPluginsAdd - used for adding plugins without buttons.
     *
	 * @param array TinyMCE configuration options.
     * @return void
     */
	protected function setOptions(array $options)
	{
		if (isset($options['theme']) && $options['theme'] == self::THEME_SIMPLE) {
			$this->options['theme'] = self::THEME_SIMPLE;
			unset($this->options['theme_advanced_buttons']);
			unset($this->options['plugins']);
		}
		else {
			if (isset($options['nonButtonsPluginsReset']) && is_array($options['nonButtonsPluginsReset'])) {
				$this->options['plugins'] = $options['nonButtonsPluginsReset'];
				unset($options['nonButtonsPluginsReset']);
			}
			elseif (isset($options['nonButtonsPluginsAdd']) && is_array($options['nonButtonsPluginsAdd'])) {
				foreach ($options['nonButtonsPluginsAdd'] as $plugin) {
					if (!in_array($plugin, $this->options['plugins'])) {
						$this->options['plugins'][] = $plugin;
					}
				}
				unset($options['nonButtonsPluginsAdd']);
			}
			
			if (isset($options['buttonsReset']) && is_array($options['buttonsReset']) && is_array(current($options['buttonsReset']))) {
				$this->options['theme_advanced_buttons'] = $options['buttonsReset'];
				unset($options['buttonsReset']);
			}
			elseif (isset($options['buttonsAdd']) && is_array($options['buttonsAdd'])) {
				foreach ($options['buttonsAdd'] as $key=>$buttons) {
					if (is_numeric($key) && is_array($buttons)) {
						$this->options['theme_advanced_buttons'][$key] = $buttons;
					}
				}
				unset($options['buttonsAdd']);
			}
		}
		
		$this->options = array_merge($this->options, $options); //Adding other supplied options.
	}
	
	/**
     * Preparing $options array, by loading plugins according to the 
	 * added buttons and setting up some plugins' settings.
     *
     * @return void
     */
	protected function setupOptions()
	{
		$this->setupButtons();
		$this->setupPlugins();
	}
	
	/**
     * Removes all unsupported or invalid supplied buttons and loads 
	 * plugins for all added buttons which don't belong to 
	 * $advancedThemeButtons.
     *
	 * @param string Name of the form field that will be set as "elements" options.
     * @return void
     */
	protected function setupButtons()
	{
		if (isset($this->options['theme_advanced_buttons'])) {
			foreach ($this->options['theme_advanced_buttons'] as $i=>$buttons) {
				foreach ($buttons as $j=>$button) {
					if (!in_array($button, $this->advancedThemeButtons)) {
						$foundButton = false;
						foreach ($this->plugins as $plugin=>$setup) {
							if (isset($setup['buttons']) && in_array($button, $setup['buttons'])) {
								if (!in_array($plugin, $this->options['plugins'])) {
									$this->options['plugins'][] = $plugin;
								}
								
								$foundButton = true;
								break;
							}
						}
						
						if (!$foundButton) { //Plugin is not added, which means that supplied button is not supported or is invalid.
							unset($this->options['theme_advanced_buttons'][$i][$j]);
						}
					}
				}
			}
		}
	}
	
	/**
     * Sets "extended_valid_elements" TinyMCE option if some plugin 
	 * which have some valid_elements rules to add is loaded.
     *
     * @return void
     */
	protected function setupPlugins()
	{
		if (isset($this->options['plugins'])) {
			foreach ($this->options['plugins'] as $key=>$plugin) {
				if (array_key_exists($plugin, $this->plugins)) {
					if (isset($this->plugins[$plugin]['valid_elements'])) { //Plugin has some valid elements to add?
						if (!isset($this->options['extended_valid_elements'])) {
							$this->options['extended_valid_elements'] = array();
						}
						
						$this->options['extended_valid_elements'] = array_merge_recursive($this->options['extended_valid_elements'], $this->plugins[$plugin]['valid_elements']);
					}
				}
			}
		}
	}
	
	/**
     * Converts data from $options array in form which is fits 
	 * TinyMCE options syntax and includes all necessary JS code in 
	 * header of a page by utilizing headScript view helper.
     *
	 * @param string Name of the form field that will be used as target for rendering.
     * @return void
     */
	protected function generateJS($name)
	{
		$output = $this->view->headScript(Zend_View_Helper_HeadScript::FILE, $this->view->baseUrl('libs/TinyMCE/jscripts/tiny_mce/jquery.tinymce.js'));
		
		$options = $this->options;
		
		foreach ($options as $key=>$option) {
			if ($key == 'plugins' && !empty($option)) {
				$options['plugins'] = implode(',', $option);
			}
			elseif ($key == 'theme_advanced_buttons') {
				foreach ($option as $i=>$buttons) {
					$options['theme_advanced_buttons' . $i] = implode(',', $buttons);
				}
				unset($options['theme_advanced_buttons']);
			}
			elseif ($key == 'extended_valid_elements') {
				$extended_valid_elements = array();
				foreach ($option as $elem=>$attribs) {
					$extended_valid_elements[] = $elem . '[' . implode('|', array_unique($attribs)) . ']';
				}
				
				$options['extended_valid_elements'] = implode(',', $extended_valid_elements);
			}
		}
		
		$options['script_url'] = $this->view->baseUrl('libs/TinyMCE/jscripts/tiny_mce/tiny_mce.js');
		
		$output .= $this->view->headScript(Zend_View_Helper_HeadScript::SCRIPT, 
			"$(document).ready(function() {
				$('textarea#" . $name . "').tinymce("
				. Zend_Json::encode($options, false, array('enableJsonExprFinder' => true))
				. ');
			});'
		);
		
		$this->options = null; //Preventing situation in which previous options set for some element will affect some other, if user is outputting two or more TinyMCE editors on the same page.
	}
}
?>
