<?php
/**
 * Webfolio CMS
 *
 * Copyright (C) 2009 Nikola Posa (http://www.nikolaposa.in.rs)
 *
 * This file is part of Webfolio CMS.
 *
 * Webfolio CMS is free software: you can redistribute it and/or modify 
 * it under the terms of the GNU General Public License as published by 
 * the Free Software Foundation, either version 3 of the License, or 
 * (at your option) any later version.
 *
 * Webfolio CMS is distributed in the hope that it will be useful, but 
 * WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU 
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License 
 * along with Webfolio CMS. If not, see <http://www.gnu.org/licenses/>.
 */
 
/**
 * Action helper that handles saving of taxonomy/terms data, 
 * that can be posted during some request in admin panel. 
 * Some additional module can use Taxonomy module in forms for 
 * adding some of its content, and this helper will handle and 
 * save all terms related data from such forms.
 *
 * @author Nikola Posa <posa.nikola@gmail.com>
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License
 */
class Taxonomy_Controller_Action_Helper_TaxonomyDataHandler extends Zend_Controller_Action_Helper_Abstract
{	
	/**
     * Terms-related data from some form that uses taxonomy (terms) 
	 * functionality, retrieved in preDispatch hook.
     *
     * @return void
     */
	protected $termsData = array();
	
    /**
     * Defined by Zend_Controller_Action_Helper_Abstract.
     *
	 * Gathers taxonomy-related data from some form.
	 *
     * @return void
     */
    public function preDispatch()
    {
		if ($this->getRequest()->isPost() && ($termsData = $this->getRequest()->getPost('taxonomyData'))) {
            $this->termsData = $termsData;
		}
	}
	
	/**
     * Saves terms data gathered in preDispatch hook, and relating 
	 * them with content id which is passed as argument.
	 *
     * @param int Content id.
     * @return void
     */
	protected function saveTermsData($contentId)
	{
		if (!empty($this->termsData)) {
			foreach ($this->termsData as $taxonomy=>$taxData) {
				$terms = trim($taxData['terms']);
				$currentTerms = trim($taxData['current']);
				
				if ($terms != $currentTerms) {
					$taxonomyMain = new Taxonomy_Model_Main($taxonomy);
					
					$dbHandler = $taxonomyMain->getDbHandler();
					$dbHandler->beginTransaction();
					
					try {
						if ($terms == '') { //User want to remove relation with some content?
							$taxonomyMain->removeTermRelations($contentId);
						}
						elseif (is_numeric($terms) && strpos($terms, Taxonomy_Model_Main::MULTI_TERMS_SEPARATOR) === false) { //Combo box?
							$taxonomyMain->saveTermRelations($contentId, $terms);
						}
						else { //Text field (tags)...
							$multiTerms = explode(Taxonomy_Model_Main::MULTI_TERMS_SEPARATOR, $terms);
							
							$taxonomyMain->saveTermRelations($contentId, $multiTerms);
						}
						
						$dbHandler->commit();
					}
					catch (Zend_Db_Exception $ex) {
						$dbHandler->rollBack();
						
						throw $ex;
					}		
				}
			}
		}
	}
	
	/**
     * Strategy pattern: proxy to saveTermsData().
	 *
     * @param int Content id.
     * @return void
     */
    public function direct($contentId)
    {
        $this->saveTermsData($contentId);
    }
}
?>