<?php
/**
 * Webfolio CMS
 *
 * Copyright (C) 2009 Nikola Posa (http://www.nikolaposa.in.rs)
 *
 * This file is part of Webfolio CMS.
 *
 * Webfolio CMS is free software: you can redistribute it and/or modify 
 * it under the terms of the GNU General Public License as published by 
 * the Free Software Foundation, either version 3 of the License, or 
 * (at your option) any later version.
 *
 * Webfolio CMS is distributed in the hope that it will be useful, but 
 * WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU 
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License 
 * along with Webfolio CMS. If not, see <http://www.gnu.org/licenses/>.
 */
 
/**
 * Action helper for managing options for customizing terms 
 * grid and form, in session, so they can be handled in 
 * appropriate place. This helper should be called by modules 
 * which use taxonomy module, usually in preDispatch() method 
 * of their admin action controller on which taxonomy helpers 
 * are used.
 *
 * @author Nikola Posa <posa.nikola@gmail.com>
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License
 */
class Taxonomy_Controller_Action_Helper_TermsCustomParams extends Zend_Controller_Action_Helper_Abstract
{
    /**
     * Default params that are used in displaying terms form 
     * and grids.
     * 
     * @var array
     */
    protected $_termsCustomParams = array(
        'keyword'		  => 'term',
        'nameColLabel'	  => 'Name',
        'termNameLabel'	  => 'Name',
        'useParent'		  => true,
        'parentTermLabel' => 'Parent'
    );

	/**
     * Zend_Session storage object.
     *
     * @var Zend_Session_Namespace
     */
    protected static $_WFTaxonomySession;
	
	/**
     * Session ariable that is used for holding terms params.
     *
     * @var string
     */
	protected $_variable = 'termsCustomParams';
	
	/**
     * Constructor.
     *
     * @return void
     */
	public function __construct()
	{
        self::$_WFTaxonomySession = new Zend_Session_Namespace('WFTaxonomy');

        if (self::$_WFTaxonomySession->__isset($this->_variable)) {
            $this->_termsCustomParams = self::$_WFTaxonomySession->{$this->_variable};
        }
	}

	/**
	 * Stores user supplied options for customizing terms grid and 
	 * form, in session, so they can be handled in appropriate 
	 * place. This should be called by modules which use taxonomy 
	 * module, usually in init() method of action controller on 
	 * which taxonomy helpers are used.
	 *
	 * Supported params for $options are:
     *   keyword - Word that describes your taxonomy and will be used in many rendering situations (form heading title, grid empty message, etc.),
     *   nameColLabel - Header lable of form term name column in terms grid (string),
	 *   termNameLabel - Label of term name field in form for adding/editing term (string),
	 * 	 useParent - Whether to enable selection of parent term in form for adding/editing term (bool)
	 *	 parentTermLabel - Label of combo box for selecting parent term.
	 *
	 * @param array Options for generating terms grid and form.
	 * @return void
	 */
	public function setTermsCustomParams($options)
	{
        $this->_termsCustomParams = array_merge($this->_termsCustomParams, $options);
		self::$_WFTaxonomySession->{$this->_variable} = $this->_termsCustomParams;
	}
	
	/**
     * Gets params that are used in displaying terms form and 
	 * grids.
     *
     * @return array
     */
    public function getTermsParams()
    {
        return $this->_termsCustomParams;
    }
	
	/**
     * Strategy pattern: proxy to setTermsCustomParams().
	 *
     * @param array Options for generating terms grid and form.
     * @return void
     */
    public function direct($options)
    {
        $this->setTermsCustomParams($options);
    }
}
?>