<?php
/**
 * Webfolio CMS
 *
 * Copyright (C) 2009 Nikola Posa (http://www.nikolaposa.in.rs)
 *
 * This file is part of Webfolio CMS.
 *
 * Webfolio CMS is free software: you can redistribute it and/or modify 
 * it under the terms of the GNU General Public License as published by 
 * the Free Software Foundation, either version 3 of the License, or 
 * (at your option) any later version.
 *
 * Webfolio CMS is distributed in the hope that it will be useful, but 
 * WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU 
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License 
 * along with Webfolio CMS. If not, see <http://www.gnu.org/licenses/>.
 */
 
/**
 * Form for adding/editing term.
 *
 * @author Nikola Posa <posa.nikola@gmail.com>
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License
 */
class Taxonomy_Form_Term extends Zend_Form
{
	/**
	 * Initializing form.
	 *
	 * @return Zend_Form
	 */
	public function __construct()
	{
		$elements = array();
		
		$name = new Zend_Form_Element_Text('name', array('required'=>true, 'disableLoadDefaultDecorators'=>true));
		$name->addFilters(array('StringTrim', new Zend_Filter_HtmlEntities(array('quotestyle'=>ENT_QUOTES, 'charset'=>'UTF-8'))));
		$elements[] = $name;
		
		if ($this->getView()->useParent == true) {
			$elements[] = new Zend_Form_Element_Select('parentId', array('registerInArrayValidator'=>false, 'required'=>false, 'disableLoadDefaultDecorators'=>true));
			
			$elements[] = new Zend_Form_Element_Hidden('currentParentId', array('disableLoadDefaultDecorators'=>true));
		}
		
		$elements[] = new Zend_Form_Element_Hidden('taxonomy', array('disableLoadDefaultDecorators'=>true));
		
		$elements[] = new Zend_Form_Element_Hidden('id', array('disableLoadDefaultDecorators'=>true));
		
		$this->setDisableLoadDefaultDecorators(true);
		$this->addElements($elements);
	}
	
	/**
	 * Defined by Zend_Form.
	 *
	 * Injecting custom pre-validation logic.
	 *
	 * @param array Submitted form data.
	 * @return bool
	 */
	public function isValid($data)
	{
		$dbHandler = Zend_Registry::get('dbHandler');
		$noRecordExists = new Zend_Validate_Db_NoRecordExists('wf_terms', 'name', 'taxonomy = ' . $dbHandler->quote($this->getView()->taxonomy) . ' AND id != ' . $dbHandler->quote($data['id'], Zend_Db::INT_TYPE), $dbHandler);
		$noRecordExists->setMessage(ucfirst($this->getView()->keyword) . ' with that name already exists.', Zend_Validate_Db_Abstract::ERROR_RECORD_FOUND);
		$this->getElement('name')->addValidator($noRecordExists);
		
		return parent::isValid($data);
	}
}
?>