<?php
/**
 * Webfolio CMS
 *
 * Copyright (C) 2009 Nikola Posa (http://www.nikolaposa.in.rs)
 *
 * This file is part of Webfolio CMS.
 *
 * Webfolio CMS is free software: you can redistribute it and/or modify 
 * it under the terms of the GNU General Public License as published by 
 * the Free Software Foundation, either version 3 of the License, or 
 * (at your option) any later version.
 *
 * Webfolio CMS is distributed in the hope that it will be useful, but 
 * WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU 
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License 
 * along with Webfolio CMS. If not, see <http://www.gnu.org/licenses/>.
 */
 
/**
 * ViewHelper that generates grid for managing terms of some 
 * taxonomy.
 *
 * @author Nikola Posa, www.nikolaposa.in.rs
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License
 */
class Zend_View_Helper_ManageTermsGrid extends Zend_View_Helper_Abstract
{
	/**
	 * Generates grid for managing terms of some taxonomy.
	 *
	 * @param string Taxonomy for which this grid will be rendered.
	 * @return string
	 */
	public function manageTermsGrid($taxonomy)
	{
        $config = array('taxonomy'=>$taxonomy, 'termsCustomParams'=>Zend_Controller_Action_HelperBroker::getStaticHelper('termsCustomParams')->getTermsParams());
        
		$this->view->headScript()->appendFile($this->view->baseUrl('libs/ExtJS/adapter/ext/ext-base.js'));
		$this->view->headScript()->appendFile($this->view->baseUrl('front-end/js/taxonomy/terms_grid.js?param=' . mt_rand())); //Passing random number to prevent caching.
        $this->view->headScript('SCRIPT',
        "
            Ext.onReady(function() {
                Ext.BLANK_IMAGE_URL = $('#base_url').val() + '/libs/ExtJS/resources/images/default/s.gif';

                Ext.QuickTips.init();

                var termsGrid = new WFTaxonomy.terms(" . Zend_Json_Encoder::encode($config) . ");
            });"
        );

        $editAllowed = (WebfolioCMS_Common::isUserAllowed(WebfolioCMS_Auth::getInstance()->getIdentity()->group_id, 'taxonomy_' . $taxonomy, 'edit')) ? '1' : '';
        $deleteAllowed = (WebfolioCMS_Common::isUserAllowed(WebfolioCMS_Auth::getInstance()->getIdentity()->group_id, 'taxonomy_' . $taxonomy, 'delete')) ? '1' : '';

		return '
            <div id="terms_grid"></div>

            <input type="hidden" id="edit_' . $taxonomy . '_permission" value="' . $editAllowed . '" />
            <input type="hidden" id="delete_' . $taxonomy . '_permission" value="' . $deleteAllowed . '" />
            ';
	}
}
?>