<?php
/**
 * Webfolio CMS
 *
 * Copyright (C) 2009 Nikola Posa (http://www.nikolaposa.in.rs)
 *
 * This file is part of Webfolio CMS.
 *
 * Webfolio CMS is free software: you can redistribute it and/or modify 
 * it under the terms of the GNU General Public License as published by 
 * the Free Software Foundation, either version 3 of the License, or 
 * (at your option) any later version.
 *
 * Webfolio CMS is distributed in the hope that it will be useful, but 
 * WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU 
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License 
 * along with Webfolio CMS. If not, see <http://www.gnu.org/licenses/>.
 */
 
/**
 * ViewHelper that generates form field for assigning term to 
 * some webfolio content, which already registered its 
 * taxonomy.
 *
 * @author Nikola Posa, www.nikolaposa.in.rs
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License
 */
class Zend_View_Helper_TermPicker extends Zend_View_Helper_Abstract
{
	/**
	 * Generates term picker.
	 *
	 * Supported params for $options:
	 *	taxonomy: Taxonomy for which this picker will be rendered - string (mandatory),
	 *	type: Picker type (comboBox or textField) - string (optional),
	 *	emptyOption: Whether to generate first, empty option, if "type" option is 'comboBox' - bool (optional, default: true),
	 *	addTermLink: Whether to render link for adding new term next to combo box - bool (optional, default: false),
	 *	addTermLinkLabel: Visible text of a add term link that will be rendered - string (optional)
	 *
	 * @param string Field name (this should always be null, as this param will be omitted).
	 * @param int|null Id of a content on which form this picker will be rendered (optional).
	 * @param array Options for rendering this picker.
	 * @return string
	 */
	public function termPicker($name = null, $value = null, $options)
	{	
		if (!isset($options['taxonomy'])) {
			throw new Exception ('Taxonomy name must be supplied in order to use taxonomy term picker.');
		}

		$taxonomy = $options['taxonomy'];
		$type = (isset($options['type'])) ? $options['type'] : 'comboBox';
		unset($options['taxonomy']);
		unset($options['type']);
		
		$taxonomyMain = new Taxonomy_Model_Main($taxonomy);
		$relatedTerms = $taxonomyMain->getTerms($value);
		
		$output = '';
		
		$currentTerms = '';
		
		if ($type == 'comboBox') { //Selector.
			$terms = array();
			$termsTree = $taxonomyMain->getTermsTree();
			
			if ($termsTree) {
				if (!isset($options['emptyOption']) || $options['emptyOption'] == true) {
					$terms[""] = 'Choose';
					unset($options['emptyOption']);
				}
				
				foreach ($termsTree as $term) {
					$terms[$term['id']] = str_repeat('-', (int)$term['depth']*2) . ' ' . $term['name'];
				}
			}
			else {
				$terms[""] = 'N/A';
			}
			
			if (isset($options['addTermLink']) && $options['addTermLink'] == true && WebfolioCMS_Common::isUserAllowed(WebfolioCMS_Auth::getInstance()->getIdentity()->group_id, 'taxonomy_' . $taxonomy, 'add')) {
				$linkLabel = isset($options['addTermLinkLabel']) ? $options['addTermLinkLabel'] : null;
				unset($options['addTermLink']);
				unset($options['addTermLinkLabel']);
		
				$output = $this->view->addTermLink($taxonomy, $linkLabel);
			}
			
			$term = current($relatedTerms); //This is select box, so there's only one related term.
			$currentTerms = $term['id'];
			
			//Utilizing formSelect view helper.
			$output = $this->view->formSelect('taxonomyData[' . $taxonomy . '][terms]', $term['id'], $options, $terms) . ' ' . $output;
		}
		elseif ($type == 'textField') { //Tags.
			$selectedTerms = array();
			
			foreach ($relatedTerms as $term) {
				$selectedTerms[] = $term['name'];
			}
			
			$selectedTermsString = implode(Taxonomy_Model_Main::MULTI_TERMS_SEPARATOR, $selectedTerms);
			$currentTerms = $selectedTermsString;

			$output .= '
				<input type = "text" name = "taxonomyData[' . $taxonomy . '][terms]" value = "' . $selectedTermsString . '">
				';
		}
		
		if ($output != '') {
			$output .= '
				<input type = "hidden" name = "taxonomyData[' . $taxonomy . '][current]" value = "' . $currentTerms . '">
			';
		}
		
		return $output;
	}
}
?>