<?php
/**
 * Webfolio CMS
 *
 * Copyright (C) 2009 Nikola Posa (http://www.nikolaposa.in.rs)
 *
 * This file is part of Webfolio CMS.
 *
 * Webfolio CMS is free software: you can redistribute it and/or modify 
 * it under the terms of the GNU General Public License as published by 
 * the Free Software Foundation, either version 3 of the License, or 
 * (at your option) any later version.
 *
 * Webfolio CMS is distributed in the hope that it will be useful, but 
 * WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU 
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License 
 * along with Webfolio CMS. If not, see <http://www.gnu.org/licenses/>.
 */
 
/**
 * ViewHelper that generates combo box with available terms 
 * in some taxonomy.
 *
 * @author Nikola Posa, www.nikolaposa.in.rs
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License
 */
class Zend_View_Helper_TermsComboBox
{
	/**
	 * Generates terms combo box.
	 *
	 * @param string Taxonomy for which this terms-picker will be rendered.
	 * @param int|null Id of a term that is currently selected (optional).
	 * @param int|null Id of a term that should be excluded, i.e. term that is currently being edited (int) (optional).
	 * @return string
	 */
	public function termsComboBox($taxonomy, $termId = null, $excludeId = null)
	{	
		$taxonomyMain = new Taxonomy_Model_Main($taxonomy);
		$terms = $taxonomyMain->getTermsTree();
		
		$firstOption = (!empty($terms)) ? 'Choose' : 'N/A';
		
		$output .= '
			<select name = "parentId">
				<option value = "">' . $firstOption . '</option>';
		
		foreach ($terms  as $term) {
			if ($excludeId == null || $excludeId != $term['id']) {
				$selected = ($termId != null && $termId == $term['id']) ? 'selected = "selected"' : '';
				$output .= '
				<option value = "' . $term['id'] . '" ' . $selected . '>' . str_repeat('-', (int)$term['depth']*2) . ' ' . $term['name'] . '</option>';
			}
		}
		
		$output .= '
			</select>';
		
		return $output;
	}
}
?>