<?php
/**
 * Webfolio CMS
 *
 * Copyright (C) 2009 Nikola Posa (http://www.nikolaposa.in.rs)
 *
 * This file is part of Webfolio CMS.
 *
 * Webfolio CMS is free software: you can redistribute it and/or modify 
 * it under the terms of the GNU General Public License as published by 
 * the Free Software Foundation, either version 3 of the License, or 
 * (at your option) any later version.
 *
 * Webfolio CMS is distributed in the hope that it will be useful, but 
 * WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU 
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License 
 * along with Webfolio CMS. If not, see <http://www.gnu.org/licenses/>.
 */
 
/**
 * View helper which renders content that can be registerd by 
 * additional modules, at defined placeholders (before and 
 * after content of some site page).
 *
 * @author Nikola Posa <posa.nikola@gmail.com>
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License
 */
class Zend_View_Helper_ContentPlugin extends Zend_View_Helper_Abstract 
{
	protected $knownPlugins = array('WFComments');
	
	/**
	 * Renders selected content plugins.
	 *
	 * @param string Type of a plugin (pre or post).
	 * @return string
	 */
	public function contentPlugin($type)
	{
		$selectedPlugins = Model_WebfolioSettings::getSettings('content_plugins');
		$plugins = $selectedPlugins[$type];
		
		$output = '';
		
		if (Zend_Registry::isRegistered(WebfolioCMS_Controller_Action_Helper_WFEntryFinder::CURRENT_WF_ENTRY_KEY) && !empty($plugins)) {
			$key = Zend_Registry::get(WebfolioCMS_Controller_Action_Helper_WFEntryFinder::CURRENT_WF_ENTRY_KEY);
			$currentEntry = $this->view->$key;
			
			foreach ($plugins as $plugin) {
				if (($plugin['module'] == 'default' || WebfolioCMS_Common::isModuleActive($plugin['module'])) && (in_array($plugin['helperName'], $this->knownPlugins) || $this->checkSelections($currentEntry, $plugin))) {
					$this->_preparePaths($plugin);
					
					$methodName = $plugin['helperName'];
						
					$helper = $this->view->getHelper($methodName);
					
					if ($helper instanceof WebfolioCMS_View_Helper_ContentPlugin_Abstract) {
						$helper->setType($type);
						
						$helperOutput = $helper->$methodName()->render($currentEntry);
						
						if ($helperOutput != '') {
							$output .= $this->_prepareHelperOutput($plugin, $helperOutput);
						}
					}
				}
			}
		}
		
		return $output;
	}
	
	/**
	 * Checks whether plugin should be rendered, based on user 
	 * selection between plugins and content on his/her site 
	 * (pages, items, etc.).
	 *
	 * @param mixed Entry that is currently being outputted.
	 * @param array Content plugin.
	 * @return bool
	 */
	private function checkSelections($currentEntry, $plugin)
	{
		$selections = $plugin['settings']['selections'];
		
		if (array_key_exists($currentEntry['type'], $selections) && in_array($currentEntry['id'], $selections[$currentEntry['type']])) {	
			return true;
		}
		else {
			return false;
		}
	}

    /**
     * Adding path to view resources (scripts, helpers) of the
     * content plugin's module.
     *
     * @param array Content plugin.
     * @return void
     */
    private function _preparePaths($plugin)
    {
        $this->view->addScriptPath(APPLICATION_PATH . '/views/parts'); //Some partial scripts of default module can be stored in that folder.

        if ($plugin['module'] != 'default') {
            $path = APPLICATION_PATH . '/modules/' . $plugin['module'] . '/views';
            $this->view->addBasePath($path);

            $this->view->addScriptPath($path . '/parts');
        }

        //Adding path to themes folder at the top of the script paths stack,
        //so some redefined script in active theme folder can be used instead
        //of default partial script of some content plugin.
        $this->view->addScriptPath(BASE_PATH . '/front-end/themes/' . Model_WebfolioSettings::getSettings('theme_dir'));
    }

    /**
     * Wrapping output of some content plugin, based on their
     * "topSeparator" and "float" appearance settings.
     *
     * @param array Content plugin.
     * @param string $output Output of some content plugin.
     * @return string
     */
    protected function _prepareHelperOutput($plugin, $output)
    {
        if ($plugin['settings']['float'] && $plugin['settings']['float'] != 'none') {
            $output =  '
            <div style="float: ' . $plugin['settings']['float'] . '">
                ' . $output . '
            </div>';
        }

        if ((bool)$plugin['settings']['topSeparator'] == true) {
            $output = '
            <div class = "plugin_separator" style="clear: both;"></div>
                ' . $output;
        }

        return $output . '
            <div style="clear: both;"></div>';
    }
}
?>