<?php
/**
 * Webfolio CMS
 *
 * Copyright (C) 2009 Nikola Posa (http://www.nikolaposa.in.rs)
 *
 * This file is part of Webfolio CMS.
 *
 * Webfolio CMS is free software: you can redistribute it and/or modify 
 * it under the terms of the GNU General Public License as published by 
 * the Free Software Foundation, either version 3 of the License, or 
 * (at your option) any later version.
 *
 * Webfolio CMS is distributed in the hope that it will be useful, but 
 * WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU 
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License 
 * along with Webfolio CMS. If not, see <http://www.gnu.org/licenses/>.
 */
 
/**
 * ViewHelper that fetches and then displays comments in one 
 * webfolio entry, using partial view script, that is placed
 * in folder of active theme.
 *
 * @author Nikola Posa, www.nikolaposa.in.rs
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License
 */
class Zend_View_Helper_WFComments extends WebfolioCMS_View_Helper_ContentPlugin_Abstract
{
	/**
	 * Initializing view helper.
	 *
	 * @return Zend_View_Helper_Abstract
	 */
	public function WFComments() 
	{
		return $this;
	}
	
	/**
	 * Defined by WebfolioCMS_View_Helper_ContentPlugin_Abstract. 
	 * Displays comments in one webfolio entry.
	 *
	 * @param mixed Content that is currently being outputted.
	 * @return string
	 */
	public function render($content)
	{
		$output = '';
		
		if ($this->hasThemeViewScript('comments.phtml') && $content['use_comments'] == 1) { //Only if there's appropriate view script in active theme's folder and if we're on some webfolio entry (i.e. item) page and comments are allowed for that entry.
			$WFEntryId = $content['id'];
			
			$webfolioComments = new Model_WebfolioComments();
			$where = $webfolioComments->getMapper()->getDbTable()->getAdapter()->quoteInto('status = \'approved\' AND wf_entry_id = ?', $WFEntryId, Zend_DB::INT_TYPE);
			
			$comments = null;
			
			$commentsCountPerPage = (int)Model_WebfolioSettings::getSettings('comments_count_per_page');
			
			if ($commentsCountPerPage > 0) { //User decided to use pagination of comments?
				$comments = new Zend_Paginator(new WebfolioCMS_Paginator_Adapter_Model($webfolioComments, array('where'=>$where, 'order'=>'datetime DESC')));
				$comments->setItemCountPerPage($commentsCountPerPage);
			}
			else {
				$comments = $webfolioComments->fetchAll($where, 'datetime ASC');
			}

			$commentAuthor = new Zend_Session_Namespace('commentAuthor');
			if (WebfolioCMS_Common::isUserLoggedIn() && $commentAuthor->name != WebfolioCMS_Auth::getInstance()->getIdentity()->public_name) {
                $webfolioUsers = new Model_WebfolioUsers();
                $user = $webfolioUsers->getOneWithMetaGroup(array(Model_DbTable_WebfolioUsers::USERS_TABLE_ALIAS . '.id = ?'=>WebfolioCMS_Auth::getInstance()->getIdentity()->id));

                $commentAuthor->name = $user->publicName;
                $commentAuthor->email = $user->email;
                $commentAuthor->url = (isset($user->meta) && $user->meta->website) ? $user->meta->website : '';
            }
            
			$commentsData = array(
				'comments' 	  => $comments, 
				'WFEntryId'	  => $WFEntryId,
				'authorName'  => ($commentAuthor->name) ? $commentAuthor->name : '',
				'authorEmail' => ($commentAuthor->email) ? $commentAuthor->email : '',
				'authorUrl'	  => ($commentAuthor->url) ? $commentAuthor->url : ''
			);
			
			$output = $this->view->partial('comments.phtml', null, $commentsData);
		}
		
		return $output;
	}
	
	/**
	 * Renders text of some comment, and also parses smiley signs 
	 * that may occur.
	 *
	 * @param Model_WebfolioComments User comment data.
	 * @return string
	 */
	public function renderCommentText($text)
	{
		$smileysParser = new Model_ContentParser_Smileys();
		
		return $smileysParser->parse($text);
	}
	
	/**
	 * Renders name of some comment's author, in form of link or 
	 * just plain text, based on whether author supplied his/her 
	 * URL when posting comment.
	 *
	 * @param Model_WebfolioComments User comment data.
	 * @return string
	 */
	public function renderAuthorsInfo(Model_WebfolioComments $comment)
	{
		return (strlen($comment->authorUrl) > 0) ? '<a href = "' . $comment->authorUrl . '" rel="nofollow"><b> ' . $comment->authorName . '</b></a>' : '<b>' . $comment->authorName . '</b>';
	}
	
	/**
	 * Renders datetime when some comments was posted.
	 *
	 * @param Model_WebfolioComments User comment data.
	 * @return string
	 */
	public function renderCommentsDateTime(Model_WebfolioComments $comment)
	{
		return $this->view->dateTime($comment->datetime, 'date') . ' ' . $this->view->dateTime($comment->datetime, 'time');
	}
}
?>