<?php
/**
 * Webfolio CMS
 *
 * Copyright (C) 2009 Nikola Posa (http://www.nikolaposa.in.rs)
 *
 * This file is part of Webfolio CMS.
 *
 * Webfolio CMS is free software: you can redistribute it and/or modify 
 * it under the terms of the GNU General Public License as published by 
 * the Free Software Foundation, either version 3 of the License, or 
 * (at your option) any later version.
 *
 * Webfolio CMS is distributed in the hope that it will be useful, but 
 * WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU 
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License 
 * along with Webfolio CMS. If not, see <http://www.gnu.org/licenses/>.
 */
 
/**
 * ViewHelper which renders posting date of some webfolio 
 * entry, below its title.
 *
 * @author Nikola Posa, www.nikolaposa.in.rs
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License
 */
class Zend_View_Helper_WFEntryDate extends WebfolioCMS_View_Helper_ContentPlugin_Abstract
{
	/**
	 * Initializing view helper.
	 *
	 * @return Zend_View_Helper_Abstract
	 */
	public function WFEntryDate() 
	{
		return $this;
	}
	
	/**
	 * Renders webfolio entry's posting date.
	 *
	 * @return string
	 */
	public function render()
	{
		$output = '';
		
		if (isset($this->view->webfolioItem) || ($entry = $this->getAssignedEntry()) != null) { //Has appropriate view script and we're on appopriate site page?
			$WFEntry = isset($this->view->webfolioItem) ? $this->view->webfolioItem : $entry;
			
			$output .= '<div class="entry-date">' . date(Model_WebfolioSettings::getSettings('date_format'), strtotime($WFEntry['date'])) . '</div>';
		}
		
		return $output;
	}
	
	/**
	 * Checks whether there is some variable of type Webfolio_Entry 
	 * assigned to view, probably by some additional module, which 
	 * uses public layout.
	 *
	 * @return Model_WebfolioEntries|null
	 */
	protected function getAssignedEntry()
	{
		foreach ($this->view->getVars() as $variable) {
			if ($variable instanceof Model_WebfolioEntries) { //Found some webfolio entry?
				return $variable;
			}
		}
		
		return null;
	}
}
?>