<?php
/**
 * Webfolio CMS
 *
 * Copyright (C) 2009 Nikola Posa (http://www.nikolaposa.in.rs)
 *
 * This file is part of Webfolio CMS.
 *
 * Webfolio CMS is free software: you can redistribute it and/or modify 
 * it under the terms of the GNU General Public License as published by 
 * the Free Software Foundation, either version 3 of the License, or 
 * (at your option) any later version.
 *
 * Webfolio CMS is distributed in the hope that it will be useful, but 
 * WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU 
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License 
 * along with Webfolio CMS. If not, see <http://www.gnu.org/licenses/>.
 */
 
/**
 * ViewHelper for generating head section of default module 
 * pages.
 *
 * @author Nikola Posa, www.nikolaposa.in.rs
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License
 */
class Zend_View_Helper_WFHeadSection extends WebfolioCMS_View_Helper_HeadSectionAbstract 
{
	protected $_allowedModulesFrontEndResources = array('css', 'js');
	
	/**
	 * Adding head section elements of public pages, based on 
	 * action controller.
	 *
	 * @return WebfolioCMS_View_Helper_HeadSectionAbstract
	 */
	public function WFHeadSection() 
	{
		$this->setAppendContentType(true);
		
		//Common values.
		$this->addTitle(Model_WebfolioSettings::getSettings('site_title'), 'PREPEND'); //Getting site name that will be prepended to the title in the head section.
		$this->addCss(
			array(
				$this->view->baseUrl('front-end/css/common.css'),
				$this->view->baseUrl('front-end/themes/' . Model_WebfolioSettings::getSettings('theme_dir') . '/style.css'), 
				$this->view->baseUrl('libs/shadowbox/shadowbox.css')
			),
			WebfolioCMS_View_Helper_HeadSectionAbstract::FILE,
			'PREPEND'
		);
		$this->addJs(
			array(
				$this->view->baseUrl('libs/jQuery/jquery.js'), 
				$this->view->baseUrl('libs/jQuery/plugins/jquery.json.js'),
				$this->view->baseUrl('libs/jQuery/plugins/jquery.form.js'),
				$this->view->baseUrl('front-end/js/comments.js'),
				$this->view->baseUrl('libs/shadowbox/shadowbox.js')
			), 
			WebfolioCMS_View_Helper_HeadSectionAbstract::FILE,
			'PREPEND'
		);
        $this->addJs(
            '$(document).ready( function() {
                Shadowbox.init();
            });'
        , 'SCRIPT');
		$this->view->headScript('FILE', $this->view->baseUrl('libs/jQuery/plugins/pngFix/jquery.pngFix.js'), 'APPEND', array('conditional'=>'IE'));
		$this->view->headScript('FILE', $this->view->baseUrl('front-end/js/png_fix.js'), 'APPEND', array('conditional'=>'IE'));
		
		if ((bool)Model_WebfolioSettings::getSettings('enable_rss_wf_items')) {
			$title = html_entity_decode(Model_WebfolioSettings::getSettings('site_title'), ENT_COMPAT, 'UTF-8') . ' - webfolio';
			$this->view->headLink()->appendAlternate($this->view->url(array('format'=>'rss'), 'wf_feed', true), 'application/rss+xml', $title);
			$this->view->headLink()->appendAlternate($this->view->url(array('format'=>'atom'), 'wf_feed', true), 'application/atom+xml', $title);
		}
		
		if ($this->module == 'default') {
			$this->addTitle(' | ' . strip_tags($this->view->WFTitle(' | ')));
		}
		
		$this->appendModulesData();
		
		return $this;
	}
	
	/**
	 * Appends front-end data (css, js) of each active module, 
	 * to existing head section data. 
	 * 
	 * @return void
	 */
	protected function appendModulesData()
	{
		foreach ($this->_allowedModulesFrontEndResources as $dir) {
			foreach (Model_WebfolioSettings::getSettings('active_modules') as $module) {
				$path = '/front-end/' . $dir . '/' . $module;
	
				if (is_dir(BASE_PATH . $path)) {
					$files = scandir(BASE_PATH . $path);
		
					if ($files !== false) {	
						foreach ($files as $file) {
							if ($file != '..' && $file != '.' && substr($file, 0, 7) == 'public_') { //Public resource (public prefix)?
								$method = 'add' . ucfirst($dir);
								$this->$method($this->view->baseUrl($path . '/' . $file));
							}	
						}
					}
				}
			}		
		}
	}
}
?>