<?php
/**
 * Webfolio CMS
 *
 * Copyright (C) 2009 Nikola Posa (http://www.nikolaposa.in.rs)
 *
 * This file is part of Webfolio CMS.
 *
 * Webfolio CMS is free software: you can redistribute it and/or modify 
 * it under the terms of the GNU General Public License as published by 
 * the Free Software Foundation, either version 3 of the License, or 
 * (at your option) any later version.
 *
 * Webfolio CMS is distributed in the hope that it will be useful, but 
 * WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU 
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License 
 * along with Webfolio CMS. If not, see <http://www.gnu.org/licenses/>.
 */
 
/**
 * ViewHelper for generating sidebar items.
 *
 * @author Nikola Posa, www.nikolaposa.in.rs
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License
 */
class Zend_View_Helper_WFSidebar extends Zend_View_Helper_Abstract 
{
	const SIDEBAR_BLOCK_PARTIAL = 'sidebar_block.phtml';
	
	/**
	 * Sidebar items scheme.
	 *
	 * @var array
	 */
	protected $_sidebarItems;
	
	/**
	 * Generates user's sidebar selection. 
	 *
	 * @param array Used for picking which sidebar items will be rendered. This array should contain of arrays with "module" and "helperName" keys.
	 * @return string
	 */
	public function WFSidebar(array $selection = array()) 
	{
		$sidebarItems = $this->getSidebarItems();
		
		$output = '';
		
		$activeThemePath = BASE_PATH . '/front-end/themes/' . Model_WebfolioSettings::getSettings('theme_dir');
		
		if (!empty($sidebarItems) && file_exists($activeThemePath . '/' . self::SIDEBAR_BLOCK_PARTIAL)) { //Only if active theme support sidebar blocks, and has some view script for that purpose.
			$model = array(); //Data that will be assigned to partial script for rendering sidebar blocks.
			
			foreach ($sidebarItems as $sidebarItem) {
				if (empty($selection) || in_array(array('module'=>$sidebarItem['module'], 'helperName'=>$sidebarItem['helperName']), $selection)) {
					if ($sidebarItem['module'] == 'default' || WebfolioCMS_Common::isModuleActive($sidebarItem['module'])) {
						if ($sidebarItem['module'] != 'default') { //If module is not default, we need to add path to its view helpers.
							$this->view->addBasePath(APPLICATION_PATH . '/modules/' . $sidebarItem['module'] . '/views');
						}
						
						$helperName = $sidebarItem['helperName'];
						$helper = $this->view->getHelper($helperName);
						
						$r = new ReflectionClass($helper);
						if ($r->implementsInterface('WebfolioCMS_View_Helper_WFSidebar_Interface')) {
							$itemTitle = '';
							$body = '';
							
							if (strlen($sidebarItem['title']) > 0) {
								$itemTitle = $this->view->translate($sidebarItem['title']);
							}
						

                            //Has some specific settings, which were set on panel for managing sidebar in admin panel?
                            $settigs = (array_key_exists('settings', $sidebarItem)) ? $sidebarItem['settings'] : null;
                            //Getting actual content.
                            $body = $helper->$helperName()->sidebarRender($settigs);
							
							$model[] = array('title'=>$itemTitle, 'body'=>$body);
						}
					}
				}
			}
			
			$this->view->addScriptPath($activeThemePath);
			$output = $this->view->partialLoop(self::SIDEBAR_BLOCK_PARTIAL, $model);
		}
		
		return $output;
	}
	
	/**
	 * Gets sidebar items scheme.
	 *
	 * @return array
	 */
	public function getSidebarItems()
	{
		if ($this->_sidebarItems === null) {
			$this->_sidebarItems = Model_WebfolioSettings::getSettings('sidebar_items');
		}
		
		return $this->_sidebarItems;
	}
}
?>