<?php
/**
 * Webfolio CMS
 *
 * Copyright (C) 2009 Nikola Posa (http://www.nikolaposa.in.rs)
 *
 * This file is part of Webfolio CMS.
 *
 * Webfolio CMS is free software: you can redistribute it and/or modify 
 * it under the terms of the GNU General Public License as published by 
 * the Free Software Foundation, either version 3 of the License, or 
 * (at your option) any later version.
 *
 * Webfolio CMS is distributed in the hope that it will be useful, but 
 * WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU 
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License 
 * along with Webfolio CMS. If not, see <http://www.gnu.org/licenses/>.
 */
 
/**
 * ViewHelper for generating sidebar menu.
 *
 * @author Nikola Posa, www.nikolaposa.in.rs
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License
 */
class Zend_View_Helper_WFSidebarMenu extends Zend_View_Helper_Abstract implements WebfolioCMS_View_Helper_WFSidebar_Interface
{
    const WRAPPER_ID = 'sidebar_menu';

	/**
	 * Initializing view helper.
	 *
	 * @return Zend_View_Helper_WFSidebarMenu
	 */
	public function WFSidebarMenu() 
	{
		return $this;
	}
	
	/**
	 * Defined by WebfolioCMS_View_Helper_WFSidebar_Interface.
	 *
     * @param array $settings Settings for rendering (optional).
	 * @return string
	 */
	public function sidebarRender($settings = null)
	{
        $output = $this->view->WFMenu()->sidebar();

        $settings = (array)$settings;
        if (!empty($settings) && (bool)$settings['make_collapsible'] == true) {
            unset($settings['make_collapsible']);

            $output = '<div id="' . self::WRAPPER_ID . '">
                ' . $output . '
                </div>

                ' . $this->_renderJS($settings);
        }
        
		return $output;
	}

    /**
     * Renders necessary JS code for making sidebar menu items
     * collapsible.
     *
     * @param array $settings Settings for this widget.
     * @return string
     */
    protected function _renderJS($settings)
    {
        $output = '<script type="text/javascript" src="' .  $this->view->baseUrl('front-end/js/jquery.collapsibleMenu.js') . '"></script>';

        $options = array();

        $s2cc = new Zend_Filter_Word_SeparatorToCamelCase('_');
        foreach ($settings as $key=>$value) {
            $option = $s2cc->filter($key);
            $option{0} = chr((ord($option{0}) + 32)); //lcfirst()
            $options[$option] = $value;
        }

        $output .= sprintf('
            <script type="text/javascript">
                //<![CDATA[
                    $.fn.collapsibleMenu.defaults.eventType = "click";
                    $("#' . self::WRAPPER_ID . ' ul").collapsibleMenu(%s);
                //]]>
            </script>',
            Zend_Json_Encoder::encode($options)
        );

        return $output;
    }
}
?>