<?php
/**
 * Webfolio CMS
 *
 * Copyright (C) 2009 Nikola Posa (http://www.nikolaposa.in.rs)
 *
 * This file is part of Webfolio CMS.
 *
 * Webfolio CMS is free software: you can redistribute it and/or modify 
 * it under the terms of the GNU General Public License as published by 
 * the Free Software Foundation, either version 3 of the License, or 
 * (at your option) any later version.
 *
 * Webfolio CMS is distributed in the hope that it will be useful, but 
 * WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU 
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License 
 * along with Webfolio CMS. If not, see <http://www.gnu.org/licenses/>.
 */
 
/**
 * ViewHelper for generating page title in Webfolio CMS 
 * default module.
 *
 * @author Nikola Posa, www.nikolaposa.in.rs
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License
 */
class Zend_View_Helper_WFTitle extends Zend_View_Helper_Abstract
{
	const DEFAULT_SEPARATOR = ' / ';
	
	/**
	 * Breadcrumb title of current page/item that is being viewed.
	 *
	 * @return string
	 */
	protected $title = null;
	
	/**
	 * Sting that is currently being used as a separator.
	 *
	 * @return string
	 */
	protected $separator;
	
	/**
	 * Generates page title by utilizing breadcrumbs navigation 
	 * helper.
	 *
	 * @return string
	 */
	public function WFTitle($separator = self::DEFAULT_SEPARATOR) 
	{
		if ($this->title == null) {
			$this->title = $this->view->navigation()->breadcrumbs()->setSeparator($separator)->setMinDepth(0)->setUseTranslator(false)->render();
		}
		elseif ($this->separator != $separator) {
			$this->title = preg_replace('/(>)' . preg_quote($this->separator, '/') . '(<)?/', '\1' . $separator . '\2', $this->title); //Changing separator.
		}
		
		$this->separator = $separator;
		
		return $this->title;
	}
}
?>