<?php
/**
 * Webfolio CMS
 *
 * Copyright (C) 2009 Nikola Posa (http://www.nikolaposa.in.rs)
 *
 * This file is part of Webfolio CMS.
 *
 * Webfolio CMS is free software: you can redistribute it and/or modify 
 * it under the terms of the GNU General Public License as published by 
 * the Free Software Foundation, either version 3 of the License, or 
 * (at your option) any later version.
 *
 * Webfolio CMS is distributed in the hope that it will be useful, but 
 * WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU 
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License 
 * along with Webfolio CMS. If not, see <http://www.gnu.org/licenses/>.
 */
 
/**
 * Script for handling AJAX requests for executing some 
 * comments-like actions (approve, unapprove, markAsSpam, 
 * notSpam, deleteAllSpam).
 *
 * @author Nikola Posa <posa.nikola@gmail.com>
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License
 */
include_once('../../../wf_init.php');

require_once('Zend/Application.php');

//Bootstrapping...
$application = new Zend_Application(APPLICATION_ENV, include APPLICATION_PATH . '/configs/wf_config.php');
$application->getBootstrap()->bootstrap(array('Autoloaders', 'DB', 'Cachemanager'));

if (!WebfolioCMS_Common::isUserLoggedIn()) {
	echo 'error';
	exit;
}

//Getting data sent from AJAX.
$action = $_POST['action'];
if ((ord($action{0}) <= 90)) {
	$action{0} = chr((ord($action{0}) + 32)); //lcfirst()
}
$ids = $_POST['id'];

if (
    (in_array($action, array('approve', 'unapprove', 'markAsSpam', 'notSpam')) && !WebfolioCMS_Common::isUserAllowed(WebfolioCMS_Auth::getInstance()->getIdentity()->group_id, 'admin_comments', 'manage'))
    || ($action == 'deleteAllSpam' && !WebfolioCMS_Common::isUserAllowed(WebfolioCMS_Auth::getInstance()->getIdentity()->group_id, 'admin_comments', 'delete'))
) {
    echo 'error';
	exit;
}

$status = '';
switch($action) {
	case 'approve':
	{
		$status = 'approved';
		
		break;
	}
	case 'unapprove':
	{
		$status = 'ready';
		
		break;
	}
	case 'markAsSpam':
	{
		$status = 'spam';
		
		break;
	}
	case 'notSpam':
	{
		if (Model_WebfolioSettings::getSettings('admin_moderate_comment') == true) {
			$status = 'awaiting';
		}
		else {
			$status = 'approved';
		}
		
		break;
	}
	case 'deleteAllSpam':
	{
		$webfolioComments = new Model_DbTable_WebfolioComments();
		$webfolioComments->delete('status = \'spam\'');
		
		echo 'ok';
		exit;
		
		break;
	}
}
		
try {
	if (($ids{0} == '{' || $ids{0} == '[') && ($ids{strlen($ids)-1} == '}' || $ids{strlen($ids)-1} == ']')) { //JSON?
		$ids = Zend_Json_Decoder::decode($ids);
	}

	if (!is_array($ids)) {
		$ids = array($ids);
	}

	$webfolioComments = new Model_DbTable_WebfolioComments();

	$data = array('status'=>$status);
	
	//Updating comment's status.
	foreach ($ids as $id) {
		$where = $webfolioComments->getAdapter()->quoteInto('id = ?', $id, Zend_DB::INT_TYPE);
		
		$rowsAffected = $webfolioComments->update($data, $where);
	
		if ($rowsAffected == 0) { //No affected rows?
			echo 'Selected comments are already approved.';
			exit;
		}
	}
	
	echo 'ok';
}
catch (Exception $ex) {
	echo 'An error occured. Please try later.'; //$ex->getMessage()
}
?>