<?php
/**
 * Webfolio CMS
 *
 * Copyright (C) 2009 Nikola Posa (http://www.nikolaposa.in.rs)
 *
 * This file is part of Webfolio CMS.
 *
 * Webfolio CMS is free software: you can redistribute it and/or modify 
 * it under the terms of the GNU General Public License as published by 
 * the Free Software Foundation, either version 3 of the License, or 
 * (at your option) any later version.
 *
 * Webfolio CMS is distributed in the hope that it will be useful, but 
 * WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU 
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License 
 * along with Webfolio CMS. If not, see <http://www.gnu.org/licenses/>.
 */
 
/**
 * Script for handling AJAX requests for fetching data that
 * will be outputed in panel for managing sidebar.
 *
 * @author Nikola Posa <posa.nikola@gmail.com>
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License
 */
include_once('../../../wf_init.php');

require_once('Zend/Application.php');

//Bootstrapping...
$application = new Zend_Application(APPLICATION_ENV, include APPLICATION_PATH . '/configs/wf_config.php');
$application->getBootstrap()->bootstrap(array('Autoloaders', 'DB', 'Hooks', 'Modules', 'Cachemanager'));

if (!WebfolioCMS_Common::isUserLoggedIn()) {
	echo 'error';
	exit;
}

$action = $_POST['action'];

if (($action == 'get' && !WebfolioCMS_Common::isUserAllowed(WebfolioCMS_Auth::getInstance()->getIdentity()->group_id, 'admin_appearance', 'content-plugins'))
    || (in_array($action, array('settings', 'save')) && !WebfolioCMS_Common::isUserAllowed(WebfolioCMS_Auth::getInstance()->getIdentity()->group_id, 'admin_appearance_content-plugins', 'manage'))
   ) {
    echo 'error';
    exit;
}

try {
	if ($action == 'get') {
		$type = $_POST['type'] . 'Content';
		
		$place = $_POST['place'];
		
		$selectedPlugins = Model_WebfolioSettings::getSettings('content_plugins');
		
		$contentPlugins = array();
		
		if ($place == 'optional') {
			$plugins = Model_ContentPlugins::get($type);
			
			foreach ($plugins as $key=>$plugin) {
				foreach ($selectedPlugins[$type] as $sPlugin) {
					if ($plugin['helperName'] == $sPlugin['helperName'] && $plugin['module'] == $sPlugin['module']) {
						unset($plugins[$key]);
					}
				}
			}
			
			$contentPlugins = $plugins;
			sort($contentPlugins);
		}
		elseif ($place == 'selected') {
			foreach ($selectedPlugins[$type] as $key=>$plugin) {
				if ($plugin['module'] == 'default' || ($plugin['module'] != 'default' && WebfolioCMS_Common::isModuleActive($plugin['module']))) { //Module of selected plugin is not active?
					$contentPlugins[] = $plugin;
				}
			}
		}
		
		echo Zend_Json_Encoder::encode(array('plugins'=>$contentPlugins)); //Outputting to ExtJS grid.
	}
	elseif ($action == 'settings') { //Outputting content selection list and appearance settings, so user can pick on which pages some plugin will be rendered.
		$settings = Zend_Json_Decoder::decode($_POST['settings']);
		$currentSelection = $settings['selections'];
		
		$output = '';
		
		if ($currentSelection !== null) {
			$output .= '<h2>Content selection</h2>';
			
			$webfolioEntries = new Model_DbTable_WebfolioEntries();
			
			$allEntries = $webfolioEntries->getTree();
			
			$currentType = '';
			foreach ($allEntries as $entry) {
				$type = $entry['type'];
				if (
					(!array_key_exists('ctPick', $settings) && !array_key_exists('ctOmit', $settings))
					|| (array_key_exists('ctPick', $settings) && in_array($type, $settings['ctPick'])) || (array_key_exists('ctOmit', $settings) && !in_array($type, $settings['ctOmit']))
				) {
					if ($type != $currentType) {
						$output .=  '
						<h3 style = "margin-top: 20px; margin-bottom: 0px;"><input type = "checkbox" id = "' . $type . '_all" style = "margin-right: 3px;" onclick = "if ($(this).is(\':checked\')) { $(\'.' . $type . '\').attr(\'checked\', \'checked\'); } else { $(\'.' . $type . '\').removeAttr(\'checked\'); }" /> Content type: <b>' . $type . '</b></h3>
						';
						
						$currentType = $type;
					}
					
					$checked = '';
					if (array_key_exists($type, $currentSelection) && in_array($entry['id'], $currentSelection[$type])) {
						$checked = ' checked = "checked"';
					}
						
					$indent = (int)$entry['depth'] * 10;
						
					$output .= '
						<input type = "checkbox" name = "selections_' . $type . '" value = "' . $entry['id'] . '"' . $checked . ' class = "' . $type . '" onclick = "if ($(\'#' . $type . '_all\').is(\':checked\')) { $(\'#' . $type . '_all\').removeAttr(\'checked\'); } " /> 
						<span style = "margin-left: ' . $indent . 'px">' . $entry['title'] . '</span> <br />';
				}
			}
		}
        
		$output .= '<h2>Appearance</h2>
		
		<p>Display top separator line: <input type = "checkbox" name = "topSeparator"' . (((bool)$settings['topSeparator'] == true) ? ' checked = "checked"' : '') . ' value = "1" /></p>

        <p>
            <label>Float: </label>
            <select name="float" id="float">
                <option value="none"' . (($settings['float'] == 'none') ? ' selected = "selected"' : '') . '>None</option>
                <option value="left"' . (($settings['float'] == 'left') ? ' selected = "selected"' : '') . '>Left</option>
                <option value="right"' . (($settings['float'] == 'right') ? ' selected = "selected"' : '') . '>Right</option>
            </select>
        </p>';
		
		echo '<div style = "width: 286px; height: 370px; overflow: auto; padding: 7px;">' . $output . '</div>';
	}
	elseif ($action == 'save') {
		$data = Zend_Json_Decoder::decode($_POST['data']);
		
		Model_WebfolioSettings::updateSetting('content_plugins', $data);
		
		echo 'ok';
	}
}
catch (Exception $ex) {
	echo $ex->getMessage();
}
?>