<?php
/**
 * Webfolio CMS
 *
 * Copyright (C) 2009 Nikola Posa (http://www.nikolaposa.in.rs)
 *
 * This file is part of Webfolio CMS.
 *
 * Webfolio CMS is free software: you can redistribute it and/or modify 
 * it under the terms of the GNU General Public License as published by 
 * the Free Software Foundation, either version 3 of the License, or 
 * (at your option) any later version.
 *
 * Webfolio CMS is distributed in the hope that it will be useful, but 
 * WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU 
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License 
 * along with Webfolio CMS. If not, see <http://www.gnu.org/licenses/>.
 */
 
/**
 * Script for handling AJAX requests for deleting some db
 * entry (webfolio entry, comment, user, group, etc.).
 *
 * @author Nikola Posa <posa.nikola@gmail.com>
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License
 */
include_once('../../../wf_init.php');

require_once('Zend/Application.php');

//Bootstrapping...
$application = new Zend_Application(APPLICATION_ENV, include APPLICATION_PATH . '/configs/wf_config.php');
$application->getBootstrap()->bootstrap(array('Autoloaders', 'DB', 'Modules', 'Cachemanager'));

if (!WebfolioCMS_Common::isUserLoggedIn()) {
	echo 'error';
	exit;
}

//Getting data sent from AJAX.
$action = $_POST['action'];
$ids 	= $_POST['id'];
if ($_POST['module']) { //Some additional module is using this ajax handler?
    $resource = $_POST['module'] . '_admin';
}
else {
    $resource = ($action{(strlen($action)-1)} != 's') ? 'admin_' . $action . 's' : 'admin_' . $action;
}

if (!WebfolioCMS_Common::isUserAllowed(WebfolioCMS_Auth::getInstance()->getIdentity()->group_id, $resource, 'delete')) {
    echo 'error';
	exit;
}
		
try {
	if (($ids{0} == '{' || $ids{0} == '[') && ($ids{strlen($ids)-1} == '}' || $ids{strlen($ids)-1} == ']')) { //JSON?
		$ids = Zend_Json_Decoder::decode($ids);
	}

	if (!is_array($ids)) {
		$ids = array($ids);
	}

	if (in_array($action, array('comment', 'user', 'group')) && class_exists($className = 'Model_DbTable_Webfolio' . ucfirst($action) . 's')) { //Deleting some comment/user/group?
		if ($action == 'group' && array_intersect(array_keys(Model_DbTable_WebfolioGroups::getReadOnlyGroups()), $ids)) { //Checking whether some read-only groups are trying to be deleted.
            echo 'Read-only groups can\'t be deleted.';
            exit;
        }

        $dbTableModel = new $className();
		
		foreach ($ids as $id) {
			$where = $dbTableModel->getAdapter()->quoteInto('id = ?', $id, Zend_DB::INT_TYPE);
			$rowsAffected = $dbTableModel->delete($where);
	
			if ($rowsAffected == 0) { //No affected rows?
				echo 'Unexisting ' . $action . ' supplied.';
				exit;
			}

            //Deleting related db entries.
            foreach ($dbTableModel->getDependentTables() as $tableClass) {
                $t = new $tableClass();

                $t->_cascadeDelete($className, array('id'=>$id));
            }
		}
		
		if ($action == 'group') {
			Zend_Registry::get('CacheManager')->getCache('default')->remove(WebfolioCMS_Acl::CACHE_ID);
		}
    }
	else { //Probably some webfolio entry...
		$webfolioEntries = new Model_DbTable_WebfolioEntries();
		
		$cascade = (bool)$_POST['cascade'];
		
		$dbHandler = Zend_Registry::get('dbHandler');
		$dbHandler->beginTransaction();
		
		try {			
			foreach ($ids as $id) {
				$deletedIds = $webfolioEntries->deleteNode($id, $cascade);
				
				if (empty($deletedIds)) { //No affected rows?
					echo 'Unexisting entry supplied.';
					exit;
				}
				
				//Deleting related webfolio comments.
				foreach ($webfolioEntries->getDependentTables() as $tableClass) {
					foreach ($deletedIds as $id) {
						$t = new $tableClass();
						
						$t->_cascadeDelete('Model_DbTable_WebfolioEntries', array('id'=>$id));
					}
				}
				
				//Cleaning default cache.
				Zend_Registry::get('CacheManager')->getCache('default')->clean(Zend_Cache::CLEANING_MODE_MATCHING_ANY_TAG, array('wf_entry', 'wf_' . $action));
				
				//Notifying delete() hook of WFEntry plugins.
				WebfolioCMS_Events_Broker::notifyEventHandlers(WebfolioCMS_Events_Broker::WF_ENTRY_DELETE, array($deletedIds));
			}
			
			$dbHandler->commit();
		}
		catch (Zend_Db_Exception $ex) {
			$dbHandler->rollBack();
			
			throw $ex;
		}
	}
	
	echo 'ok';
}
catch (Exception $ex) {
	echo $ex->getMessage();
}
?>