<?php
/**
 * Webfolio CMS
 *
 * Copyright (C) 2009 Nikola Posa (http://www.nikolaposa.in.rs)
 *
 * This file is part of Webfolio CMS.
 *
 * Webfolio CMS is free software: you can redistribute it and/or modify 
 * it under the terms of the GNU General Public License as published by 
 * the Free Software Foundation, either version 3 of the License, or 
 * (at your option) any later version.
 *
 * Webfolio CMS is distributed in the hope that it will be useful, but 
 * WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU 
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License 
 * along with Webfolio CMS. If not, see <http://www.gnu.org/licenses/>.
 */
 
/**
 * Script for handling AJAX requests from modules grid (get 
 * list of all modules, activate/deactivate/delete module(s)).
 *
 * @author Nikola Posa <posa.nikola@gmail.com>
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License
 */
include_once('../../../wf_init.php');

require_once('Zend/Application.php');

//Bootstrapping...
$application = new Zend_Application(APPLICATION_ENV, include APPLICATION_PATH . '/configs/wf_config.php');
$application->getBootstrap()->bootstrap(array('Autoloaders', 'DB', 'Modules', 'Cachemanager'));

if (!WebfolioCMS_Common::isUserLoggedIn()) {
	echo 'error';
	exit;
}

$action = $_POST['action'];

if (
    ($action == 'get' && !WebfolioCMS_Common::isUserAllowed(WebfolioCMS_Auth::getInstance()->getIdentity()->group_id, 'admin_modules', 'index'))
    || ($action != 'get') && !WebfolioCMS_Common::isUserAllowed(WebfolioCMS_Auth::getInstance()->getIdentity()->group_id, 'admin_modules', 'manage')
) {
    echo 'error';
	exit;
}

try {
	$modulesDir = new Admin_Model_DirContent_Modules();
	
	if ($action == 'get') {
		$modules = array('modules'=>$modulesDir->getModulesInfo());
		
		echo Zend_Json_Encoder::encode($modules); //Outputting to ExtJS grid.
	}
	else { //Activate/deactivate/delete/update.
		if ($action == 'activate') { //We should clear ACL cache, as modules can add their own resources.
			Zend_Registry::get('CacheManager')->getCache('default')->remove(WebfolioCMS_Acl::CACHE_ID);
		}
		
		$methodName = $action . 'Module';
		
		$modules = $_POST['dirs'];
		$moduleDirs = Zend_Json_Decoder::decode($modules);
	
		$modulesDir->$methodName($moduleDirs);
	
		echo 'ok';
	}
}
catch (Exception $ex) {
	echo $ex->getMessage();
}
?>