<?php
/**
 * Webfolio CMS
 *
 * Copyright (C) 2009 Nikola Posa (http://www.nikolaposa.in.rs)
 *
 * This file is part of Webfolio CMS.
 *
 * Webfolio CMS is free software: you can redistribute it and/or modify 
 * it under the terms of the GNU General Public License as published by 
 * the Free Software Foundation, either version 3 of the License, or 
 * (at your option) any later version.
 *
 * Webfolio CMS is distributed in the hope that it will be useful, but 
 * WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU 
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License 
 * along with Webfolio CMS. If not, see <http://www.gnu.org/licenses/>.
 */
 
/**
 * Script for handling AJAX requests for fetching data that
 * will be outputed in panel for managing sidebar.
 *
 * @author Nikola Posa <posa.nikola@gmail.com>
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License
 */
include_once('../../../wf_init.php');

require_once('Zend/Application.php');

//Bootstrapping...
$application = new Zend_Application(APPLICATION_ENV, include APPLICATION_PATH . '/configs/wf_config.php');
$application->getBootstrap()->bootstrap(array('Autoloaders', 'DB', 'Hooks', 'Modules', 'Cachemanager'));

if (!WebfolioCMS_Common::isUserLoggedIn()) {
	echo 'error';
	exit;
}

$action = $_POST['action'];

if (($action == 'get' && !WebfolioCMS_Common::isUserAllowed(WebfolioCMS_Auth::getInstance()->getIdentity()->group_id, 'admin_appearance', 'sidebar'))
    || ($action == 'save' && !WebfolioCMS_Common::isUserAllowed(WebfolioCMS_Auth::getInstance()->getIdentity()->group_id, 'admin_appearance_sidebar', 'manage'))
   ) {
    echo 'error';
    exit;
}

$sidebar = Model_WFSidebar::getInstance();

try {
	if ($action == 'get') {
		$type = $_POST['type'];
		
		$selectedSidebarItems = Model_WebfolioSettings::getSettings('sidebar_items');
		
		$sidebarItems = array();
		
		if ($type == 'optional') {
			$sidebarItems = Model_WFSidebar::get();
			foreach ($sidebarItems as $key=>$item) {
				foreach ($selectedSidebarItems as $sItem) {
					if ($item['helperName'] == $sItem['helperName'] && $item['module'] == $sItem['module']) {
						unset($sidebarItems[$key]);
					}
				}
			}
			
			sort($sidebarItems);
		}
		elseif ($type == 'selected') {
			foreach ($selectedSidebarItems as $key=>$item) {
				if ($item['module'] == 'default' || ($item['module'] != 'default' && WebfolioCMS_Common::isModuleActive($item['module']))) { //Module of selected sidebar item is not active?
					$sidebarItems[] = $item;
				}
			}
		}
		
		
	
		echo Zend_Json_Encoder::encode(array('items'=>$sidebarItems)); //Outputting to ExtJS grid.
	}
	elseif ($action == 'save') {
		$data = Zend_Json_Decoder::decode($_POST['data']);
		
		Model_WebfolioSettings::updateSetting('sidebar_items', $data);
		
		echo 'ok';
	}
}
catch (Exception $ex) {
	echo 'error';
}
?>