<?php
/**
 * Webfolio CMS
 *
 * Copyright (C) 2009 Nikola Posa (http://www.nikolaposa.in.rs)
 *
 * This file is part of Webfolio CMS.
 *
 * Webfolio CMS is free software: you can redistribute it and/or modify 
 * it under the terms of the GNU General Public License as published by 
 * the Free Software Foundation, either version 3 of the License, or 
 * (at your option) any later version.
 *
 * Webfolio CMS is distributed in the hope that it will be useful, but 
 * WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU 
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License 
 * along with Webfolio CMS. If not, see <http://www.gnu.org/licenses/>.
 */
 
/**
 * AJAX handler for pre-user delete logic, which is used for
 * rendering pre-deleting panel for choosing whether to delete
 * all related entries or assing them to some other user, and
 * for handling selected action.
 *
 * @author Nikola Posa <posa.nikola@gmail.com>
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License
 */
include_once('../../../wf_init.php');

require_once('Zend/Application.php');

//Bootstrapping...
$application = new Zend_Application(APPLICATION_ENV, include APPLICATION_PATH . '/configs/wf_config.php');
$application->getBootstrap()->bootstrap(array('Autoloaders', 'DB', 'Modules', 'Cachemanager'));

if (!WebfolioCMS_Common::isUserLoggedIn() || !WebfolioCMS_Common::isUserAllowed(WebfolioCMS_Auth::getInstance()->getIdentity()->group_id, 'admin_users', 'delete')) {
	echo 'error';
	exit;
}

//Getting data sent from AJAX.
$action = $_POST['action'];

if ($action == 'offer') {
    $selectedUsers = Zend_Json_Decoder::decode($_POST['selected_users']);
    $wfUsersDbTable = new Model_DbTable_WebfolioUsers();
    $users = $wfUsersDbTable->fetchAll('id NOT IN (' . $wfUsersDbTable->getAdapter()->quote($selectedUsers, Zend_Db::INT_TYPE) . ')')->toArray();
    $selectBox = '<select id="user_id">';
    foreach ($users as $user) {
        $selectBox .= '<option value="' . $user['id'] . '">' . $user['public_name'] . '</option>';
    }
    $selectBox .= '</select>';

    $output = '<div style = "padding: 4px;"><b>What would you like to do with webfolio entries that were posted by selected user(s)?</b>';
    $output .= '<p><input type="radio" name="action" value="assign" checked="checked" /> Assign them to other user: ' . $selectBox . '</p>';
    $output .= '<p><input type="radio" name="action" value="delete" /> Delete them</p></div>';

    echo $output;
}
elseif ($action == 'execute') {
    $userDelAction = $_POST['user_delete_action'];
    $ids = $_POST['id'];
	
	if (($ids{0} == '{' || $ids{0} == '[') && ($ids{strlen($ids)-1} == '}' || $ids{strlen($ids)-1} == ']')) { //JSON?
		$ids = Zend_Json_Decoder::decode($ids);
	}

	if (!is_array($ids)) {
		$ids = array($ids);
	}

    $WFEntriesDbTable = new Model_DbTable_WebfolioEntries();

    $where = 'user_id IN (' . $WFEntriesDbTable->getAdapter()->quote($ids, Zend_Db::INT_TYPE) . ')';

	if ($userDelAction == 'assign') {
        $assignTo = (int)$_POST['assign_to'];
        $WFEntriesDbTable->update(array('user_id'=>$assignTo), $where);
    }
    elseif ($userDelAction == 'delete') {
		//Getting related wf entries.
		$entries = $WFEntriesDbTable->fetchAll($where);
		$entryIds = array();
		foreach ($entries as $entry) {
			$entryIds[] = $entry['id'];
		}
		
		$WFEntriesDbTable->delete($where);
			
		//Deleting related webfolio comments.
		foreach ($WFEntriesDbTable->getDependentTables() as $tableClass) {
			foreach ($entryIds as $id) {
				$t = new $tableClass();
				
				$t->_cascadeDelete('Model_DbTable_WebfolioEntries', array('id'=>$id));
			}
		}
			
		//Notifying delete() hook of WFEntry plugins.
		WebfolioCMS_Events_Broker::notifyEventHandlers(WebfolioCMS_Events_Broker::WF_ENTRY_DELETE, array($entryIds));
		
		//Cleaning default cache.
		Zend_Registry::get('CacheManager')->getCache('default')->clean(Zend_Cache::CLEANING_MODE_MATCHING_ANY_TAG, array('wf_entry'));
    }
	
	echo 'ok';
}
?>