<?php
/**
 * Webfolio CMS
 *
 * Copyright (C) 2009 Nikola Posa (http://www.nikolaposa.in.rs)
 *
 * This file is part of Webfolio CMS.
 *
 * Webfolio CMS is free software: you can redistribute it and/or modify 
 * it under the terms of the GNU General Public License as published by 
 * the Free Software Foundation, either version 3 of the License, or 
 * (at your option) any later version.
 *
 * Webfolio CMS is distributed in the hope that it will be useful, but 
 * WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU 
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License 
 * along with Webfolio CMS. If not, see <http://www.gnu.org/licenses/>.
 */
 
/**
 * Script for handling AJAX requests from comment form.
 *
 * @author Nikola Posa <posa.nikola@gmail.com>
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License
 */
include_once('../../wf_init.php');

require_once('Zend/Application.php');

//Bootstrapping...
$application = new Zend_Application(APPLICATION_ENV, include APPLICATION_PATH . '/configs/wf_config.php');
$application->getBootstrap()->bootstrap(array('Autoloaders', 'Logger', 'DB', 'Locale', 'Translate', 'Modules'));

$commentForm = new Form_Comment();

try {
	if ($commentForm->isValid($_POST)) { //Valid data?
		$data = $commentForm->getValues();
		
		//Saving submitted comment.
		$webfolioComment = new Model_WebfolioComments($data);
		$webfolioComment->save();

		$commentStatus = $webfolioComment->getStatus();
		
		$translateAdapter = Zend_Registry::get(WebfolioCMS_Application_Resource_Translate::DEFAULT_REGISTRY_KEY);		
		
		$output = null;
		
		if ($commentStatus == 'approved') {
			$output = 'reload';
		}
		elseif ($commentStatus == 'overLimit') {
			$output = array('status'=>'red', 'message'=>sprintf($translateAdapter->translate('commentOverLimitMsg'), (int)Model_WebfolioSettings::getSettings('comments_visitor_limit')));
		}
		
		echo Zend_Json_Encoder::encode($output);
	}
	else {
		$errorMessages = array();
		$messages = $commentForm->getMessages();
		foreach ($messages as $field=>$message) {
			$errorMessages[$field] = $message[0];
		}
		
		echo Zend_Json_Encoder::encode($errorMessages);	
	}
}
catch (Zend_Mail_Exception $ex) {
	$errorLogger = Zend_Registry::get('errorLogger');
	$errorLogger->log('Comments notification email could not be sent.', Zend_Log::ERR);
}
catch (Exception $ex) {
	echo 'red#' . $ex->getMessage(); //'error_An error occurred. Please try later.';
}
?>