<?php
/**
 * Webfolio CMS
 *
 * Copyright (C) 2009 Nikola Posa (http://www.nikolaposa.in.rs)
 *
 * This file is part of Webfolio CMS.
 *
 * Webfolio CMS is free software: you can redistribute it and/or modify 
 * it under the terms of the GNU General Public License as published by 
 * the Free Software Foundation, either version 3 of the License, or 
 * (at your option) any later version.
 *
 * Webfolio CMS is distributed in the hope that it will be useful, but 
 * WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU 
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License 
 * along with Webfolio CMS. If not, see <http://www.gnu.org/licenses/>.
 */
 
/**
 * Script for handling AJAX requests from contact form.
 *
 * @author Nikola Posa <posa.nikola@gmail.com>
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License
 */
include_once('../../wf_init.php');

require_once('Zend/Application.php');

//Bootstrapping...
$application = new Zend_Application(APPLICATION_ENV, include APPLICATION_PATH . '/configs/wf_config.php');
$application->getBootstrap()->bootstrap(array('Autoloaders', 'DB', 'Locale', 'View', 'Translate'));

$contactForm = new Form_Contact();

$translateAdapter = Zend_Registry::get(WebfolioCMS_Application_Resource_Translate::DEFAULT_REGISTRY_KEY);

$action = $_POST['action'];
unset($_POST['action']);

if ($action == 'submit_form') {
    //Preventing usage of session hops for captcha session.
    Zend_Session::start();
    unset($_SESSION['__ZF']['Zend_Form_Captcha_' . $_POST['captcha']['id']]['ENNH']);
    
    try {
        if ($contactForm->isValidPartial($_POST)) { //Partial validation because only one contact form field may be sent to validation (onkeyup event).
            if (count($_POST) > 1) { //User clicked "Send"?
                $data = $contactForm->getValues();

                //Sending email message.
                $zendMail = new Zend_Mail('utf-8');
                @ $zendMail->addTo(Model_WebfolioSettings::getSettings('admin_email'))->setSubject($data['subject'])->setBodyHtml($data['text'])->setFrom($data['email'], $data['name'])->send();

                echo Zend_Json_Encoder::encode(array('status'=>'ok', 'message'=>$translateAdapter->translate('emailSentMsg')));
            }
            else { //Custom contact form field validation (onkeyup event)?
                echo Zend_Json_Encoder::encode(array(key($_POST)=>''));
            }
        }
        else {
            $errorMessages = array();
            $messages = $contactForm->getMessages();
            foreach ($messages as $field=>$message) {
                $errorMessages[$field] = current($message);
            }

            echo Zend_Json_Encoder::encode($errorMessages);
        }
    }
    catch (Exception $ex) {
        echo Zend_Json_Encoder::encode(array('status'=>'error', 'message'=>$translateAdapter->translate('emailErrorMsg')));
    }
}
elseif ($action == 'reload_captcha') {
    //Unsetting previous captcha session.
    $namespace = 'Zend_Form_Captcha_' . $_POST['current_captcha_id'];
    $captchaNamespace = new Zend_Session_Namespace($namespace);
    $captchaNamespace->unsetAll();

    //Generating new captcha.
    $captcha = $contactForm->getElement('captcha')->getCaptcha();
    $newCaptchaId = $captcha->generate();
    $newCaptcha = $captcha->render();

    echo Zend_Json_Encoder::encode(array('captcha'=>$newCaptcha, 'id'=>$newCaptchaId));
}
?>