<?php
/**
 * Webfolio CMS
 *
 * Copyright (C) 2009 Nikola Posa (http://www.nikolaposa.in.rs)
 *
 * This file is part of Webfolio CMS.
 *
 * Webfolio CMS is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Webfolio CMS is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Webfolio CMS. If not, see <http://www.gnu.org/licenses/>.
 */
 
/**
 * Script for handling AJAX requests for managing settings 
 * for sidebar menu view helper, which acts as sidebar
 * widget.
 *
 * @author Nikola Posa <posa.nikola@gmail.com>
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License
 */
include_once('../../wf_init.php');

require_once('Zend/Application.php');

//Bootstrapping...
$application = new Zend_Application(APPLICATION_ENV, include_once(APPLICATION_PATH . '/configs/wf_config.php'));
$application->getBootstrap()->bootstrap(array('Autoloaders', 'Cachemanager'));

if (!WebfolioCMS_Common::isUserLoggedIn() || !WebfolioCMS_Common::isUserAllowed(WebfolioCMS_Auth::getInstance()->getIdentity()->group_id, 'admin_appearance_sidebar', 'manage')) {
	echo 'error';
	exit;
}

$eventTypes = array('click', 'hover');

//Getting current settings.
$currentSettings = Zend_Json_Decoder::decode($_POST['data']);

$makeCollapsible = (bool)$currentSettings['make_collapsible'];
$disabled = (!$makeCollapsible) ? ' disabled="disabled"' : '';

$output = '
	<form name = "settings" style = "padding: 4px;">

    <p>
        <label>Make sidebar menu collapsible:</label>
        <input type="checkbox" name="make_collapsible" id="make_collapsible" onclick="if (!$(\'#make_collapsible\').is(\':checked\')) { $(\'.make_collapsible\').attr(\'disabled\', \'disabled\'); } else { $(\'.make_collapsible\').removeAttr(\'disabled\'); }" value="1"' . (($makeCollapsible == true) ? ' checked="checked"' : '') . ' />
    </p>

    <p>
        <label>Start collapsing from menu items at level:</label>
        <input type="text" size="4" class="make_collapsible" name="collapse_from_level" id="collapse_from_level" value="' . (($level = (int)$currentSettings['collapse_from_level']) ? $level : '1') . '"' . $disabled . ' />
    </p>
    
    <p>
        <label>Expand/collapse type:</label>
        <select name="event_type" id="event_type" class="make_collapsible"' . $disabled . '>
        
    ';

foreach ($eventTypes as $eType) {
    $output .= '<option value="' . $eType . '"' . (($currentSettings['event_type'] == $eType) ? ' selected="selected"' : '') . '>' . $eType . '</option>';
}

$output .= '
        </select>
    </p>

    </form>

    <script type="text/javascript">
        $(\'#make_collapsible\').click(function(e) {
            if ($(this).is(":checked")) {
                $(\'.make_collapsible\').attr(\'disabled\', \'disabled\');
            }
            else {
                $(\'.make_collapsible\').removeAttr(\'disabled\');
            }
        );
    </script>';


echo $output; //Outputting to ExtJS grid.
?>