/**
 * Webfolio CMS
 *
 * Copyright (C) 2009 Nikola Posa (http://www.nikolaposa.in.rs)
 *
 * This file is part of Webfolio CMS.
 *
 * Webfolio CMS is free software: you can redistribute it and/or modify 
 * it under the terms of the GNU General Public License as published by 
 * the Free Software Foundation, either version 3 of the License, or 
 * (at your option) any later version.
 *
 * Webfolio CMS is distributed in the hope that it will be useful, but 
 * WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU 
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License 
 * along with Webfolio CMS. If not, see <http://www.gnu.org/licenses/>.
 */
 
/**
 * Basic (abstract) grid, that has functionality for deleting some
 * entries.
 *
 * @author Nikola Posa <posa.nikola@gmail.com>
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License
 */
 
Ext.namespace('WFAdmin');

WFAdmin.basicGrid = Ext.extend(Ext.grid.GridPanel, {	
	//Defaults - configurable from outside.
	action: '',
	width:300,
	height:300,
	disableSelection:true,
	loadMask: true,
	sm: new Ext.grid.CheckboxSelectionModel(),
	
    viewConfig: { forceFit:true },
			
	handleDelete: function () {
		var selectedKeys = this.selModel.selections.keys; //returns array of selected rows ids only
           
		var sLength = selectedKeys.length;
		
		var actionPlural = (this.action.charAt(this.action.lenght-1) == 'y') ? this.action.substr(0, -1) + 'ies' : this.action + 's';
		
		if (sLength  > 0)
		{
			Ext.MessageBox.confirm('Confirmation','Are you sure you want to delete selected ' + actionPlural + '?', this.doDelete, this);
		}
		else
		{
			Ext.MessageBox.alert('Note','You must select at least one of the listed ' + actionPlural + ' to proced.');
		}
	},
	
	doDelete: function (btn) {
		if (btn == 'yes') {
			var selectedKeys = this.selModel.selections.keys;
			var ids = Ext.encode(selectedKeys);
			
			Ext.Ajax.request( 
			{   
				url: $('#base_url').val() + '/front-end/ajax_handlers/admin/delete.php', 
				params: { 
					action: this.action,
					id: ids
				},
				scope: this,
				success: function(response, options) {
					if (response.responseText == 'ok') {
						this.store.reload();
					}
					else {
						Ext.MessageBox.alert('Error', response.responseText);
					}
				}                                      
			});
		}
	}
});