/**
 * Webfolio CMS
 *
 * Copyright (C) 2009 Nikola Posa (http://www.nikolaposa.in.rs)
 *
 * This file is part of Webfolio CMS.
 *
 * Webfolio CMS is free software: you can redistribute it and/or modify 
 * it under the terms of the GNU General Public License as published by 
 * the Free Software Foundation, either version 3 of the License, or 
 * (at your option) any later version.
 *
 * Webfolio CMS is distributed in the hope that it will be useful, but 
 * WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU 
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License 
 * along with Webfolio CMS. If not, see <http://www.gnu.org/licenses/>.
 */
 
/**
 * Content plugins drag&drop panels.
 *
 * @author Nikola Posa <posa.nikola@gmail.com>
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License
 */

WFAdminFrontEnd.contentPluginsDropZone = Ext.extend(WFAdminFrontEnd.dropZone, {
	//Redefining onContainerOver because we must disallow moving items between different plugin types.
	onContainerOver: function(dd, e, data) {
		return ((dd.grid !== this.grid || this.grid.getXType().substr(0, 8) == 'selected') && dd.grid.type == this.grid.type) ? this.dropAllowed : this.dropNotAllowed;
	} 
	
	//Redefining onContainerDrop because we must disallow moving items between different plugin types.
	,onContainerDrop: function(dd, e, data) {
		if (dd.grid.type == this.grid.type) {	
			return WFAdminFrontEnd.contentPluginsDropZone.superclass.onContainerDrop.apply(this, arguments);
		}
		else {
			return false;
		}
	}
});

WFAdminFrontEnd.contentPlugins = Ext.extend(WFAdminFrontEnd.dragDropAbstract, {
	type: ''
	,place: ''
	,initComponent:function() {
		var config = {
			store:new Ext.data.JsonStore({
				url: $('#base_url').val() + '/front-end/ajax_handlers/admin/content_plugins_panel.php', 
				baseParams: {action: 'get', type: this.type, place: this.place},
				root: 'plugins',
				fields: [
					{name: 'helperName', type: 'string', mapping: 'helperName'},
					{name: 'userFriendlyName', type: 'string', mapping: 'userFriendlyName'},
					{name: 'module', type: 'string', mapping: 'module'},
					{name: 'settings', type: 'auto', mapping: 'settings'}
				]
			})
			,viewConfig: { 
				forceFit:true
				//,emptyText: 'Currently, there is no any available plugin.'
			}
			,columns:[{
				dataIndex:'userFriendlyName'
				,header: this.place.charAt(0).toUpperCase() + this.place.substr(1) + ' plugins'
				}
			]
			,enableColumnHide: false
		};

        if (!$('#manage_plugins_permission').val()) {
            config.enableDragDrop = false;
        }
  
		//Apply config.
		Ext.apply(this, Ext.apply(this.initialConfig, config));
   
		//Call parent.
		WFAdminFrontEnd.contentPlugins.superclass.initComponent.apply(this, arguments);
	}

	,onRender:function() {
		this.store.load();
		WFAdminFrontEnd.contentPlugins.superclass.onRender.apply(this, arguments);
		
		//We must set contentPlugins dropZone object.
		this.dz = new WFAdminFrontEnd.contentPluginsDropZone(this, {ddGroup:this.ddGroup || 'GridDD'});
	}
});

WFAdminFrontEnd.selectedPlugins = Ext.extend(WFAdminFrontEnd.contentPlugins, {
	initComponent:function() {
		//Call parent.
		WFAdminFrontEnd.selectedPlugins.superclass.initComponent.apply(this, arguments);

        if ($('#manage_plugins_permission').val()) {
            //Adding additional column (actions) into "columns" stack.
            var config = this.initialConfig;

            config.columns.push({
                dataIndex:'userFriendlyName'
                    ,header: 'Actions'
                    ,width: 40
                    ,renderer: this.renderActions
            });

            //Apply config.
            this.getColumnModel().setConfig(config.columns);
        }
  
		//Ext.apply(this, Ext.apply(this.initialConfig, config));
	}
	
	,renderActions: function (value, p, record) {
		return actions = '<span class = "grid_actions"><a class = "act_settings" style = "cursor: pointer;">Settings</a></span>';
	}
	
	,onClick: function(e) {
		var btn = e.getTarget('.grid_actions');        
		
		if (btn) {
			var t = e.getTarget(); 
			var v = this.getView();			
			var action = t.className.split('_')[1];
			switch (action) {
				case 'settings':
				{
					var index = v.findRowIndex(t);
					var record = this.store.getAt(index);
					var currentSettings = record.data.settings;
					
					if (record.data.helperName == 'WFComments') { //Webfolio comments is built in plugin, and user can not select on which pages it will be rendered.
						currentSettings.selections = null;
					}
					
					Ext.Ajax.request( 
					{   
						url: $('#base_url').val() + '/front-end/ajax_handlers/admin/content_plugins_panel.php', 
						params: { 
							action: 'settings',
							settings: Ext.encode(currentSettings)
						},
						success: function(response, options) {
							var win = new Ext.Window({
								modal: true
								,width:320
								,height:470
								,html: response.responseText
							});
							win.addButton("Ok", function(btn, e) {
								var settings = record.data.settings;
								var values = $(":input").serializeArray(); //Data from the form.
								
								//Reseting current selection and top separator settings.
								settings.selections = new Object();
								settings.topSeparator = '';
								
								jQuery.each(values, function(i, field) {
									if (field.name.substr(0, 10) == 'selections') {
										var type = field.name.substr(11);
										
										if (!settings.selections[type]) {
											settings.selections[type] = [];
										}
										
										settings.selections[type].push(field.value);
									}
									else {
										settings[field.name] = field.value;
									}
								});
								
								record.set('settings', settings);
								record.commit();
								win.destroy();
								 
							}, this);
							win.addButton("Cancel", win.destroy, win);
							win.show();
						}                                      
					});
					
					break;
				}
			}
		}            
	}
});

WFAdminFrontEnd.optionalPreContentPlugins = Ext.extend(WFAdminFrontEnd.contentPlugins, {
	initComponent:function() {
		var config = {
			type: 'pre'
			,place: 'optional'
		};
  
		//Apply config.
		Ext.apply(this, Ext.apply(this.initialConfig, config));
   
		//Call parent.
		WFAdminFrontEnd.optionalPreContentPlugins.superclass.initComponent.apply(this, arguments);
	}
});
//Register xtype.
Ext.reg('optionalpreplugins', WFAdminFrontEnd.optionalPreContentPlugins);

WFAdminFrontEnd.selectedPreContentPlugins = Ext.extend(WFAdminFrontEnd.selectedPlugins, {
	initComponent:function() {
		var config = {
			type: 'pre'
			,place: 'selected'
		};
  
		//Apply config.
		Ext.apply(this, Ext.apply(this.initialConfig, config));
   
		//Call parent.
		WFAdminFrontEnd.selectedPreContentPlugins.superclass.initComponent.apply(this, arguments);
	}
});
//Register xtype.
Ext.reg('selectedpreplugins', WFAdminFrontEnd.selectedPreContentPlugins);

WFAdminFrontEnd.optionalPostContentPlugins = Ext.extend(WFAdminFrontEnd.contentPlugins, {
	initComponent:function() {
		var config = {
			type: 'post'
			,place: 'optional'
		};
  
		//Apply config.
		Ext.apply(this, Ext.apply(this.initialConfig, config));
   
		//Call parent.
		WFAdminFrontEnd.optionalPostContentPlugins.superclass.initComponent.apply(this, arguments);
	}
});
//Register xtype.
Ext.reg('optionalpostplugins', WFAdminFrontEnd.optionalPostContentPlugins);

WFAdminFrontEnd.selectedPostContentPlugins = Ext.extend(WFAdminFrontEnd.selectedPlugins, {
	initComponent:function() {
		var config = {
			type: 'post'
			,place: 'selected'
		};
  
		//Apply config.
		Ext.apply(this, Ext.apply(this.initialConfig, config));
   
		//Call parent.
		WFAdminFrontEnd.selectedPostContentPlugins.superclass.initComponent.apply(this, arguments);
	}
});
//Register xtype.
Ext.reg('selectedpostplugins', WFAdminFrontEnd.selectedPostContentPlugins);
  
//Main entry point.
Ext.onReady(function() {
	Ext.BLANK_IMAGE_URL = $('#base_url').val() + '/libs/ExtJS/resources/images/default/s.gif';
 
	Ext.QuickTips.init();

    var panelItems = [
        {
            html:'Pre-content plugins:'
            ,colspan: 2
            ,cellCls: 'cell_header'
        }
        ,{
            xtype:'optionalpreplugins'
            ,id: 'optionalPrePlugins'
            ,width:340
            ,height: 200
            ,cellCls: 'left_box'
        }
        ,{
            xtype:'selectedpreplugins'
            ,id: 'selectedPrePlugins'
            ,width:340
            ,height: 200
        }
        ,{
            html:'Post-content plugins:'
            ,colspan: 2
            ,cellCls: 'cell_header'
        }
        ,{
            xtype:'optionalpostplugins'
            ,id: 'optionalPostPlugins'
            ,width:340
            ,height: 200
            ,cellCls: 'left_box'
        }
        ,{
            xtype:'selectedpostplugins'
            ,id: 'selectedPostPlugins'
            ,width:340
            ,height: 200
        }
    ];

    if ($('#manage_plugins_permission').val()) {
        panelItems.push(
            {
				colspan: 2
				,cellCls: 'toolbar'
				,items:
				[{
					xtype:'button'
					,text: 'Save'
					,width: 100
					,handler: function (b, e) {

						var plugins = new Object();
						plugins.preContent = new Array();
						plugins.postContent = new Array();

						for (var type in plugins) {
							var shortType = type.substr(0, type.indexOf('Content'));
							var id = 'selected' + shortType.charAt(0).toUpperCase() + shortType.substr(1) + 'Plugins';

							var range = this.ownerCt.ownerCt.items.get(id).store.getRange();

							for (var i in range) {
								plugins[type][i] = range[i].data;
							}
						}

						var data = Ext.encode(plugins);

						/*var plugins = new Object();

						var selected = new Object();
						selected.preContent = this.ownerCt.ownerCt.items.get('selectedPrePlugins').store.getRange();
						selected.postContent = this.ownerCt.ownerCt.items.get('selectedPostPlugins').store.getRange();

						for (var type in selected) {
							var row = new Array();
							for (var i in selected[type]) {
								row[i] = selected[type][i].data;
							}

							plugins[type] = row;
						}

						var data = Ext.encode(plugins);*/

						Ext.Ajax.request(
						{
							url: $('#base_url').val() + '/front-end/ajax_handlers/admin/content_plugins_panel.php',
							params: {
								action: 'save',
								data: data
							},
							success: function(response, options) {
								if (response.responseText == 'ok') {
									Ext.MessageBox.alert('Message', 'Your content plugins setup has been saved.');
								}
								else {
									Ext.MessageBox.alert('Error', response.responseText);
								}
							}
						});
					}
				}]
			}
        );
    }

	//Create and show window.
	var panel = new Ext.Panel({
		layout:'table'
		,width:690
		,frame: true
		,layoutConfig: {
			columns: 2
		}
		,renderTo: 'content_plugins_panel'
		,items:panelItems
	});
}); 