/**
 * Webfolio CMS
 *
 * Copyright (C) 2009 Nikola Posa (http://www.nikolaposa.in.rs)
 *
 * This file is part of Webfolio CMS.
 *
 * Webfolio CMS is free software: you can redistribute it and/or modify 
 * it under the terms of the GNU General Public License as published by 
 * the Free Software Foundation, either version 3 of the License, or 
 * (at your option) any later version.
 *
 * Webfolio CMS is distributed in the hope that it will be useful, but 
 * WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU 
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License 
 * along with Webfolio CMS. If not, see <http://www.gnu.org/licenses/>.
 */
 
/**
 * Script with functions used in "Edit theme" page in admin 
 * panel.
 *
 * @author Nikola Posa <posa.nikola@gmail.com>
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License
 */
 
/**
 * Loads content of some theme file.
 *
 * @param string Id of a span element which holds file id.
 * @param string Name of the file that will be loaded.
 * @return void
 */
 
$(document).ready(function () {
	$('.edit_theme_file').click(function () {
		var themeDirName = $('#themesList').val();
		var fileName = $(this).attr('title');
	
		$('#loadProgressImg').html('<img src = "' + $('#base_url').val() + '/front-end/img/ajax-loader.gif" alt = "Loading..." />');
		$('.error_message').html('');
		
		$.ajax({
			type: 'POST',
			url: $('#base_url').val() + '/front-end/ajax_handlers/admin/theme_file.php',
			data: 'action=load&themeDirName=' + themeDirName + '&fileName=' + fileName,
			success: function(msg) {
				if (msg.substr(0, 6) != 'error_') {
					$('#loadProgressImg').html('');
					
					$('#fileContent').val(msg);
				}
			}
		});
	
		$('#headerFileName').html($(this).html());
		$('#fileName').val(fileName);
					
		$('.edit_theme_file').removeClass('edit_theme_file_selected');
		$(this).addClass('edit_theme_file_selected');
	});
});

/**
 * Updates content of theme file that is currently being 
 * edited.
 *
 * @return void
 */
function updateThemeFile() {
	$('#updateProgressImg').html('<img src = "' + $('#base_url').val() + '/front-end/img/ajax-loader.gif" alt = "Loading..." />');
	
	var themeDirName = $('#themesList').val();
	var fileName 	 = $('#fileName').val();
	var fileContent  = $('#fileContent').val();
	fileContent = encodeURIComponent(fileContent);
	
	$.ajax({
		type: 'POST',
		url: $('#base_url').val() + '/front-end/ajax_handlers/admin/theme_file.php',
		data: 'action=update&themeDirName=' + themeDirName + '&fileName=' + fileName + '&fileContent=' + fileContent,
		success: function(msg) {
			$('#updateProgressImg').html('');
			
			$('.error_message').html('');
			
			if ((msg.charAt(0) == '{' || msg.charAt(0) == '[') && (msg.charAt(msg.length-1) == '}' || msg.charAt(msg.length-1) == ']')) { //JSON (validation errors)?
				$('.error_message').html('');
				
				var errMsgs = $.evalJSON(msg);
				
				for (var field in errMsgs) {
					$('#err_' + field).html(errMsgs[field]);
				}
			}
			else {
				var pos = msg.indexOf('_');
				var status = msg.substr(0, pos);
				var message = msg.substr(pos + 1);
				var messageClass;
				
				if (status == 'ok') {
					messageClass = 'green';
				}
				else if (status == 'error') {
					messageClass = 'red';
				}
				
				$('#message').show();
				$('#message').html('<p class = "message_' + messageClass + '">' + message + '</p>');
				setTimeout('$(\'#message\').hide(\'slow\');', 2000);
			}
		}
	});
}