/**
 * Webfolio CMS
 *
 * Copyright (C) 2009 Nikola Posa (http://www.nikolaposa.in.rs)
 *
 * This file is part of Webfolio CMS.
 *
 * Webfolio CMS is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Webfolio CMS is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Webfolio CMS. If not, see <http://www.gnu.org/licenses/>.
 */

Ext.namespace('WFAdmin'); 

WFAdmin.groupsGrid = Ext.extend(WFAdmin.basicGrid, {
	initComponent: function() {
		var config = {
			action: 'group',
			width:300,
			height:400,
			store:new Ext.data.JsonStore({
				url: $('#base_url').val() + '/front-end/ajax_handlers/admin/users_groups_grid.php',
                method: 'POST',
                baseParams: {action: 'groups'},
                root: 'groups', // name of the property that is container for an Array of row objects
                id: 'id',
				fields: [
					{name: 'id', type: 'int', mapping: 'id'},
                    {name: 'name', type: 'string', mapping: 'name'}
				]
			}),
			viewConfig: {
				forceFit:true,
				emptyText: 'Currently, there is no any user group.'
			},
			columns:[
				this.sm,
				{
                    header: "Name",
                    width: 200,
                    sortable: true,
                    dataIndex: 'name'
				},{
					header: 'Actions',
					width: 100,
					dataIndex: 'id',
                    scope: this,
					renderer: this.renderActions,
					hideable: false
				}
			],
			tbar: []
		};

        if ($('#delete_groups_permission').val()) {
            config.tbar.push(
                {
                    text: 'Delete',
                    tooltip: 'Click to delete selected groups.',
                    scope: this,
                    handler: this.handleDelete
                }
            );
        }

		//Apply config.
		Ext.apply(this, Ext.apply(this.initialConfig, config));

        this.on('beforerender', function(){
            if (!$('#edit_groups_permission').val() && !$('#delete_groups_permission').val()) {
                this.getColumnModel().setHidden(0, true);
                this.getColumnModel().setHidden(2, true);
            }
        });

		//Call parent.
        WFAdmin.groupsGrid.superclass.initComponent.apply(this, arguments);
    },

    handleDelete: function () { //override
		var selectedKeys = this.selModel.selections.keys; //returns array of selected rows ids only

        var callParent = true;

		Ext.each(selectedKeys, function(key, i) {
            Ext.each($.evalJSON($('#read_only_groups_ids').val()), function(id, j) {
                if (key == id) {
                    Ext.MessageBox.alert('Error','One of the groups that you\'ve selected can not be deleted.');
                    callParent = false;
                    return false;
                }
            });
        });

        if (callParent == true) {
            WFAdmin.groupsGrid.superclass.handleDelete.apply(this, arguments);
        }
	},

    onRender:function() {
        this.store.load();

        WFAdmin.groupsGrid.superclass.onRender.apply(this, arguments);
    },

    onClick: function(e) {
		var btn = e.getTarget('.grid_actions');

		if (btn) {
			var t = e.getTarget();
			var action = t.className.split('_')[1];
			switch (action) {
                case 'edit':
				{
					var v = this.getView();
                    var recordIndex = v.findRowIndex(t);
                    var record = this.store.getAt(recordIndex);

                    var url = $('#base_url').val() + '/admin/groups/edit/' + record.data.id;

                    window.open(url, '', 'top=' + (e.getPageY() - 100) + ', left=' + (e.getPageY() + 20) + ', width=400, height=300, scrollbars=yes, location=no, status=no, toolbar=no');
					break;
				}
				case 'delete':
				{
					this.handleDelete();
					break;
				}
			}
		}
	},

    renderActions: function (val) {
		var allowed = true;
        
        Ext.each($.evalJSON($('#read_only_groups_ids').val()), function(id, index) {
            if (val == id) {
                allowed = false;
                return false;
            }
        });

        if (allowed == true) {
            var actions = [];
             if ($('#edit_groups_permission').val() || val == $('#user_id').val()) {
                actions.push('<a class = "act_edit">Edit</a>');
            }

            if ($('#delete_groups_permission').val()) {
                actions.push('<a class = "act_delete">Delete</a>');
            }

            return '<span class = "grid_actions">' + actions.join(' | ') + '</span>';
        }
        else {
            return '';
        }
	}
});

Ext.onReady(function() {
	Ext.BLANK_IMAGE_URL = $('#base_url').val() + '/libs/ExtJS/resources/images/default/s.gif';

	Ext.QuickTips.init();

	var groupsGrid = new WFAdmin.groupsGrid();
    groupsGrid.render('groups_grid');
});