/**
 * Webfolio CMS
 *
 * Copyright (C) 2009 Nikola Posa (http://www.nikolaposa.in.rs)
 *
 * This file is part of Webfolio CMS.
 *
 * Webfolio CMS is free software: you can redistribute it and/or modify 
 * it under the terms of the GNU General Public License as published by 
 * the Free Software Foundation, either version 3 of the License, or 
 * (at your option) any later version.
 *
 * Webfolio CMS is distributed in the hope that it will be useful, but 
 * WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU 
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License 
 * along with Webfolio CMS. If not, see <http://www.gnu.org/licenses/>.
 */
 
/**
 * Grids for managing webfolio items and comments.
 *
 * @author Nikola Posa <posa.nikola@gmail.com>
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License
 */
 
Ext.namespace('WFAdminManage');

WFAdminManage.itemsGrid = Ext.extend(WFAdmin.basicGrid, {
	initComponent: function() {
		var config = {
			action: 'item',
			width:730,
			autoHeight: true,
			renderTo:'items_grid',
			store:new Ext.data.JsonStore({
				url: $('#base_url').val() + '/front-end/ajax_handlers/admin/show_grids.php', 
				baseParams: {action: 'items'},
				root: 'results',
				id: 'id',
				fields: [
					{name: 'id', type: 'int', mapping: 'id'},
					{name: 'title', type: 'string', mapping: 'title'},
					{name: 'titleUrlFormat', type: 'string', mapping: 'title_url_format'},
					{name: 'date', type: 'date', mapping: 'date'},
					{name: 'status', type: 'string', mapping: 'status'},
					{name: 'depth', type: 'string', mapping: 'depth'},
                    {name: 'author', type: 'string', mapping: 'author'}
				]
			}),
			viewConfig: { 
				forceFit:true,
				emptyText: 'Currently, there is no any item in your webfolio.'
			},
			columns:[
				this.sm,
				{
					header: 'Title',
					width: 200,
					dataIndex: 'title',
					renderer: this.renderTitle,
					sortable: false,
					hideable: false
				},
				{
					header: 'Date',
					width: 100,
					dataIndex: 'date',
					renderer: Ext.util.Format.dateRenderer('d/m/Y'),
					sortable: true
				},
                {
					header: 'Author',
					width: 130,
					dataIndex: 'author',
					sortable: true
				},
				{
					header: 'Status',
					width: 100,
					dataIndex: 'status'
				}
			],
			tbar: [
				{
					text:'Delete',
                    itemId: 'deleteButton',
					tooltip:'Delete selection.',
					scope: this,
					handler: this.handleDelete
				}
			]
		};

        if (!$('#delete_items_permission').val()) {
            config.tbar = [];
        }
  
		//Apply config.
		Ext.apply(this, config);

        this.on('beforerender', function(){
            if (!$('#delete_items_permission').val()) {
                this.getColumnModel().setHidden(0, true);
            }
        });
   
		//Call parent.
        WFAdminManage.itemsGrid.superclass.initComponent.apply(this, arguments);
    },
    
    onRender:function() {
        this.store.load();
		
        WFAdminManage.itemsGrid.superclass.onRender.apply(this, arguments);
    },

	renderTitle: function (value, p, record) {
        if ($('#edit_items_permission').val()) {
            return '<a style = "margin-left: ' + (record.data.depth + 3) + 'px;" href="' + $('#base_url').val() + '/admin/items/edit/' + record.data.titleUrlFormat + '">' + value + '</a>';
        }
        else {
            return '<span style = "margin-left: ' + (record.data.depth + 3) + 'px;">' + value + '</span>';
        }
	}
});

WFAdminManage.commentsGrid = Ext.extend(WFAdmin.basicGrid, {
	//This can be changed from outside.
	type: '',
	action: 'comment',
	width:770,
	height:560,
	viewConfig: {
		forceFit:true,
		enableRowBody:true,
		showPreview:true,
		emptyText: 'There is no any comment to display.',
		getRowClass: function(record, rowIndex, p, store) {
			if (this.showPreview) {
				p.body = '<div style = "margin-left: 3px;"> <p>' + record.data.text + '</p> <p style = " padding-top: 2px; border-top: 1px dashed #8db2e3;">In ' + record.data.WFItemTitle + ', ' + record.data.datetime.dateFormat('d/m/Y, H:i') + '</p> </div>';
				return 'x-grid3-row-expanded';
			}
			return 'x-grid3-row-collapsed';
		}
	},
			
	initComponent:function() {
		var store = new Ext.data.JsonStore({
			url: $('#base_url').val() + '/front-end/ajax_handlers/admin/show_grids.php', 
			baseParams: {action: 'comments', cond: this.type},
			root: 'results',
			totalProperty: 'total',
			id: 'id',
			fields: [
				{name: 'id', type: 'int', mapping: 'id'},
				{name: 'WFItemTitle', type: 'string', mapping: 'title'},
				{name: 'authorName', type: 'string', mapping: 'author_name'},
				{name: 'authorEmail', type: 'string', mapping: 'author_email'},
				{name: 'authorUrl', type: 'string', mapping: 'author_url'},
				{name: 'authorIp', type: 'string', mapping: 'author_ip'},
				{name: 'text', type: 'string', mapping: 'text'},
				{name: 'datetime', type: 'date', mapping: 'datetime'},
				{name: 'status', type: 'string', mapping: 'status'}
			]
		});
		
		 var config = {
            store: store,
            columns: [
				this.sm,
				{
					header: 'Comment',
					width: 430,
					dataIndex: 'authorName',
					renderer: this.renderAuthorInfo,
					hideable: false
				},
				{
					header: 'Date',
					width: 100,
					dataIndex: 'datetime',
					renderer: Ext.util.Format.dateRenderer('d/m/Y'),
					sortable: true
				},
				{
					header: 'Actions',
                    id: 'actionsColumn',
					width: 240,
					dataIndex: 'id',
					renderer: this.renderActions,
					hideable: false
				}
			],
			
           bbar: new Ext.PagingToolbar({
				pageSize: 20,
				store: store,
				displayInfo: true,
				displayMsg: 'Displaying comments {0} - {1} of {2}',
				emptyMsg: 'There is no any comment.'
			})
        };
		
		//Apply config.
		Ext.apply(this, config);

        this.on('beforerender', function(){
            if (!$('#manage_comments_permission').val() && !$('#delete_comments_permission').val()) {
                this.getColumnModel().setHidden(0, true);
                if (!$('#edit_comments_permission').val()) {
                    this.getColumnModel().setHidden(3, true);
                }
            }
        });
   
		//Call parent.
        WFAdminManage.commentsGrid.superclass.initComponent.apply(this, arguments);
	},
		
	onRender:function() {
		this.store.load({params:{start:0, limit:20}});
		
		WFAdminManage.commentsGrid.superclass.onRender.apply(this, arguments);
	},
	
	onClick: function(e) {
		var btn = e.getTarget('.grid_actions');        
		
		if (btn) {
			var t = e.getTarget();          
			var action = t.className.split('_')[1];
			switch (action) {
				case 'delete':
				{
					this.handleDelete();
					break;
				}
				default:
				{
					this.doHandleCommentActions(action);
					break;
				}
			}
		}            
	},
	
	toggleDetails: function(btn, pressed) {
		var view = this.getView();
		view.showPreview = pressed;
		view.refresh();
	},
	
	renderAuthorInfo: function (value, p, record) {
		var newNotify = '';
		var authorUrl = '';
		
		if (record.data.status == 'awaiting') {
			newNotify = '<span style = "font-weight: bold; font-size: 14px; color: #FF8C00; margin-left: 10px;">(awaiting)</span>';
		}
		
		if (record.data.authorUrl.length > 0) {
			authorUrl = '<a href = "' + record.data.authorUrl + '">' + record.data.authorUrl + '</a> | ';
		}
		
        var authorName = ($('#edit_comments_permission').val()) ? '<a href="' + $('#base_url').val() + '/admin/comments/edit/{1}">{0}</a>' : '{0}';

		return String.format('<span style = "font-size: 14px; font-weight: bold;">' + authorName + '</span> ' + newNotify + '<br /> (' + authorUrl + '{3} | {4})', value, record.data.id, record.data.authorUrl, record.data.authorEmail, record.data.authorIp);
	},
	
	renderActions: function (value, p, record) {
        var actions = [];
        if ($('#manage_comments_permission').val()) {
            if (record.data.status != 'approved') {
                actions.push('<a class = "act_approve">Approve</a>');
            }
            else {
                actions.push('<a class = "act_unapprove">Unapprove</a>');
            }

            if ($('#use_akismet').val() == '1') {
                actions.push('<a class = "act_markAsSpam">Mark as spam</a>');
            }
        }

        if ($('#edit_comments_permission').val()) {
            actions.push('<a href="' + $('#base_url').val() + '/admin/comments/edit/' + record.data.id + '">Edit</a>');
        }

        if ($('#delete_comments_permission').val()) {
            actions.push('<a class = "act_delete">Delete</a>');
        }
		
		return '<span class = "grid_actions">' + actions.join(' | ') + '</span>';
	},
	
	handleCommentActions: function(button) {
		var action = button.getId().substr(7);
		
		this.doHandleCommentActions(action);
	},
	
	doHandleCommentActions: function(action) {
		var selectedKeys = this.selModel.selections.keys; //Returns array of selected rows ids only.
           
		var sLength = selectedKeys.length;
		
		if (sLength  > 0)
		{
			var ids = Ext.encode(selectedKeys);
			
			Ext.Ajax.request( 
			{   
				url: $('#base_url').val() + '/front-end/ajax_handlers/admin/comments.php', 
				params: { 
					action: action,
					id: ids
				},
				scope: this,
				success: function(response, options) {
					if (response.responseText == 'ok') {
						if (action == 'markAsSpam') {
							window.location = $('#base_url').val() + '/admin/comments';
						}
						else {
							this.store.reload();
						}
					}
					else {
						Ext.MessageBox.alert('Error', response.responseText);
					}
				}                                      
			});
		}
		else
		{
			Ext.MessageBox.alert('Note', 'You must select at least one of the listed comments to proced.');
		}
	}
});

WFAdminManage.regularCommentsGrid = Ext.extend(WFAdminManage.commentsGrid, {
    initComponent:function() {
        var tbarButtons = [];
        
        if ($('#manage_comments_permission').val()) {
            tbarButtons.push(
            {
				id: 'button_approve',
				text:'Approve',
				tooltip:'Approve selected comments.',
				scope: this,
				handler: this.handleCommentActions
			},
			'-',
			{
				id: 'button_unapprove',
				text:'Unapprove',
				tooltip:'Unapprove selected comments.',
				scope: this,
				handler: this.handleCommentActions
			});

            if ($('#use_akismet').val() == '1') { //Only if Akismet spam protections is enabled.
                tbarButtons.push(
                    '-',
                    {
                        id: 'button_markAsSpam',
                        text:'Mark as spam',
                        tooltip:'Mark selected comments as spam.',
                        scope: this,
                        handler: this.handleCommentActions
                    }
                );
            }
        }

        if ($('#delete_comments_permission').val()) {
            if (tbarButtons.length > 0) {
                tbarButtons.push('-');
            }

            tbarButtons.push(
                {
                    text:'Delete',
                    tooltip:'Delete selected comments.',
                    scope: this,
                    handler: this.handleDelete
                }
            );
        }

        if (tbarButtons.length > 0) {
            tbarButtons.push('-');
        }

		tbarButtons.push(
			{
				pressed: true,
				enableToggle: true,
				text: 'Details',
				tooltip: 'Show/hide text of a comment.',
				scope: this,
				cls: 'x-btn-text-icon details',
				toggleHandler: function(btn, pressed) {
					var view = this.getView();
					view.showPreview = pressed;
					view.refresh();
				}
			}
		);
		
        var config = {
			type: 'not_spam',
			renderTo:'comments_grid',
			tbar: tbarButtons
        };
		
		//Apply config.
		Ext.apply(this, Ext.apply(this.initialConfig, config));
   
		//Call parent.
        WFAdminManage.regularCommentsGrid.superclass.initComponent.apply(this, arguments);
    }
});

WFAdminManage.spamCommentsGrid = Ext.extend(WFAdminManage.commentsGrid, {
	initComponent:function() {
        var config = {
			type: 'spam',
			width:670,
			renderTo:'comments_spam_grid',
			viewConfig: {
				forceFit:true,
				enableRowBody:true,
				showPreview:true,
				emptyText: 'There is no any comment marked as spam.',
				getRowClass: function(record, rowIndex, p, store) {
					if (this.showPreview) {
						p.body = '<div style = "margin-left: 3px;"> <p>' + record.data.text + '</p> <p style = " padding-top: 2px; border-top: 1px dashed #8db2e3;">In ' + record.data.WFItemTitle + ', ' + record.data.datetime.dateFormat('d/m/Y, H:i') + '</p> </div>';
						return 'x-grid3-row-expanded';
					}
					return 'x-grid3-row-collapsed';
				}
			},
			tbar: []
        };

        if ($('#manage_comments_permission').val()) {
            config.tbar.push(
            {
					id: 'button_notSpam',
					text:'Not spam',
					tooltip:'Mark selected comments as spam.',
					scope: this,
					handler: this.handleCommentActions
			});
        }

        if ($('#delete_comments_permission').val()) {
            if (config.tbar.length > 0) {
                config.tbar.push('-');
            }

            config.tbar.push(
            {
                text:'Delete',
                tooltip:'Delete selected comments.',
                scope: this,
                handler: this.handleDelete
            });
        }
		
		//Apply config.
		Ext.apply(this, Ext.apply(this.initialConfig, config));
		
		Ext.override(WFAdminManage.commentsGrid, {
			renderActions: function (value, p, record) {
                var actions = [];
                
                if ($('#manage_comments_permission').val()) {
                    actions.push('<a class = "act_notSpam">Not spam</a>');
                }

                if ($('#delete_comments_permission').val()) {
                    actions.push('<a class = "act_delete">Delete</a>');
                }
                
				return '<span class = "grid_actions">' + actions.join(' | ') + '</span>';
			}
		});
   
		//Call parent.
        WFAdminManage.spamCommentsGrid.superclass.initComponent.apply(this, arguments);
    }
});

WFAdminManage.grids = function() {
	 
    var grid; //Grid object.
	
	var gridId;
 
    /*****************/
    /*--Public Area--*/
    return { 
        /*--Public Properties--*/

        /*--Public Methods--*/
        init: function() { 

            /* Put initialization code here */
			Ext.BLANK_IMAGE_URL = $('#base_url').val() + '/libs/ExtJS/resources/images/default/s.gif';
			
			//var gridDiv = $('.grid:first').attr('id');
			gridId = $('.grid:first').attr('id');
			gridId = gridId.substr(0, gridId.lastIndexOf('_'));
			
             // get our Grid!
            this.getGrid(); // this = refers to properties and methods inside the public area
    
            // Works without this, used for state awareness...
            //Ext.state.Manager.setProvider(new Ext.state.CookieProvider());
        },//end of init
       
        getGrid: function() {  
            Ext.QuickTips.init(); //Enables Quicktips.
			
			switch (gridId) {
				case 'categories':
					grid = new WFAdminManage.categoriesGrid();
					break;
				case 'items':
					grid = new WFAdminManage.itemsGrid();
					break;
				case 'comments':
					grid = new WFAdminManage.regularCommentsGrid();
					break;
				case 'comments_spam':
					grid = new WFAdminManage.spamCommentsGrid();
					break;
				default:
					break;
			}
        }
    }
    /*--Public Area--*/
    /*****************/
}();

Ext.onReady(WFAdminManage.grids.init, WFAdminManage.grids, true);