/**
 * Webfolio CMS
 *
 * Copyright (C) 2009 Nikola Posa (http://www.nikolaposa.in.rs)
 *
 * This file is part of Webfolio CMS.
 *
 * Webfolio CMS is free software: you can redistribute it and/or modify 
 * it under the terms of the GNU General Public License as published by 
 * the Free Software Foundation, either version 3 of the License, or 
 * (at your option) any later version.
 *
 * Webfolio CMS is distributed in the hope that it will be useful, but 
 * WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU 
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License 
 * along with Webfolio CMS. If not, see <http://www.gnu.org/licenses/>.
 */
 
/**
 * Grid for managing modules.
 *
 * @author Nikola Posa <posa.nikola@gmail.com>
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License
 */
 
Ext.namespace('WFAdmin');

WFAdmin.modules = Ext.extend(Ext.grid.GridPanel, {
	initComponent: function() {
		var sm = new Ext.grid.CheckboxSelectionModel();
	
		var store = new Ext.data.JsonStore({
				url: $('#base_url').val() + '/front-end/ajax_handlers/admin/modules_grid.php', 
				baseParams: { 
					action: 'get'
				},
				root: 'modules',
				fields: [
					{name: 'name', type: 'string', mapping: 'name'},
					{name: 'uri', type: 'string', mapping: 'uri'},
					{name: 'description', type: 'string', mapping: 'description'},
					{name: 'version', type: 'string', mapping: 'version'},
					{name: 'author', type: 'string', mapping: 'author'},
					{name: 'dirName', type: 'string', mapping: 'dirName'},
					{name: 'active', type: 'int', mapping: 'active'},
                    {name: 'offerUpdate', type: 'boolean', mapping: 'offerUpdate'}
				]
		});
		
		var config = {	
			renderTo:'modules_grid',
			width: 650,
            height: 500,
			enableColumnHide: false,
			store: store,
			columns:[
				sm,
                {
                    header: 'Module',
                    width: 200,
                    dataIndex: 'name',
					renderer: this.renderModuleInfo,
					sortable: true
                },
				{
                    header: 'Actions',
                    width: 100,
                    dataIndex: 'id',
                    renderer: this.renderActions
                }
			],
			loadMask: true,
			disableSelection: true,
            sm: sm,
			
			viewConfig: {
                forceFit:true,
                emptyText: 'There is no any additional module in your app/modules directory.',
				enableRowBody:true,
                getRowClass : function(record, rowIndex, p, store){
					var background = '';
					if (record.data.active == 1) {
						background = ' background-color: #F0FFF0;';
					}
					
					p.body = '<div style = "margin-left: 3px; padding: 3px;' + background + '"> <p>' + record.data.description + '</p> <p style = " padding-top: 2px; border-top: 1px dashed;">Author(s): ' + record.data.author + ' | Version: ' + record.data.version + '</p> </div>';
					
					return 'x-grid3-row-expanded';
                }
            },
        
            tbar: [
				{
					text: 'Activate',
					tooltip: 'Activate selected modules.',
                    itemId: 'button_activate',
					scope: this,
					handler: this.handleTbar
				},
				{
					text: 'Deactivate',
					tooltip: 'Deactivate selected modules.',
                    itemId: 'button_deactivate',
					scope: this,
					handler: this.handleTbar
				},
				{
					text: 'Delete',
					tooltip: 'Delete selected modules.',
                    itemId: 'button_delete',
					scope: this,
					handler: this.handleTbar
				}
			]
		};

        if (!$('#manage_modules_permission').val()) {
            config.tbar = [];
        }
  
		//Apply config.
		Ext.apply(this, Ext.apply(this.initialConfig, config));

        this.on('beforerender', function(){
            if (!$('#manage_modules_permission').val()) {
                this.getColumnModel().setHidden(2, true);
            }
        });
   
		//Call parent.
		WFAdmin.modules.superclass.initComponent.apply(this, arguments);
	},

	onRender:function() {
		this.store.load();
		WFAdmin.modules.superclass.onRender.apply(this, arguments);
	},
	
	onClick: function(e) {
		var btn = e.getTarget('.grid_actions');        
		
		if (btn) {
			var t = e.getTarget();          
			var action = t.className.split('_')[1];
            switch (action) {
                case 'activate': case 'deactivate': case 'update':
                    this.doAction(action);
                    break;
                case 'delete':
                    Ext.MessageBox.confirm('Confirmation', 'Are you sure you want to delete this module?', this.doDelete, this);
                    break;
            }
		}            
	},
	
	renderFileName:function (value, p, record) {
		if (value.indexOf('://') == -1) {
			return String.format(value.substr(value.lastIndexOf('/') + 1));
		}
		else {
			return String.format(value);
		}
	},
	
	renderModuleInfo:function (value, p, record) {
		var name = '<span style = "font-size: 14px; font-weight: bold;">' + value + '</span>';
		var moduleName = (record.data.uri.length > 0) ? '<a href = "' + record.data.uri + '">' + name + '</a>' : name;
		
		return String.format(moduleName);
	},
	
	renderActions:function (value, p, record) {
        var actions = [];

		if (record.data.active == 1) {
            actions.push('<a class = "act_deactivate">Deactivate</a>');
		}
		else {
            actions.push('<a class = "act_activate">Activate</a>');
            actions.push('<a class = "act_delete">Delete</a></span>');
		}

        if (record.data.offerUpdate) {
             actions.push('<a class = "act_update">Update</a></span>');
        }

		return '<span class = "grid_actions">' + actions.join(' | ') + '</span>';
	},
    
    handleTbar:function(button, event) {
        var buttonId = button.initialConfig.itemId;
        var action = buttonId.substr(7);
        
        switch(action) {
            case 'activate': case 'deactivate':
                var selectedKeys = this.selModel.selections.keys; //returns array of selected rows ids only

                var sLength = selectedKeys.length;
                if (sLength > 0)
                {
                    this.doAction(action);
                }
                else {
                    Ext.MessageBox.alert('Note','You must select at least one module to proced.');
                }

                break;
            case 'delete':
                var selectedKeys = this.selModel.selections.keys; //returns array of selected rows ids only

                var sLength = selectedKeys.length;
                if (sLength > 0)
                {
                    var text = 'selected modules';
                    if (sLength == 1) {
                        text = 'this module';
                    }

                    var selectedRecords = this.selModel.getSelections();

                    var marker = 0;
                    //Checking whether user selected some module that is active.
                    for (var i = 0; i < selectedRecords.length; i++) {
                        if (selectedRecords[i].data.active == 1) {
                            marker = 1;
                            Ext.MessageBox.alert('Note','Module ' + selectedRecords[i].data.name + ' is active and it can not be deleted.');
                            break;
                        }
                    }

                    if (marker == 0) {	//No active modules selected? We can then delete selected modules...
                        Ext.MessageBox.confirm('Confirmation', 'Are you sure you want to delete ' + text + '?', this.doDelete, this);
                    }
                }
                else
                {
                    Ext.MessageBox.alert('Note','You must select at least one module to proced.');
                }
                
                break;
        }
    },
	
	doDelete:function(btn) {
		if (btn == 'yes') {
			this.doAction('delete');
		}
	},
	
	doAction:function(action) {
		Ext.Ajax.request( 
		{   
			url: $('#base_url').val() + '/front-end/ajax_handlers/admin/modules_grid.php', 
			params: { 
				action: action,
				dirs: this.getSelectedModules()
			},
			scope: this,
			success: function(response, options) {
				if (response.responseText == 'ok') {
					this.store.reload();
				}
				else {
					Ext.MessageBox.alert('Error', response.responseText);
				}
			}                                      
		});
	},
	
	getSelectedModules: function() {
		var selectedRecords = this.selModel.getSelections(); 
		
		var modules = new Array();
		for (var i = 0; i < selectedRecords.length; i++) {
			modules[i] = selectedRecords[i].data.dirName;
		}
           
		return Ext.encode(modules);
	}
});

Ext.onReady(function() {
	Ext.BLANK_IMAGE_URL = $('#base_url').val() + '/libs/ExtJS/resources/images/default/s.gif';
 
	Ext.QuickTips.init();
	
	var modulesGrid = new WFAdmin.modules();
});