/**
 * Webfolio CMS
 *
 * Copyright (C) 2009 Nikola Posa (http://www.nikolaposa.in.rs)
 *
 * This file is part of Webfolio CMS.
 *
 * Webfolio CMS is free software: you can redistribute it and/or modify 
 * it under the terms of the GNU General Public License as published by 
 * the Free Software Foundation, either version 3 of the License, or 
 * (at your option) any later version.
 *
 * Webfolio CMS is distributed in the hope that it will be useful, but 
 * WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU 
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License 
 * along with Webfolio CMS. If not, see <http://www.gnu.org/licenses/>.
 */
 
/**
 * Sidebar drag&drop panel.
 *
 * @author Nikola Posa <posa.nikola@gmail.com>
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License
 */

WFAdminFrontEnd.optionalSidebarItems = Ext.extend(WFAdminFrontEnd.dragDropAbstract, {
	initComponent:function() {
		var config = {
			store:new Ext.data.JsonStore({
				url: $('#base_url').val() + '/front-end/ajax_handlers/admin/sidebar_panel.php', 
				baseParams: {action: 'get', type: 'optional'},
				root: 'items',
				fields: [
					{name: 'helperName', type: 'string', mapping: 'helperName'},
					{name: 'userFriendlyName', type: 'string', mapping: 'userFriendlyName'},
					{name: 'module', type: 'string', mapping: 'module'},
					{name: 'title', type: 'string', mapping: 'title'},
					{name: 'settings', type: 'auto', mapping: 'settings'}
				]
			})
			,columns:[{
				dataIndex:'userFriendlyName'
				,header:'Available items'
				}
			]
			,enableColumnHide: false
		};

        if (!$('#manage_sidebar_permission').val()) {
            config.enableDragDrop = false;
        }
  
		//Apply config.
		Ext.apply(this, Ext.apply(this.initialConfig, config));
   
		//Call parent.
		WFAdminFrontEnd.optionalSidebarItems.superclass.initComponent.apply(this, arguments);
	}

	,onRender:function() {
		this.store.load();
		WFAdminFrontEnd.optionalSidebarItems.superclass.onRender.apply(this, arguments);
	}	
});
 
//Register xtype.
Ext.reg('optionalsidebaritems', WFAdminFrontEnd.optionalSidebarItems);

WFAdminFrontEnd.selectedSidebarItems = Ext.extend(WFAdminFrontEnd.dragDropAbstract, {
	initComponent:function() {
		var config = {
			store:new Ext.data.JsonStore({
				url: $('#base_url').val() + '/front-end/ajax_handlers/admin/sidebar_panel.php', 
				baseParams: {action: 'get', type: 'selected'},
				root: 'items',
				fields: [
					{name: 'helperName', type: 'string', mapping: 'helperName'},
					{name: 'userFriendlyName', type: 'string', mapping: 'userFriendlyName'},
					{name: 'module', type: 'string', mapping: 'module'},
					{name: 'title', type: 'string', mapping: 'title'},
					{name: 'settings', type: 'auto', mapping: 'settings'}
				]
			})
			,columns:[{
				dataIndex:'userFriendlyName'
				,header:'Current sidebar scheme'
				//,renderer: this.renderSelectedItem
				}
				,{
					header: 'Actions'
					,width: 50
					,renderer: this.renderActions
				}
			]
			,enableColumnHide: false
		};

        if (!$('#manage_sidebar_permission').val()) {
            config.enableDragDrop = false;
        }
  
		//Apply config.
		Ext.apply(this, Ext.apply(this.initialConfig, config));

        this.on('beforerender', function(){
            if (!$('#manage_sidebar_permission').val()) {
                this.getColumnModel().setHidden(1, true);
            }
        });
   
		//Call parent.
		WFAdminFrontEnd.selectedSidebarItems.superclass.initComponent.apply(this, arguments);
	}
	
	,onRender:function() {
		this.store.load();
		WFAdminFrontEnd.selectedSidebarItems.superclass.onRender.apply(this, arguments);
	}
	
	,renderActions: function (value, p, record) {
		var actions = '<span class = "grid_actions"><a class = "act_title" style = "cursor: pointer;">Set title</a></span>';
		
		if (record.data.settings) {
			actions += ' | <span class = "grid_actions"><a class = "act_settings" style = "cursor: pointer;">Settings</a></span>';
		}
		
		return actions;
	}
	
	,onClick: function(e) {
		var btn = e.getTarget('.grid_actions');        
		
		if (btn) {
			var t = e.getTarget(); 
			var v = this.getView();			
			var action = t.className.split('_')[1];
			
			var index = v.findRowIndex(t);
			var record = this.store.getAt(index);
					
			switch (action) {
				case 'title': //Editing title of some sidebar item.
				{
					Ext.Msg.prompt('Title', '', function(btn, text) {
						if (btn == 'ok'){
							record.set('title', text);
							record.commit();
						}
					}, this, false, record.data.title);
					
					break;
				}
				case 'settings': //Editing settings sidebar item.
				{
					Ext.Ajax.request( 
					{   
						url: $('#base_url').val() + '/front-end/ajax_handlers/' + ((record.data.module != 'default') ? record.data.module : '') + '/' + record.data.helperName.toLowerCase() + '_settings.php',
						params: { 
							data: Ext.encode(record.data.settings)
						},
						success: function(response, options) {
							var win = new Ext.Window({
								modal: true
								,width:250
								,height:350
								,html: response.responseText
							});
							win.addButton("Ok", function(btn, e) {
								var settings = record.data.settings;
								var values = $(":input").serializeArray(); //Data from the form.
								
								 //Reseting current settings.
								 for (var i in settings) {
									if ($.isArray(settings[i])) {
										settings[i] = new Array();
									}
									else {
										settings[i] = '';
									}
								 }
								 
								jQuery.each(values, function(i, field){
									if (settings[field.name] != undefined) {
										if ($.isArray(settings[field.name])) {
											settings[field.name].push(field.value);
										}
										else {
											settings[field.name] = field.value;
										}
									}
								});
								
								record.set('settings', settings);
								record.commit();
								win.destroy();
								 
							}, this);
							win.addButton("Cancel", win.destroy, win);
							win.show();
						}                                      
					});
				}
			}
		}            
	}
});
   
//Register xtype.
Ext.reg('selectedsidebaritems', WFAdminFrontEnd.selectedSidebarItems);
  
//Main entry point.
Ext.onReady(function() {
	Ext.BLANK_IMAGE_URL = $('#base_url').val() + '/libs/ExtJS/resources/images/default/s.gif';
 
	Ext.QuickTips.init();

    var panelItems = [
        {
            xtype:'optionalsidebaritems'
            ,id: 'optionalItems'
            ,region:'west'
            ,width:340
            ,split:true
        }
        ,{
            xtype:'selectedsidebaritems'
            ,id: 'selectedItems'
            ,region:'center'
            ,width:340
        }
    ];

    if ($('#manage_sidebar_permission').val()) {
        panelItems.push(
        {
            xtype:'toolbar'
            ,items: {
                xtype:'button'
                ,text: 'Save'
                ,width: 70
                ,x: 307
                ,y: 4
                ,handler: function (b, e) {
                    var items = new Array();
                    var selectedItems = this.ownerCt.ownerCt.items.get('selectedItems').store.getRange();

                    for (var i in selectedItems) {
                        items[i] = selectedItems[i].data;
                    }

                    var data = Ext.encode(items);

                    Ext.Ajax.request(
                    {
                        url: $('#base_url').val() + '/front-end/ajax_handlers/admin/sidebar_panel.php',
                        params: {
                            action: 'save',
                            data: data
                        },
                        success: function(response, options) {
                            if (response.responseText == 'ok') {
                                Ext.MessageBox.alert('Message', 'Your sidebar scheme has been saved.');
                            }
                            else {
                                Ext.MessageBox.alert('Error', response.responseText);
                            }
                        }
                    });
                }
            }
            ,height: 30
            ,region:'south'
            ,layout: 'absolute'
        }
        );
    }


	//Create and show window.
	var panel = new Ext.Panel({
		layout:'border'
		,width:680
		,height:400
		,frame: true
		,renderTo: 'sidebar_panel'
		,items:panelItems
	});
}); 