/**
 * Webfolio CMS
 *
 * Copyright (C) 2009 Nikola Posa (http://www.nikolaposa.in.rs)
 *
 * This file is part of Webfolio CMS.
 *
 * Webfolio CMS is free software: you can redistribute it and/or modify 
 * it under the terms of the GNU General Public License as published by 
 * the Free Software Foundation, either version 3 of the License, or 
 * (at your option) any later version.
 *
 * Webfolio CMS is distributed in the hope that it will be useful, but 
 * WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU 
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License 
 * along with Webfolio CMS. If not, see <http://www.gnu.org/licenses/>.
 */
 
/**
 * Panel for managing themes.
 *
 * @author Nikola Posa <posa.nikola@gmail.com>
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License
 */
 
Ext.namespace('WFAdminFrontEnd');

WFAdminFrontEnd.themesGrid = Ext.extend(Ext.grid.GridPanel, {
    activeTheme: '',
	initComponent:function() {
		var config = {
			renderTo:'themes_grid',
			width:930,
			height:800,
			store:new Ext.data.JsonStore({
				url: $('#base_url').val() + '/front-end/ajax_handlers/admin/themes_panel.php', 
				root: 'themes',
				fields: [
					{name: 'name', type: 'string', mapping: 'name'},
					{name: 'uri', type: 'string', mapping: 'uri'},
					{name: 'description', type: 'string', mapping: 'description'},
					{name: 'version', type: 'string', mapping: 'version'},
					{name: 'author', type: 'string', mapping: 'author'},
					{name: 'dirName', type: 'string', mapping: 'dirName'},
					{name: 'screenshot', type: 'string', mapping: 'screenshot'},
					{name: 'active', type: 'int', mapping: 'active'}
				]
			}),
			viewConfig: {
                forceFit:true,
				enableRowBody:true,
                getRowClass : function(record, rowIndex, p, store) {
					var backgroundClass = '';
					if (record.data.active == 1) {
						backgroundClass = ' active-theme';
					}
					
					return 'x-grid3-row-expanded' + backgroundClass;
                }
            },
			columns:[
				{
					header: 'Activate',
					dataIndex: 'dirName',
                    scope: this,
					renderer: this.renderActivation,
					tooltip: 'Click on a radio button to activate theme.',
					css: 'padding-top: 100px;',
					hideable: false
				},
				{
					header: 'Preview',
					width: 310,
					dataIndex: 'dirName',
					renderer: this.renderPreview
				},
				{
					header: 'Info',
					width: 310,
					dataIndex: 'name',
					renderer: this.renderInfo
				},
				{
					header: 'Actions',
					align: 'center',
					dataIndex: 'dirName',
					renderer: this.renderActions,
					css: 'padding-top: 100px;',
					hideable: false
				}
			]
		};
  
		//Apply config.
		Ext.apply(this, Ext.apply(this.initialConfig, config));

        this.on('beforerender', function(){
            if (!$('#change_themes_permission').val()) {
                this.getColumnModel().setHidden(0, true);
            }

            if (!$('#edit_themes_permission').val()) {
                this.getColumnModel().setHidden(3, true);
            }
        });
   
		//Call parent.
		WFAdminFrontEnd.themesGrid.superclass.initComponent.apply(this, arguments);
	}
	
	,onRender:function() {
		this.store.load();
		WFAdminFrontEnd.themesGrid.superclass.onRender.apply(this, arguments);
	}

    ,onClick: function(e) {
		var t = e.getTarget();
        var el = Ext.get(t);
        if ((type = el.getAttribute('type')) && type == 'radio') {
            if ((themeDirName = el.getValue()) != $('#activeTheme').val()) { //Not already activated?
                this.activateTheme(themeDirName, true);
            }
        }
        else if (el.parent().hasClass('screenshot')) { //Image preview?
            this.themePreview(el.parent().getAttribute('id'));
        }
	}
	
	,renderActivation: function (value, p, record) {
		var checked = '';
		
		if (record.data.active == 1) {
			checked = ' checked = "checked"';
            this.activeTheme = value;
		}
		
		return '<input type = "radio" name="activate_theme" ' + checked + ' value="' + value + '" />';
	}
	
	,renderPreview: function (value, p, record) {
		return '<div class = "screenshot" id="' + value + '">' + record.data.screenshot + '</div>';
	}
	
	,renderInfo: function (value, p, record) {
		var themeName = value;
						
		if (record.data.uri.length > 0) {
			themeName = '<a href = "' + record.data.uri + '" rel = "nofollow">' + themeName + '</a>';
		}
						
		return '<div><h3 style = "font-weight: bold;">' + themeName + '</h3><p>' + record.data.description + '</p><span>Author(s): ' + record.data.author + '</span></div>';
	}
	
	,renderActions: function (value, p, record) {
		return '<a href = "' + $('#base_url').val() + '/admin/appearance/themes/edit/' + value + '">Edit</a>';
	}

    ,themePreview: function (themeDirName) {
        this.activateTheme(themeDirName, false);

        this.showPreview.defer(500, this, [themeDirName]);
    }

    ,showPreview: function (themeDirName) {
        var options = {
            content:    $('#site_url').val(),
            player:     'iframe',
            width:      800,
            height:     600
        }

       if ($('#change_themes_permission').val()) {
            options.title = '<a class="activate_from_preview" id="' + themeDirName + '" href = "javascript: void(0);" style="color: #FFFFFF;">Activate</a>';
        }

        Shadowbox.open(options);
    }

    ,activateTheme: function (themeDirName, redirect) {
        $.ajax({
            type: 'POST',
            url: $('#base_url').val() + '/front-end/ajax_handlers/admin/theme_activate.php',
            data: 'themeDirName=' + encodeURIComponent(themeDirName),
            success: function(msg) {
                if (msg == 'ok' && redirect == true) {
                    window.location = $('#base_url').val() + '/admin/appearance/themes';
                }
            }
        });
    }
});
   
Ext.onReady(function() {
	Ext.BLANK_IMAGE_URL = $('#base_url').val() + '/libs/ExtJS/resources/images/default/s.gif';
 
	Ext.QuickTips.init();
   
	var themesGrid = new WFAdminFrontEnd.themesGrid();

   Shadowbox.init({
        onClose: function(elem) {
            themesGrid.activateTheme(themesGrid.activeTheme);
        }
    });

    $('.activate_from_preview').live('click', function () {
        themesGrid.activateTheme($(this).attr('id'), true);
    });
});