/**
 * Webfolio CMS
 *
 * Copyright (C) 2009 Nikola Posa (http://www.nikolaposa.in.rs)
 *
 * This file is part of Webfolio CMS.
 *
 * Webfolio CMS is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Webfolio CMS is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Webfolio CMS. If not, see <http://www.gnu.org/licenses/>.
 */

Ext.namespace('WFAdmin'); 

WFAdmin.usersGrid = Ext.extend(WFAdmin.basicGrid, {
	initComponent: function() {
        var groupsCombo = new Ext.form.ComboBox({
            store: new Ext.data.JsonStore({
				url: $('#base_url').val() + '/front-end/ajax_handlers/admin/users_groups_grid.php',
                method: 'POST',
                baseParams: {action: 'groups'},
                root: 'groups', // name of the property that is container for an Array of row objects
				fields: [
					{name: 'id'},
                    {name: 'name'}
				]
			}),
            mode: 'remote',
            valueField: 'id',
            displayField: 'name',
            emptyText : 'Change group to...',
            itemId: 'groupsCombo',
            editable: false,
            forceSelection: true,
            triggerAction: 'all'
        });

		var config = {
			action: 'user',
			width:900,
			height:600,
			store:new Ext.data.JsonStore({
				url: $('#base_url').val() + '/front-end/ajax_handlers/admin/users_groups_grid.php',
                method: 'POST',
                baseParams: {action: 'users'},
                root: 'users', // name of the property that is container for an Array of row objects
                id: 'id',
				fields: [
					{name: 'id', type: 'int', mapping: 'id'},
                    {name: 'username', type: 'string', mapping: 'username'},
                    {name: 'public_name', type: 'string', mapping: 'public_name'},
                    {name: 'email', type: 'string', mapping: 'email'},
                    {name: 'group', type: 'string', mapping: 'group'}
				]
			}),
			viewConfig: {
				forceFit:true,
				emptyText: 'Currently, there is no any user.'
			},
			columns:[
				this.sm,
				{
                    header: "Username",
                    width: 200,
                    sortable: true,
                    dataIndex: 'username',
                    renderer: this.renderUsername
				}
                ,{
                    header: "Name",
                    width: 200,
                    sortable: true,
                    dataIndex: 'public_name'
				}
                ,{
                    header: "Email",
                    width: 200,
                    sortable: false,
                    dataIndex: 'email'
				}
                ,{
                    header: "Group",
                    width: 200,
                    sortable: true,
                    dataIndex: 'group'
				}
                ,{
					header: 'Actions',
					width: 100,
					dataIndex: 'id',
                    scope: this,
					renderer: this.renderActions,
					hideable: false
				}
			],
			tbar: []
		};

        if ($('#delete_users_permission').val()) {
            config.tbar.push(
                {
                    text: 'Delete',
                    tooltip: 'Click to delete selected users.',
                    scope: this,
                    handler: this.handleDelete
                }
            );
        }

        if ($('#edit_users_permission').val()) { //Edit permission is needed for changing user's group.
            if (config.tbar.length > 0) {
                config.tbar.push('-');
            }

            config.tbar.push(
                groupsCombo,
                {
                    text: 'Change',
                    scope: this,
                    handler: this.handleAssign
                }
            );
        }

		//Apply config.
		Ext.apply(this, Ext.apply(this.initialConfig, config));

		//Call parent.
        WFAdmin.usersGrid.superclass.initComponent.apply(this, arguments);
    },

    onRender:function() {
        this.store.load();

        WFAdmin.usersGrid.superclass.onRender.apply(this, arguments);
    },

    onClick: function(e) {
		var btn = e.getTarget('.grid_actions');

		if (btn) {
			var t = e.getTarget();
			var action = t.className.split('_')[1];
			switch (action) {
                case 'edit':
				{
					var v = this.getView();
                    var recordIndex = v.findRowIndex(t);
                    var record = this.store.getAt(recordIndex);

                    var url = $('#base_url').val() + '/admin/users/edit/' + record.data.id;

                    window.open(url, '', 'top=' + (e.getPageY() - 100) + ', left=' + (e.getPageY() + 20) + ', width=400, height=300, scrollbars=yes, location=no, status=no, toolbar=no');
					break;
				}
				case 'delete':
				{
					this.handleDelete();
					break;
				}
			}
		}
	},

    renderUsername: function (val, p, record) {
        return ($('#edit_users_permission').val() || record.data.id == $('#user_id').val()) ? '<a href = "' + $('#base_url').val() + '/admin/users/edit/' + record.data.id + '">' + val + '</a>' : val;
	},

    renderActions: function (val) {
        var actions = [];
        if ($('#edit_users_permission').val() || val == $('#user_id').val()) {
            actions.push('<a href = "' + $('#base_url').val() + '/admin/users/edit/' + val + '">Edit</a>');
        }

        if ($('#delete_users_permission').val()) {
            actions.push('<a class = "act_delete">Delete</a>');
        }

        return '<span class = "grid_actions">' + actions.join(' | ') + '</span>';
	},

    handleAssign: function () {
        var selectedKeys = this.selModel.selections.keys;
		var sLength = selectedKeys.length;

        var groupId = this.getTopToolbar().getComponent('groupsCombo').getValue();

        if (sLength == 0) {
            Ext.MessageBox.alert('Note','You must select at least one user to proced.');
        }
        else if (!groupId) {
            Ext.MessageBox.alert('Note','You must choose some group.');
        }
		else {
            var users = Ext.encode(selectedKeys);
            
            Ext.Ajax.request(
			{
				url: $('#base_url').val() + '/front-end/ajax_handlers/admin/assign_to_group.php',
				params: {
					users: users,
					group: groupId
				},
				scope: this,
				success: function(response, options) {
					if (response.responseText == 'ok') {
						this.store.reload();
					}
					else {
						Ext.MessageBox.alert('Error', response.responseText);
					}
				}
			});
		}
    },
    doDelete: function (btn) { //override
		if (btn == 'yes') {
            var selectedKeys = this.selModel.selections.keys;
			var selectedUsers = Ext.encode(selectedKeys);
            
			Ext.Ajax.request(
            {
                url: $('#base_url').val() + '/front-end/ajax_handlers/admin/user_delete.php',
                scope: this,
                params: {
                    action: 'offer',
                    selected_users: selectedUsers
                },
                success: function(response, options) {
                    var win = new Ext.Window({
                        modal: true
                        ,width:320
                        ,height:200
                        ,html: response.responseText
                    });
                    win.addButton("Ok", function(btn1, e) {
                        var params = {action: 'execute', id: selectedUsers};
                        params.user_delete_action = $(":radio:checked").val();
                        if (params.user_delete_action == 'assign') {
                            params.assign_to = $("select#user_id").val();
                        }

                        Ext.Ajax.request(
                        {
                            url: $('#base_url').val() + '/front-end/ajax_handlers/admin/user_delete.php',
                            params: params,
                            scope: this,
                            success: function(response, options) {
                                win.destroy();
                                
                                if (response.responseText == 'ok') {
                                    WFAdmin.usersGrid.superclass.doDelete.call(this, 'yes');
                                }
                                else {
                                    Ext.MessageBox.alert('Error', response.responseText);
                                }
                            }
                        });

                    }, this);
                    win.show();
                }
            });
		}
	}
});

Ext.onReady(function() {
	Ext.BLANK_IMAGE_URL = $('#base_url').val() + '/libs/ExtJS/resources/images/default/s.gif';

	Ext.QuickTips.init();

	var usersGrid = new WFAdmin.usersGrid();
    usersGrid.render('users_grid');
});