/**
 * Webfolio CMS
 *
 * Copyright (C) 2009 Nikola Posa (http://www.nikolaposa.in.rs)
 *
 * This file is part of Webfolio CMS.
 *
 * Webfolio CMS is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Webfolio CMS is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Webfolio CMS. If not, see <http://www.gnu.org/licenses/>.
 */

(function($) {
  
var EVENT_TOGGLE = 'toggle',
    options  = {
        collapseFromLevel: 1,
        activeClass: 'active',
        collapsibleClass: 'collapsible',
        collapsedClass: 'collapsed',
        eventType: 'click'
    };

function log() {
    if (window.console && window.console.log) {
        window.console.log('[collapsibleMenu] ' + Array.prototype.join.call(arguments,' '));
    }
}

$.fn.collapsibleMenu = function(opts) {
    options = $.extend($.fn.collapsibleMenu.defaults, opts);

    var elem = this[0];
    var $this = $(elem);
    if ((/ul/i.test(elem.tagName))) { //Only ul tag is allowed.
        var $menuItems = $this.find("li:has(ul)");
        if ($menuItems.length > 0) { //Found something?
            //Preparing toggler functionality.
            $menuItems.addClass(options.collapsibleClass);

            //Collapsing menu items which are non-active and on the appropriate level.
            var $validMenuItems = $menuItems.filter(function(i) {
                return (
                    !$(this).hasClass(options.activeClass) //Not active branch?
                    && $(this).parents('ul').length >= options.collapseFromLevel //Level ok?
                );
            });
            $validMenuItems.children('ul').hide();
            $validMenuItems.addClass(options.collapsedClass);

            //Enabling toggling based on selected "eventType".
            var toggle = $.fn.collapsibleMenu.eventType[options.eventType];
            if ($.isFunction(toggle)) {
                toggle($menuItems);
            }
            else {
                log('invalid event type: ' + options.eventType);
            }

            $menuItems.bind(EVENT_TOGGLE, function(event){
                $(event.target).toggleClass(options.collapsedClass);
            });
        }
    }
};

$.fn.collapsibleMenu.getOptions = function() {
    return options;
}

$.fn.collapsibleMenu.defaults = options;

$.fn.collapsibleMenu.eventType = {
    click: function($menuItems) {
        $menuItems.prepend('<span class="toggler">+</span>');
        $menuItems.not('.' + $.fn.collapsibleMenu.getOptions().collapsedClass).children('.toggler').html('-');
        
        $menuItems.bind('click', function(event) {
            var targetTagName = event.target.tagName;
            var $target = $(event.target);

            if (targetTagName != 'a' && targetTagName != 'A') { //Don't trigger on links.
                event.stopPropagation();

                if ((targetTagName == 'span' || targetTagName == 'SPAN')) { //Toggler?
                    $target = $target.parent('li:first');
                }
                
                var $ul = $target.children('ul').first();

                if ($ul.is(':hidden')) {
                    $target.children('.toggler').html('-');
                    $ul.show();
                }
                else {
                    $target.children('.toggler').html('+');
                    $ul.hide();
                }

                $target.triggerHandler(EVENT_TOGGLE);
            }
        });
    },
    hover: function($menuItems) {
        $menuItems.bind('mouseover', function(event) {
            if (!$(event.target).hasClass($.fn.collapsibleMenu.getOptions().activeClass)) {
                $(event.target).nextAll('ul').first().show();
                //$(event.target).triggerHandler(EVENT_TOGGLE);
            }
        }).bind('mouseleave', function(event) {
            if (!$(event.target).hasClass($.fn.collapsibleMenu.getOptions().activeClass)) {
                $(event.target).children('ul').hide();
                //$(event.target).triggerHandler(EVENT_TOGGLE);
            }
        });
    }
};

})(jQuery);