/**
 * Webfolio CMS
 *
 * Copyright (C) 2009 Nikola Posa (http://www.nikolaposa.in.rs)
 *
 * This file is part of Webfolio CMS.
 *
 * Webfolio CMS is free software: you can redistribute it and/or modify 
 * it under the terms of the GNU General Public License as published by 
 * the Free Software Foundation, either version 3 of the License, or 
 * (at your option) any later version.
 *
 * Webfolio CMS is distributed in the hope that it will be useful, but 
 * WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU 
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License 
 * along with Webfolio CMS. If not, see <http://www.gnu.org/licenses/>.
 */
 
Ext.namespace('WFTaxonomy');

WFTaxonomy.terms = Ext.extend(Ext.grid.GridPanel, {
    taxonomy: '',
    termsCustomParams: [],
    
    constructor: function(config) {
        if (config.taxonomy) {
            this.taxonomy = config.taxonomy;
        }

        if (config.termsCustomParams) {
            this.termsCustomParams = config.termsCustomParams;
        }

        WFTaxonomy.terms.superclass.constructor.apply(this, arguments);
    },

	initComponent: function() {
		var sm = new Ext.grid.CheckboxSelectionModel();
	
		var store = new Ext.data.JsonStore({
			url: $('#base_url').val() + '/front-end/ajax_handlers/taxonomy/get_terms.php', 
			baseParams: {taxonomy: this.taxonomy},
			root: 'terms',
			fields: [
				{name: 'id', type: 'int', mapping: 'id'},
				{name: 'name', type: 'string', mapping: 'name'},
				{name: 'depth', type: 'string', mapping: 'depth'}
			]
		});
		
		var config = {	
			renderTo:'terms_grid',
			width: 300,
            height: 300,
			store: store,
			columns:[
				sm,
                {
                    header: this.termsCustomParams.nameColLabel,
                    width: 200,
                    dataIndex: 'name',
					renderer: this.renderName,
					sortable: true
                },
				{
                    header: 'Actions',
                    width: 100,
                    dataIndex: 'id',
                    scope: this,
                    renderer: this.renderActions,
                    hideable: false
                }
			],
			disableSelection: true,
            sm: sm,
			
			viewConfig: {
                forceFit:true,
                emptyText: 'There is no any ' + this.termsCustomParams.keyword + ' to show.'
            },
        
            tbar: [{
				text: 'Delete',
				scope: this,
				handler: this.handleDelete
			}]
		};

        if (!$('#delete_' + this.taxonomy + '_permission').val()) {
            config.tbar = [];
        }
  
		//Apply config.
		Ext.apply(this, Ext.apply(this.initialConfig, config));

        this.on('beforerender', function(){
            if (!$('#delete_' + this.taxonomy + '_permission').val()) {
                this.getColumnModel().setHidden(0, true);
                if (!$('#edit_' + this.taxonomy + '_permission').val()) {
                    this.getColumnModel().setHidden(2, true);
                }
            }
        });
   
		//Call parent.
		WFTaxonomy.terms.superclass.initComponent.apply(this, arguments);
	},

	onRender:function() {
		this.store.load();
		WFTaxonomy.terms.superclass.onRender.apply(this, arguments);
	},
	
	onClick: function(e) {
		var btn = e.getTarget('.grid_actions');        
		
		if (btn) {
			var t = e.getTarget();          
			var action = t.className.split('_')[1];
			if (action == 'edit') {
				var v = this.getView();
				var recordIndex = v.findRowIndex(t);
				var record = this.store.getAt(recordIndex);
				
				var url = $('#base_url').val() + '/taxonomy/' + this.taxonomy + '/edit/' + record.data.id + '/1';
				
				var width = 400;
				var height = 300;
				
				var top = e.getPageY() - 300;
				var left = e.getPageX() + 20;
		
				window.open(url, '', 'top=' + top + ', left=' + left + ', width=' + width + ', height=' + height + ', scrollbars=yes, location=no, status=no, toolbar=no'); 
			}
			else if (action == 'delete') {
				this.handleDelete();
			}
		}            
	},
	
	renderName: function (value, p, record) {
		return '<span style = "margin-left: ' + (record.data.depth + 3) + 'px;">' + value + '</a>';
	},
	
	renderActions:function (value, p, record) {
        var actions = [];
        if ($('#edit_' + this.taxonomy + '_permission').val()) {
            actions.push('<a class = "act_edit">Edit</a>');
        }
        if ($('#delete_' + this.taxonomy + '_permission').val()) {
            actions.push('<a class = "act_delete">Delete</a></span>');
        }

		return '<span class = "grid_actions">' + actions.join(' | ') + '</span>';
	},

	handleDelete:function() {
		var selectedKeys = this.selModel.selections.keys; //returns array of selected rows ids only
           
		var sLength = selectedKeys.length;
		if (sLength > 0)
		{
			Ext.MessageBox.confirm('Confirmation', 'Are you sure you want to delete selection?', this.doDelete, this);
		}
		else
		{
			Ext.MessageBox.alert('Note','You must select at least one ' + this.termsCustomParams.keyword + ' to proced.');
		}
	},
	
	doDelete:function(btn) {
		if (btn == 'yes') {
			var selectedKeys = this.selModel.selections.keys;
			var ids = Ext.encode(selectedKeys);
			
			Ext.Ajax.request( 
			{   
				url: $('#base_url').val() + '/front-end/ajax_handlers/taxonomy/delete.php', 
				params: {
                    taxonomy: this.taxonomy,
					id: ids
				},
				scope: this,
				success: function(response, options) {
					if (response.responseText == 'ok') {
						this.store.reload();
					}
					else {
						Ext.MessageBox.alert('Error', response.responseText);
					}
				}                                      
			});
		}
	}
});