<?php
/**
 * Webfolio CMS
 *
 * Copyright (C) 2009 Nikola Posa (http://www.nikolaposa.in.rs)
 *
 * This file is part of Webfolio CMS.
 *
 * Webfolio CMS is free software: you can redistribute it and/or modify 
 * it under the terms of the GNU General Public License as published by 
 * the Free Software Foundation, either version 3 of the License, or 
 * (at your option) any later version.
 *
 * Webfolio CMS is distributed in the hope that it will be useful, but 
 * WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU 
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License 
 * along with Webfolio CMS. If not, see <http://www.gnu.org/licenses/>.
 */
 
/**
 * Webfolio CMS install script.
 *
 * @author Nikola Posa <posa.nikola@gmail.com>
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License
 */
include_once('wf_init.php');

include_once('Zend/Application.php');

try {
	$application = new Zend_Application(APPLICATION_ENV, include_once(APPLICATION_PATH . '/configs/wf_config.php'));
	$application->getBootstrap()->bootstrap(array('Autoloaders', 'DB', 'Cachemanager'));

	include_once(APPLICATION_PATH . '/modules/admin/forms/Install.php');
	include_once(APPLICATION_PATH . '/modules/admin/models/Update/Abstract.php');
	include_once(APPLICATION_PATH . '/modules/admin/models/Update/Core.php');
	include_once(APPLICATION_PATH . '/modules/admin/models/Install.php');

	$installModel = new Admin_Model_Install();
	 
	if ($installModel->isInstalled()) {
		$error = '<p>Webfolio CMS is already installed. If you want to reinstall it, please delete your old database tables first.</p>';
	}
	elseif (!empty($_POST)) {
		$formData = $_POST;
		
		$installForm = new Admin_Form_Install();
		
		if ($installForm->isValid($formData)) { //Valid data?	
			$data = $installForm->getValues();
			
			try {
				$installModel->install(array('site_title'=>$data['site_title'], 'admin_email'=>$data['email']));

                $userData = array_slice($data, 1, 3, true);

                //Fetching id of a Administrator group.
                $groupsDbTable = new Model_DbTable_WebfolioGroups();
                $adminGroup = $groupsDbTable->fetchRow('name = \'Administrator\'');

                $userData['group_id'] = (int)$adminGroup['id'];
				$webfolioUser = new Model_WebfolioUsers($userData);
				$webfolioUser->save();
				
				$message = 'Congratulations! Webfolio CMS has been successfully installed on your site. You\'ll be redirected to login page in <span id = "seconds">3</span> seconds. <br />
				<span style = "font-size: 11px;"><a href = "' . Model_WebfolioSettings::getSettings('base_url') . '/admin/login">Click here if your browser doesn\'t not automatically redirect you.</a></span>';
				$ok = true;
			}
			catch (Exception $ex) {
				$message = 'An error occurred and Webfolio CMS can not be installed on your site at the moment.';
				$ok = false;
			}
		}
		else {
			$errorMessages = $installForm->getMessages();
			
			$fieldValues = $formData;
		}
	}
	else {
		$password = Text_Password::create(12, 'unpronounceable');
		
		$password = $password;
	}
}
catch (Exception $ex) {
	$error = '<p>An error occurred and Webfolio CMS can not be installed on your site at the moment. Please check and double-check information that you\'ve entered in app/configs/wf_config.php file, and then try again.</p>';
}

include_once(APPLICATION_PATH . '/modules/admin/views/scripts/install/index.phtml'); 
?>