<?php
/** 
 * Webfolio CMS
 * 
 * Copyright (C) 2009 Nikola Posa (http://www.nikolaposa.in.rs)
 * 
 * This file is part of Webfolio CMS.
 * 
 * Webfolio CMS is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Webfolio CMS is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Webfolio CMS. If not, see <http://www.gnu.org/licenses/>.
 */

/**
 * Custom ACL class of this CMS.
 *
 * @author Nikola Posa <posa.nikola@gmail.com>
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License
 */
class WebfolioCMS_Acl extends Zend_Acl
{
    const CACHE_ID = 'wf_acl';

    /**
     * Constructor.
     *
     * @return void
     */
    public function  __construct()
    {
        $this->_init();
    }

    /**
     * Initializing ACL object.
     *
     * @return void
     */
    protected function _init()
    {
        $this->_initRoles();
        $this->_initResources();
        $this->_addRules();
    }

    /**
     * Adding roles, or in other words, all the existing user
     * groups.
     *
     * @return void
     */
    protected function _initRoles()
    {
        $wfGroupsDbTable = new Model_WebfolioGroups();
        $groups = $wfGroupsDbTable->fetchAll(null, 'id ASC');

        foreach ($groups as $group) {
            $this->addRole((string)$group['id']);
        }
    }

    /**
     * Adding resources which are registered through
     * Admin_Model_WFAdminGroupPermissions hook container.
     *
     * @return void
     */
    protected function _initResources()
    {
        $resources = array();

        foreach (Admin_Model_WFAdminGroupPermissions::get() as $groupPermData) {
            foreach ($groupPermData as $data) {
                if (isset($data['rules']['resource']) && !in_array($data['rules']['resource'], $resources)) { //Single rule?
                    $resources[] = $data['rules']['resource'];
                }
                else { //Multiple rules.
                    foreach ($data['rules'] as $rule) {
                        if (!in_array($rule['resource'], $resources)) {
                            $resources[] = $rule['resource'];
                        }
                    }
                }
            }
        }

        //Adding resources gathered from default group acls array, too.
        foreach (Model_DbTable_WebfolioGroupAcl::getDefaultGroupACLs() as $acl) {
            if (!in_array($acl['resource'], $resources)) {
                $resources[] = $acl['resource'];
            }
        }
        
        foreach ($resources as $resource) {
            $this->addResource($resource);
        }
    }

    protected function _addRules()
    {
        $webfolioGroupAclDbTable = new Model_DbTable_WebfolioGroupAcl();
        $groupACLs = $webfolioGroupAclDbTable->fetchAll();

        foreach ($groupACLs->toArray() as $groupAcl) {
             $groupId = ($groupAcl['group_id'] != null) ? (string)$groupAcl['group_id'] : null;
             $assert = ($groupAcl['assert'] != null && class_exists($groupAcl['assert'])) ? new $groupAcl['assert']() : null;

             $this->allow($groupId, $groupAcl['resource'], $groupAcl['privilege'], $assert);
        }
    }
}
?>
