<?php
/**
 * Webfolio CMS
 *
 * Copyright (C) 2009 Nikola Posa (http://www.nikolaposa.in.rs)
 *
 * This file is part of Webfolio CMS.
 *
 * Webfolio CMS is free software: you can redistribute it and/or modify 
 * it under the terms of the GNU General Public License as published by 
 * the Free Software Foundation, either version 3 of the License, or 
 * (at your option) any later version.
 *
 * Webfolio CMS is distributed in the hope that it will be useful, but 
 * WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU 
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License 
 * along with Webfolio CMS. If not, see <http://www.gnu.org/licenses/>.
 */

/**
 * DEPRECATED FROM VERSION 1.1
 *
 * Custom module bootstrapping resource was implemented in
 * version 1.1, which covers all functionality of this class,
 * so bootstrap classes of additional modules should extend
 * Zend_Application_Module_Bootstrap class.
 */

/**
 * Custom boostrap class, that all modules in Webfolio CMS 
 * must extend.
 *
 * @author Nikola Posa <posa.nikola@gmail.com>
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License
 */
abstract class WebfolioCMS_Application_Module_Bootstrap extends Zend_Application_Module_Bootstrap
{
	/**
     * Directory name of some module.
     *
     * @var string
     */
	private $moduleDirName;
	
	/**
     * Defined by Zend_Application_Bootstrap_BootstrapAbstract.
     *
     * @param Zend_Application|Zend_Application_Bootstrap_Bootstrapper $application
     * @return void
     */
    public function __construct($application)
    {
		if (WebfolioCMS_Common::isModuleActive($this->getModuleDirName())) {
			$application->setOptions($this->getModuleConfig()); //Adding module's configuration.
		}
		
        parent::__construct($application);
    }
	
	/**
     * Gets data from module's config file.
     *
     * @return array
     */
	private function getModuleConfig()
	{
		$moduleConfig = array();

		if (file_exists(($path = APPLICATION_PATH . '/modules/' . $this->getModuleDirName() . '/configs/module.php'))) {
			$moduleConfig[strtolower($this->getModuleName())] = include_once($path);
		}
		
		return $moduleConfig;
	}
	
	/**
     * Generates and returns directory name of some module.
     *
     * @return string
     */
	public function getModuleDirName()
	{
		if ($this->moduleDirName == null) {
			$cc2Dash = new Zend_Filter_Word_CamelCaseToDash();
		
			$this->moduleDirName = strtolower($cc2Dash->filter($this->getModuleName()));
		}
		
		return $this->moduleDirName;
	}

	/**
     * Defined by Zend_Application_Bootstrap_BootstrapAbstract. 
     *
     * We're overriding this method to provide custom modules 
	 * bootstrapping logic. Idea is to check that module is active, 
	 * because we want to bootstrap only active modules.
     * 
     * @param null|string|array $resource 
     * @return void
     */
	protected function _bootstrap($resource = null)
	{
		if (WebfolioCMS_Common::isModuleActive($this->getModuleDirName())) {
			parent::_bootstrap($resource);
		}
	}
}
