<?php
/**
 * Webfolio CMS
 *
 * Copyright (C) 2009 Nikola Posa (http://www.nikolaposa.in.rs)
 *
 * This file is part of Webfolio CMS.
 *
 * Webfolio CMS is free software: you can redistribute it and/or modify 
 * it under the terms of the GNU General Public License as published by 
 * the Free Software Foundation, either version 3 of the License, or 
 * (at your option) any later version.
 *
 * Webfolio CMS is distributed in the hope that it will be useful, but 
 * WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU 
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License 
 * along with Webfolio CMS. If not, see <http://www.gnu.org/licenses/>.
 */

/**
 * Custom cache manager resource, which provides capability for additional modules to add their own cache templates.
 *
 * @author Nikola Posa <posa.nikola@gmail.com>
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License
 */
class WebfolioCMS_Application_Resource_Cachemanager extends Zend_Application_Resource_Cachemanager
{
	const DEFAULT_REGISTRY_KEY = 'CacheManager';
	
    /**
     * Retrieve Zend_Cache_Manager instance
     *
     * @return Zend_Cache_Manager
     */
    public function getCacheManager()
    {
		$key = ( isset ($options['registry_key']) && !is_numeric($options['registry_key']))
             ? $options['registry_key']
             : self::DEFAULT_REGISTRY_KEY;
			 
		if (Zend_Registry::isRegistered($key)) {
			$this->_manager = Zend_Registry::get($key);
		}
		else {
			$this->_manager = new Zend_Cache_Manager();
			
		}
		
		$this->setTemplateOptions();
		
		Zend_Registry::set($key, $this->_manager);
        
        return $this->_manager;
    }
	
	/**
     * Sets cache templates options.
     *
     * @return void
     */
	protected function setTemplateOptions()
	{
		$options = $this->getOptions();
		
		foreach ($options as $key => $value) {
			if ($this->_manager->hasCacheTemplate($key)) {
				$this->_manager->setTemplateOptions($key, $value);
			} 
			else {
				$this->_manager->setCacheTemplate($key, $value);
			}
		}
	}
}
