<?php
/**
 * Webfolio CMS
 *
 * Copyright (C) 2009 Nikola Posa (http://www.nikolaposa.in.rs)
 *
 * This file is part of Webfolio CMS.
 *
 * Webfolio CMS is free software: you can redistribute it and/or modify 
 * it under the terms of the GNU General Public License as published by 
 * the Free Software Foundation, either version 3 of the License, or 
 * (at your option) any later version.
 *
 * Webfolio CMS is distributed in the hope that it will be useful, but 
 * WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU 
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License 
 * along with Webfolio CMS. If not, see <http://www.gnu.org/licenses/>.
 */

/**
 * Resource for setting available Webfolio CMS hooks.
 *
 * @author Nikola Posa <posa.nikola@gmail.com>
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License
 */
class WebfolioCMS_Application_Resource_Hooks extends Zend_Application_Resource_ResourceAbstract
{
	const SIDEBAR_ITEM    	      = 'sidebarItem';
	const CONTENT_PARSER  	      = 'contentParser';
	const CONTENT_PLUGIN  	      = 'contentPlugin';
	const ADMIN_MENU_PAGE         = 'adminMenuPage';
	const WF_ENTRY_FORM_PLUGIN    = 'WFEntryFormPlugin';
	const WF_EVENT_HANDLER        = 'webfolioEventHandler';
    const ADMIN_GROUP_PERMISSIONS = 'WFAdminGroupPermissions';

    /**
     * Available hook containers.
     *
     * @var array
     */
	protected $hookContainers = array(
		self::SIDEBAR_ITEM   	      => 'Model_WFSidebar',
		self::CONTENT_PARSER 	      => 'Model_ContentParsers',
		self::CONTENT_PLUGIN 	      => 'Model_ContentPlugins',
		self::ADMIN_MENU_PAGE 	      => 'Admin_Model_WFAdminMenu',
		self::WF_ENTRY_FORM_PLUGIN    => 'Admin_Model_WFEntryFormPlugins',
		self::WF_EVENT_HANDLER        => 'WebfolioCMS_Events_Broker',
        self::ADMIN_GROUP_PERMISSIONS => 'Admin_Model_WFAdminGroupPermissions'
	);

    /**
     * Containers that require name of the module which is adding
     * some data.
     *
     * @var array
     */
    protected $moduleRequired = array(
        self::SIDEBAR_ITEM,
        self::CONTENT_PLUGIN,
        self::WF_ENTRY_FORM_PLUGIN,
        self::ADMIN_GROUP_PERMISSIONS
    );

    /**
     * Defined by Zend_Application_Resource_Resource
     *
     * @return void
     */
    public function init()
    {
		$options = $this->getOptions();
		
		foreach ($options as $hook=>$data) {
			if (array_key_exists($hook, $this->hookContainers)) {
				if (is_numeric(key($data))) { //Array of hook data for same hook?
					foreach ($data as $hd) {
						$this->addHookData($hook, $hd);
					}
				}
				else {
					$this->addHookData($hook, $data);
				}
			}
		 }
    }
	
	/**
     * Adds data to appropriate hook handler.
     *
	 * @param string Hook name.
	 * @param array Hook data.
     * @return void
     */
	protected function addHookData($hook, $data)
	{
		if (in_array($hook, $this->moduleRequired)) {
            $bootstrap = $this->getBootstrap();
            $moduleName = 'default';
            if ($bootstrap instanceof Zend_Application_Module_Bootstrap) {
                $cc2Dash = new Zend_Filter_Word_CamelCaseToDash();

                $moduleName = strtolower($cc2Dash->filter($bootstrap->getModuleName()));
            }

			$data['module'] = $moduleName;
		}
			
		call_user_func(array($this->hookContainers[$hook], 'add'), $data);
	}
}
