<?php
/**
 * Webfolio CMS
 *
 * Copyright (C) 2009 Nikola Posa (http://www.nikolaposa.in.rs)
 *
 * This file is part of Webfolio CMS.
 *
 * Webfolio CMS is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Webfolio CMS is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Webfolio CMS. If not, see <http://www.gnu.org/licenses/>.
 */

/**
 * Custom module bootstrapping resource, that will bootstrap
 * only active modules. This resource will also add custom
 * configuration of some module (if such exists) in the
 * bootstrapping process.
 *
 * @author Nikola Posa <posa.nikola@gmail.com>
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License
 */
class WebfolioCMS_Application_Resource_Modules extends Zend_Application_Resource_Modules
{
    /**
     * Initialize modules
     *
     * @return array
     * @throws Zend_Application_Resource_Exception When bootstrap class was not found
     */
    public function init()
    {
        $bootstrap = $this->getBootstrap();
        $bootstrap->bootstrap('FrontController');
        $front = $bootstrap->getResource('FrontController');

        $modules = $front->getControllerDirectory();
        $default = $front->getDefaultModule();
        $curBootstrapClass = get_class($bootstrap);
        foreach ($modules as $module => $moduleDirectory) {
            if (WebfolioCMS_Common::isModuleActive($module)) { //Only if module is active.
                $bootstrapClass = $this->_formatModuleName($module) . '_Bootstrap';
                if (!class_exists($bootstrapClass, false)) {
                    $bootstrapPath  = dirname($moduleDirectory) . '/Bootstrap.php';
                    if (file_exists($bootstrapPath)) {
                        $eMsgTpl = 'Bootstrap file found for module "%s" but bootstrap class "%s" not found';
                        include_once $bootstrapPath;
                        if (($default != $module)
                            && !class_exists($bootstrapClass, false)
                        ) {
                            throw new Zend_Application_Resource_Exception(sprintf(
                                $eMsgTpl, $module, $bootstrapClass
                            ));
                        } elseif ($default == $module) {
                            if (!class_exists($bootstrapClass, false)) {
                                $bootstrapClass = 'Bootstrap';
                                if (!class_exists($bootstrapClass, false)) {
                                    throw new Zend_Application_Resource_Exception(sprintf(
                                        $eMsgTpl, $module, $bootstrapClass
                                    ));
                                }
                            }
                        }
                    } else {
                        continue;
                    }
                }

                if ($bootstrapClass == $curBootstrapClass) {
                    // If the found bootstrap class matches the one calling this
                    // resource, don't re-execute.
                    continue;
                }

                if (file_exists(($path = dirname($moduleDirectory) . '/configs/module.php'))) { //Adding module's configuration.
                    $moduleConfig = include $path;
                    $bootstrap->setOptions(array(strtolower($this->_formatModuleName($module))=>$moduleConfig));
                }

                $moduleBootstrap = new $bootstrapClass($bootstrap);
                $moduleBootstrap->bootstrap();
                $this->_bootstraps[$module] = $moduleBootstrap;
            }
        }

        return $this->_bootstraps;
    }
}
