<?php
/**
 * Webfolio CMS
 *
 * Copyright (C) 2009 Nikola Posa (http://www.nikolaposa.in.rs)
 *
 * This file is part of Webfolio CMS.
 *
 * Webfolio CMS is free software: you can redistribute it and/or modify 
 * it under the terms of the GNU General Public License as published by 
 * the Free Software Foundation, either version 3 of the License, or 
 * (at your option) any later version.
 *
 * Webfolio CMS is distributed in the hope that it will be useful, but 
 * WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU 
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License 
 * along with Webfolio CMS. If not, see <http://www.gnu.org/licenses/>.
 */
 
/**
 * Custom translate resource, which enables adding of translations 
 * for additional module.
 *
 * @author Nikola Posa <posa.nikola@gmail.com>
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License
 */
class WebfolioCMS_Application_Resource_Translate extends Zend_Application_Resource_Translate
{
    /**
     * Defined by Zend_Application_Resource_Translate.
     *
     * @return Zend_Translate
     */
    public function getTranslate()
    {
        $options = $this->getOptions();
 
        if (!$options['data']) {
			$bootstrapClass = get_class($this->getBootstrap());
			$module = substr($bootstrapClass, 0, strpos('_', $bootstrapClass));
			
            throw new Zend_Application_Resource_Exception('No translation source data provided for module: ' . $module . '.');
        }
 
        $adapter = isset($options['adapter']) ? $options['adapter'] : Zend_Translate::AN_ARRAY;
        $translateOptions = isset($options['options']) ? $options['options'] : array();
 
        $key = ( isset ($options['registry_key']) && !is_numeric($options['registry_key']))
             ? $options['registry_key']
             : self::DEFAULT_REGISTRY_KEY;
        
        if (Zend_Registry::isRegistered($key)) { 
			$this->_translate = Zend_Registry::get($key);
			$this->_translate->addTranslation($options['data'], $this->_translate->getLocale(), $translateOptions); //Merging additional translations.
        } 
		elseif ($this->getBootstrap()->hasResource('Locale')) { //No translate object in the registry, so we will create it.
            $this->_translate = new Zend_Translate($adapter, $options['data'], $this->getBootstrap()->getResource('Locale')->getLanguage(), $translateOptions);
        }
 
		if ($this->_translate != null) {
			Zend_Registry::set($key, $this->_translate);
		}
 
        return $this->_translate;
    }
}