<?php
/**
 * Webfolio CMS
 *
 * Copyright (C) 2009 Nikola Posa (http://www.nikolaposa.in.rs)
 *
 * This file is part of Webfolio CMS.
 *
 * Webfolio CMS is free software: you can redistribute it and/or modify 
 * it under the terms of the GNU General Public License as published by 
 * the Free Software Foundation, either version 3 of the License, or 
 * (at your option) any later version.
 *
 * Webfolio CMS is distributed in the hope that it will be useful, but 
 * WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU 
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License 
 * along with Webfolio CMS. If not, see <http://www.gnu.org/licenses/>.
 */
 
/**
 * Auth class that provides custom functionality for improving 
 * security of authentication process, by checking whether 
 * user is trying to access from the browser that was used 
 * during login process.
 *
 * @author Nikola Posa <posa.nikola@gmail.com>
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License
 */
class WebfolioCMS_Auth extends Zend_Auth
{
	/**
     * Returns an instance of WebfolioCMS_Auth.
     *
     * @return WebfolioCMS_Auth
     */
    public static function getInstance()
    {
        if (null === self::$_instance) {
            self::$_instance = new WebfolioCMS_Auth();
        }

        return self::$_instance;
    }
	
    /**
     * Defined by Zend_Auth.
     *
     * @return Zend_Auth_Result
     */
    public function authenticate(WebfolioCMS_Auth_Adapter_DbTable $adapter)
    {
        $result = parent::authenticate($adapter);

        if ($result->isValid()) {
            $identity = $result->getIdentity();
            
             //Storing user agent info in identity object, so it can be compared with same info of some user that is authenticated, when he/she tries to access some restricted resource.
            $identity->userAgent = $this->getUserAgentHash();

            $this->getStorage()->write($result->getIdentity());
        }

        return $result;

    }

    /**
     * Returns true if and only if an identity is available from 
	 * storage, and user agent info does not differs from one that 
	 * was retrieved during login process.
     *
     * @return boolean
     */
    public function hasIdentity()
    {
        if (!$this->getStorage()->isEmpty() && $this->getIdentity()->userAgent == $this->getUserAgentHash()) {
			return true;
		}
		else {
			return false;
		}
    }
	
	/**
     * Gets encrypted HTTP user agent info.
     *
     * @return string
     */
	private function getUserAgentHash()
	{
		$userAgent = ($request = Zend_Controller_Front::getInstance()->getRequest()) ? $request->getServer('HTTP_USER_AGENT') : $_SERVER['HTTP_USER_AGENT'];
		
		return sha1($userAgent);
	}
}
