<?php
/**
 * Webfolio CMS
 *
 * Copyright (C) 2009 Nikola Posa (http://www.nikolaposa.in.rs)
 *
 * This file is part of Webfolio CMS.
 *
 * Webfolio CMS is free software: you can redistribute it and/or modify 
 * it under the terms of the GNU General Public License as published by 
 * the Free Software Foundation, either version 3 of the License, or 
 * (at your option) any later version.
 *
 * Webfolio CMS is distributed in the hope that it will be useful, but 
 * WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU 
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License 
 * along with Webfolio CMS. If not, see <http://www.gnu.org/licenses/>.
 */
 
/**
 * Class that holds some common functions.
 *
 * @author Nikola Posa <posa.nikola@gmail.com>
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License
 */
class WebfolioCMS_Common
{
	/**
	 * Generates and returns base URL.
	 *
	 * @return string
	 */
	public static function baseUrl()
	{
		return ($baseUrl = Zend_Controller_Front::getInstance()->getBaseUrl()) ? $baseUrl : rtrim(Model_WebfolioSettings::getSettings('base_url'), '/\\');
	}
	
	/**
	 * Check whether user on the site is logged in.
	 *
	 * @return bool
	 */
	public static function isUserLoggedIn()
	{
		return WebfolioCMS_Auth::getInstance()->hasIdentity();
	}

    /**
	 * Check whether user has access to some resource, by utilizing
     * ACL class of this CMS.
	 *
	 * @return bool
	 */
    public static function isUserAllowed($group, $resource, $privilege = null)
	{
		return self::getAcl()->isAllowed($group, $resource, $privilege);
	}

    /**
	 * Retrieves ACL class of this CMS.
	 *
	 * @return bool
	 */
    public static function getAcl()
    {
        if (!$acl = Zend_Registry::get('CacheManager')->getCache('default')->load(WebfolioCMS_Acl::CACHE_ID)) {
            $acl = new WebfolioCMS_Acl();

            Zend_Registry::get('CacheManager')->getCache('default')->save($acl, WebfolioCMS_Acl::CACHE_ID, array('wf_acl', 'wf_group'));
        }

        return $acl;
    }
	
	/**
	 * Generates and returns URL of site which is powered by 
	 * Webfolio CMS.
	 *
	 * @return string
	 */
	public static function getSiteUrl()
	{
		$request = Zend_Controller_Front::getInstance()->getRequest();
		
		return $request->getScheme() . '://' . $request->getHttpHost() . Zend_Controller_Front::getInstance()->getBaseUrl();
	}
	
	/**
	 * DEPRECATED, dateTime view helper should be used instead.
	 *
	 * Retrieves date/time in format defined by user in "Settings"->"General" form in admin panel.
	 *
	 * @param string Date/time.
	 * @param bool Whether to append time, too.
	 * @return string
	 */
	public static function dateTime($dateTime = null, $appendTime = true)
	{
		$date = new Zend_Date($dateTime);
		$date->setOptions(array('format_type'=>'php'));
		
		$format = ($appendTime == true) ? Model_WebfolioSettings::getSettings('date_format') . ' ' . Model_WebfolioSettings::getSettings('time_format') : Model_WebfolioSettings::getSettings('date_format');
		
		return $date->toString($format);
	}
	
	/**
	 * Generates and returns Webfolio CMS email address, 
	 * that is used when sending some emails to the user of 
	 * this CMS. 
	 *
	 * @return string
	 */
	public static function generateWFEmail()
	{
		return 'webfolio_cms@' . str_replace('www.', '', Zend_Uri::factory(Model_WebfolioSettings::getSettings('site_url'))->getHost());
	}
	
	/**
	 * Check whether some module is active, based on its folder 
	 * name.
	 *
	 * @param string Module's folder name.
	 * @return bool
	 */
	public static function isModuleActive($moduleName)
	{
		$activeModules = Model_WebfolioSettings::getSettings('active_modules');
		
		return in_array($moduleName, $activeModules);
	}
}

