<?php
/**
 * Webfolio CMS
 *
 * Copyright (C) 2009 Nikola Posa (http://www.nikolaposa.in.rs)
 *
 * This file is part of Webfolio CMS.
 *
 * Webfolio CMS is free software: you can redistribute it and/or modify 
 * it under the terms of the GNU General Public License as published by 
 * the Free Software Foundation, either version 3 of the License, or 
 * (at your option) any later version.
 *
 * Webfolio CMS is distributed in the hope that it will be useful, but 
 * WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU 
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License 
 * along with Webfolio CMS. If not, see <http://www.gnu.org/licenses/>.
 */
 
/**
 * Action helper that adds path to admin module view helpers, 
 * in case that requested controller is admin controller of 
 * some additional module, or adds path to default module 
 * view helpers, in case that some module is using layout of  
 * default module (themes). 
 * Idea is to provide view helpers of admin module to modules 
 * that have controller for admin panel, or view helpers of
 * default module that has public logic controllers.
 *
 * @author Nikola Posa <posa.nikola@gmail.com>
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License
 */
class WebfolioCMS_Controller_Action_Helper_ModuleControllerInit extends Zend_Controller_Action_Helper_Abstract
{
    /**
     * Defined by Zend_Controller_Action_Helper_Abstract.
     *
     * @return void
     */
    public function preDispatch()
    {
		$module = $this->getRequest()->getModuleName();
		$controller = $this->getRequest()->getControllerName();
		
		if (!in_array($module, array('default', 'admin'))) { 
			if ($controller == 'admin') { //Admin controller of some module?
				$this->getActionController()->view->addHelperPath(APPLICATION_PATH . '/modules/admin/views/helpers');
			}
			else { //Some module that is using layout of default module.
				$this->getActionController()->view->addHelperPath(APPLICATION_PATH . '/views/helpers');
			}
		}
    }
}
?>