<?php
/**
 * Webfolio CMS
 *
 * Copyright (C) 2009 Nikola Posa (http://www.nikolaposa.in.rs)
 *
 * This file is part of Webfolio CMS.
 *
 * Webfolio CMS is free software: you can redistribute it and/or modify 
 * it under the terms of the GNU General Public License as published by 
 * the Free Software Foundation, either version 3 of the License, or 
 * (at your option) any later version.
 *
 * Webfolio CMS is distributed in the hope that it will be useful, but 
 * WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU 
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License 
 * along with Webfolio CMS. If not, see <http://www.gnu.org/licenses/>.
 */
 
/**
 * Action helper which enables themes to define how some 
 * webfolio entry content will be rendered. This helper 
 * redefines postDispatch hook to inject functionality for 
 * setting appropriate theme's view script as script path 
 * for the current request. For example, if current request 
 * is for rendering some entry of item type, this helper 
 * checks if there is view script with name item.phtml in 
 * directory of active theme, and if such file exists, it 
 * will be used for outputting result of the request.
 *
 * @author Nikola Posa <posa.nikola@gmail.com>
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License
 */
class WebfolioCMS_Controller_Action_Helper_ThemeEntryRender extends Zend_Controller_Action_Helper_Abstract
{
    /**
     * Defined by Zend_Controller_Action_Helper_Abstract.
     *
     * @return void
     */
    public function postDispatch()
    {
		if (Zend_Registry::isRegistered(WebfolioCMS_Controller_Action_Helper_WFEntryFinder::CURRENT_WF_ENTRY_KEY)) { //Has some webfolio entry assigned?
			$key = Zend_Registry::get(WebfolioCMS_Controller_Action_Helper_WFEntryFinder::CURRENT_WF_ENTRY_KEY);
			$entry = $this->getActionController()->view->$key;
			$activeThemePath = BASE_PATH . '/front-end/themes/' . Model_WebfolioSettings::getSettings('theme_dir');
			
			if (file_exists($activeThemePath . '/' . $entry['type'] . '.phtml')) { //Theme has file for outputting this entry type?
				$this->getActionController()->getHelper('viewRenderer')->setNoController(true);
				$this->getActionController()->getHelper('viewRenderer')->view->addScriptPath($activeThemePath);
				$this->getActionController()->getHelper('viewRenderer')->setScriptAction($entry['type']);
			}
		}
    }

}
?>