<?php
/**
 * Webfolio CMS
 *
 * Copyright (C) 2009 Nikola Posa (http://www.nikolaposa.in.rs)
 *
 * This file is part of Webfolio CMS.
 *
 * Webfolio CMS is free software: you can redistribute it and/or modify 
 * it under the terms of the GNU General Public License as published by 
 * the Free Software Foundation, either version 3 of the License, or 
 * (at your option) any later version.
 *
 * Webfolio CMS is distributed in the hope that it will be useful, but 
 * WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU 
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License 
 * along with Webfolio CMS. If not, see <http://www.gnu.org/licenses/>.
 */
 
/**
 * Action helper which is trying to find currently assigned 
 * content (page, webfolio item, or other content of some 
 * additional module which is also type of webfolio entry), 
 * and stores its key into the registry so it can be used by 
 * some other action (content parser) and view (ContentPlugin) 
 * helpers.
 *
 * @author Nikola Posa <posa.nikola@gmail.com>
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License
 */
class WebfolioCMS_Controller_Action_Helper_WFEntryFinder extends Zend_Controller_Action_Helper_Abstract
{
	const CURRENT_WF_ENTRY_KEY = 'currentWFEntryKey';
	
    /**
     * Defined by Zend_Controller_Action_Helper_Abstract.
     *
     * @return void
     */
    public function postDispatch()
    {	
		if ($this->getRequest()->getModuleName() != 'admin') { //We don't need to run this process, if we're on admin module.
			$this->findCurrentWFEntry();
		}
    }
	
	/**
	 * Finds webfolio entry that is currently being assigned to the 
	 * view and stores its view key into the registry, so it can be 
	 * retrieved by some other action or view helpers.
	 *
	 * @return void
	 */
	protected function findCurrentWFEntry()
	{
		$viewKey = null;
		
		if ($this->getActionController()->view->entry) { //Some page/item is requested on IndexController?
			$viewKey = 'entry';
		}
		else { //We should also check for some other webfolio entry...
			foreach ($this->getActionController()->view->getVars() as $key=>$variable) {
				if ($variable instanceof Model_WebfolioEntries 
					|| (is_array($variable) && count(array_intersect(array('title', 'text', 'type'), array_keys($variable))) == 3)
					|| ($variable instanceof Zend_Db_Table_Row && count(array_intersect(array('title', 'text', 'type'), array_keys($variable->toArray()))) == 3)
				) { //Found some webfolio entry?
					$viewKey = $key;
					break;
				}
			}
		}
		
		if ($viewKey != null) {
			Zend_Registry::set(self::CURRENT_WF_ENTRY_KEY, $viewKey);
		}
	}
}
?>