<?php
/**
 * Webfolio CMS
 *
 * Copyright (C) 2009 Nikola Posa (http://www.nikolaposa.in.rs)
 *
 * This file is part of Webfolio CMS.
 *
 * Webfolio CMS is free software: you can redistribute it and/or modify 
 * it under the terms of the GNU General Public License as published by 
 * the Free Software Foundation, either version 3 of the License, or 
 * (at your option) any later version.
 *
 * Webfolio CMS is distributed in the hope that it will be useful, but 
 * WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU 
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License 
 * along with Webfolio CMS. If not, see <http://www.gnu.org/licenses/>.
 */

/**
 * DEPRECATED FROM VERSION 1.1
 *
 * Class with custom event handler methods should be used when
 * registering event handler with WebfolioCMS_Events_Broker
 * hook container.
 */

/**
 * This class should be extended by models of some additional 
 * modules, which want to inject their own logic when some 
 * various events occur. This class provides hook methods, 
 * that are triggered at appropriate time, during execution of 
 * some event. Most of those events are related with WFEntry 
 * forms, and this class has methods that are called during 
 * population, pre-rendering and validation of some of those 
 * forms, and because of that all modules that have registered 
 * their additional WFEntry form elements, with 
 * Admin_Model_WFEntryForm_Plugins hook, should also use this 
 * hook, for injecting some custom logic for supplied form 
 * elements and logic for handling data from those elements.
 * 
 *
 * @author Nikola Posa <posa.nikola@gmail.com>
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License
 */
abstract class WebfolioCMS_Events_Handler_Abstract
{
	/**
     * Called when initializing instance of this class, before 
	 * adding it into broker's stack. This method should be used 
	 * for some custom initialization. 
	 *
     * @return void
     */
    public function init()
    {
    }
	
	/**
     * Called before saving some submitted user comment.  
	 *
	 * @param Model_WebfolioComments Submitted comment.
     * @return void
     */
    public function WFCommentPreSave(Model_WebfolioComments $comment)
    {
    }
	
	/**
     * Called after inserting comment on some webfolio entry page. 
	 * This method should be used for outputing some message to user 
	 * who is posting comment, as comments are submitted through 
	 * AJAX request.  
	 *
	 * @param Model_WebfolioComments Comment that was just inserted in database.
     * @return void
     */
    public function WFCommentPostSave(Model_WebfolioComments $comment)
    {
    }
	
	/**
     * Called prior to populating WFEntry form with some values. 
	 * This method should be used to set values for form elements 
	 * that were added by module which uses this class, using . 
	 *
	 * @param Admin_Form_WFEntry Form of WFEntry type that is currently being used by user.
     * @return void
     */
    public function WFEntryFormPopulate(Admin_Form_WFEntry $WFEntryForm)
    {
    }
	
	/**
     * Called prior to rendering some WFEntry form. This should be 
	 * used for injecting some custom pre-render logic.
	 *
	 * @param Admin_Form_WFEntry Form of WFEntry type that is currently being used by user.
     * @return void
     */
	public function WFEntryFormPreRender(Admin_Form_WFEntry $WFEntryForm)
	{
	}
	
	/**
     * Called prior to WFEntry form validation. This should be used 
	 * for injecting some custom pre-validation logic.
	 *
	 * @param Admin_Form_WFEntry Form of WFEntry type that is currently being used by user.
	 * @param array Submitted data from the form.
     * @return void
     */
	public function WFEntryFormPreValidation(Admin_Form_WFEntry $WFEntryForm, $data)
	{
	}
	
	/**
     * Called during save() method of WebfolioEntries model 
	 * instance, that is called from the WFEntry form GUI.
	 *
	 * @param Admin_Form_WFEntry Form of WFEntry type that is currently being used by user.
	 * @param int Id of a webfolio entry that was just inserted or being edited.
     * @return void
     */
	 public function WFEntrySave(Admin_Form_WFEntry $WFEntryForm, $WFEntryId)
	 {
	 }
	 
	 /**
     * Called when deleting some webfolio entry, in delete.php 
	 * ajax_handler, whtether from the actual WFEntry form, or from 
	 * some grid which displays webfolio entries.
	 *
	 * @param array Array with ids of a webfolio entries that were just deleted.
     * @return void
     */
	 public function WFEntryDelete(array $WFEntryIds)
	 {
	 }
}

