<?php
/**
 * Webfolio CMS
 *
 * Copyright (C) 2009 Nikola Posa (http://www.nikolaposa.in.rs)
 *
 * This file is part of Webfolio CMS.
 *
 * Webfolio CMS is free software: you can redistribute it and/or modify 
 * it under the terms of the GNU General Public License as published by 
 * the Free Software Foundation, either version 3 of the License, or 
 * (at your option) any later version.
 *
 * Webfolio CMS is distributed in the hope that it will be useful, but 
 * WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU 
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License 
 * along with Webfolio CMS. If not, see <http://www.gnu.org/licenses/>.
 */
 
/**
 * Custom decorator for rendering error messages.
 * 
 * @author Nikola Posa <posa.nikola@gmail.com>
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License
 */
class WebfolioCMS_Form_Decorator_Errors extends Zend_Form_Decorator_Abstract
{
	const DEFAULT_CLASS = 'error_message';
	
	/**
     * Custom error message to be used for some element.
	 *
     * @var string
     */
    protected $_customErrorMessage = null;
	
	/**
     * Gets custom error message.
     *
     * @return string
     */
    public function getCustomErrorMessage()
    {
        if (null === $this->_customErrorMessage) {
            $customErrorMessage = $this->getOption('customErrorMessage');
            if (null !== $customErrorMessage) {
                $this->removeOption('customErrorMessage');
                $this->setCustomErrorMessage($customErrorMessage);
            }
			
            return $customErrorMessage;
        }

        return $this->_customErrorMessage;
    }

    /**
     * Sets custom error message.
     *
     * @param string Custom error message
     * @return WebfolioCMS_Form_Decorator_Errors
     */
    public function setCustomErrorMessage($customErrorMessage)
    {
        if (empty($customErrorMessage)) {
            $this->_customErrorMessage = null;
        } else {
            $this->_customErrorMessage = (string)$customErrorMessage;
        }
		
        return $this;
    }
	
    /**
     * Renders error message.
     * 
     * @param string $content 
     * @return string
     */
    public function render($content)
    {
        $element = $this->getElement();

        $errors = $element->getMessages();
        if (empty($errors)) {
            return $content;
        }

        $separator = $this->getSeparator();
		
		$class = ($cls = $this->getOption('class')) ? $cls  : self::DEFAULT_CLASS;
		$error = ($customErrorMessage = $this->getCustomErrorMessage()) ? $customErrorMessage : current($errors);
		
		$output = '<span class = "' . $class . '">' . $error . '</span>';

        switch ($this->getPlacement()) {
            case self::APPEND:
                return $content . $separator . $output;
            case self::PREPEND:
                return $output . $separator . $content;
        }
    }
}
