<?php
/**
 * Webfolio CMS
 *
 * Copyright (C) 2009 Nikola Posa (http://www.nikolaposa.in.rs)
 *
 * This file is part of Webfolio CMS.
 *
 * Webfolio CMS is free software: you can redistribute it and/or modify 
 * it under the terms of the GNU General Public License as published by 
 * the Free Software Foundation, either version 3 of the License, or 
 * (at your option) any later version.
 *
 * Webfolio CMS is distributed in the hope that it will be useful, but 
 * WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU 
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License 
 * along with Webfolio CMS. If not, see <http://www.gnu.org/licenses/>.
 */

/**
 * Custom form decorator, for displaying info for some 
 * element.
 * @author Nikola Posa <posa.nikola@gmail.com>
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License
 */
class WebfolioCMS_Form_Decorator_Info extends Zend_Form_Decorator_Abstract
{	
	/**
     * Text that will be displayed as info.
	 *
     * @var string
     */
    protected $_text;
	
	/**
     * Gets text that will be displayed as info.
     *
     * @return string
     */
    public function getText()
    {
        if (null === $this->_text) {
            $text = $this->getOption('text');
            if (null !== $text) {
                $this->removeOption('text');
                $this->setText($text);
            }
			
            return $text;
        }

        return $this->_text;
    }

    /**
     * Sets text that will be displayed as info.
     *
     * @param string Text
     * @return WebfolioCMS_Form_Decorator_Info
     */
    public function setText($text)
    {
        if (empty($text)) {
            $this->_text = null;
        } else {
            $this->_text = (string)$text;
        }
		
        return $this;
    }
	
	/**
     * Gets info to render, using tooltip view helper.
     *
     * @return void
     */
    public function getInfo()
    {
        return $this->getElement()->getView()->tooltip($this->getText());
    }
	
    /**
     * Defined by Zend_Form_Decorator_Abstract.
     *
     * @param string $content
     * @return string 
     */
	public function render($content)
    {
		$info = $this->getInfo();
		$separator = $this->getSeparator();

        switch ($this->getPlacement()) {
            case self::APPEND:
                return $content . $separator . $info;
            case self::PREPEND:
                return $info . $separator . $content;
        }
    }
    
}