<?php
/**
 * Custom Webfolio CMS display group that is used for grouping 
 * elements in forms in admin panel.
 *
 * @author Nikola Posa <posa.nikola@gmail.com>
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License
 */
class WebfolioCMS_Form_DisplayGroup extends Zend_Form_DisplayGroup
{
    /**
     * Defined by Zend_Form_DisplayGroup.
     * 
	 * We must wrap our fieldset around grouping elements.
	 * 
     * @return void
     */
    public function loadDefaultDecorators()
    {
		if ($this->loadDefaultDecoratorsIsDisabled()) {
            return;
        }

        if (!$this->getDecorator('viewScript') && !$this->getDecorator('viewHelper')) {
            $this->addDecorator('FormElements');
        }

        $fieldsetClass = ($this->getAttrib('startExpanded') == true) ? 'collapsible' : 'collapsible collapsed';
        $this->removeAttrib('startExpanded');
		$this->addDecorator('HtmlTag', array('tag' => 'div'))->addDecorator('Fieldset', array('class'=>$fieldsetClass));
    }
	
	/**
     * Render display group
     * 
     * @return string
     */
    public function render(Zend_View_Interface $view = null)
    {
		if (!empty($this->_elements)) {
			foreach ($this->_elements as $element) {
				if ($element->hasErrors()) {
					$this->getDecorator('Fieldset')->setOption('class', 'collapsible'); //We have to make visible some display group in case any of elements in that group has some error message.
					break;
				}
			}
			
			return parent::render($view);
		}
		else {
			return '';
		}
    }
}
