<?php
/**
 * Webfolio CMS
 *
 * Copyright (C) 2009 Nikola Posa (http://www.nikolaposa.in.rs)
 *
 * This file is part of Webfolio CMS.
 *
 * Webfolio CMS is free software: you can redistribute it and/or modify 
 * it under the terms of the GNU General Public License as published by 
 * the Free Software Foundation, either version 3 of the License, or 
 * (at your option) any later version.
 *
 * Webfolio CMS is distributed in the hope that it will be useful, but 
 * WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU 
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License 
 * along with Webfolio CMS. If not, see <http://www.gnu.org/licenses/>.
 */
 
/**
 * Base class for all viewHelper-based hook handlers.
 *
 * @author Nikola Posa <posa.nikola@gmail.com>
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License
 */
abstract class WebfolioCMS_HookContainer_HelperBased_Abstract extends WebfolioCMS_HookContainer_Abstract
{
	const MODULE_KEY 	  = 'module';
	const HELPER_NAME_KEY = 'helperName';
	
	/**
	 * Defined by WebfolioCMS_HookContainer_Abstract.
	 * 
	 * ViewHelper hook data includes view helper names, and this 
	 * method checks whether some view helper actually exists.
	 *
	 * @param array Hook data.
	 * @return bool
	 */
	protected function isValid($hookData)
	{
		if (
			(array_key_exists(self::MODULE_KEY, $hookData) && array_key_exists(self::HELPER_NAME_KEY, $hookData))
			&&
			($hookData[self::MODULE_KEY] == 'default' || file_exists(APPLICATION_PATH . '/modules/' . $hookData[self::MODULE_KEY] . '/views/helpers/' . ucfirst($hookData[self::HELPER_NAME_KEY]) . '.php'))
		) {
			return parent::isValid($hookData);
		}
		
		return false;
	}
}
?>