<?php
/**
 * Webfolio CMS
 *
 * Copyright (C) 2009 Nikola Posa (http://www.nikolaposa.in.rs)
 *
 * This file is part of Webfolio CMS.
 *
 * Webfolio CMS is free software: you can redistribute it and/or modify 
 * it under the terms of the GNU General Public License as published by 
 * the Free Software Foundation, either version 3 of the License, or 
 * (at your option) any later version.
 *
 * Webfolio CMS is distributed in the hope that it will be useful, but 
 * WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU 
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License 
 * along with Webfolio CMS. If not, see <http://www.gnu.org/licenses/>.
 */
 
/**
 * Class for sending emails in Webfolio CMS.
 *
 * @author Nikola Posa <posa.nikola@gmail.com>
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License
 */
class WebfolioCMS_Mail extends Zend_Mail
{
	const FROM_NAME = 'Webfolio CMS';
	
	/**
     * Defined by Zend_Mail.
     *
     * @param string $charset
     */
    public function __construct($charset = 'utf-8')
    {
        parent::__construct($charset);
		
		$this->setFrom($this->generateWFEmail(), self::FROM_NAME);
    }
	
	/**
	 * Generates and returns email address for the site that is 
	 * running on Webfolio CMS. 
	 *
	 * @return string
	 */
	protected function generateWFEmail()
	{
		return 'webfolio_cms@' . str_replace('www.', '', Zend_Uri::factory(Model_WebfolioSettings::getSettings('site_url'))->getHost());
	}
	
	/**
     * Defined by Zend_Mail.
     *
     * @param  string $txt
     * @param  string $charset
     * @param  string $encoding
     * @return Zend_Mail Provides fluent interface
    */
    public function setBodyText($txt, $charset = null, $encoding = Zend_Mime::ENCODING_QUOTEDPRINTABLE)
    {
        $txt .= "\r\n\r\n" . 'Webfolio CMS';

        return parent::setBodyText($txt, $charset, $encoding);
    }
	
	/**
     * Defined by Zend_Mail.
     *
     * @param  string    $html
     * @param  string    $charset
     * @param  string    $encoding
     * @return Zend_Mail Provides fluent interface
     */
    public function setBodyHtml($html, $charset = null, $encoding = Zend_Mime::ENCODING_QUOTEDPRINTABLE)
    {
		$html .= '
			<p>Webfolio CMS</p>';
		
		return parent::setBodyHtml($html, $charset, $encoding);
    }
}
?>