<?php
/**
 * Webfolio CMS
 *
 * Copyright (C) 2009 Nikola Posa (http://www.nikolaposa.in.rs)
 *
 * This file is part of Webfolio CMS.
 *
 * Webfolio CMS is free software: you can redistribute it and/or modify 
 * it under the terms of the GNU General Public License as published by 
 * the Free Software Foundation, either version 3 of the License, or 
 * (at your option) any later version.
 *
 * Webfolio CMS is distributed in the hope that it will be useful, but 
 * WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU 
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License 
 * along with Webfolio CMS. If not, see <http://www.gnu.org/licenses/>.
 */
 
/**
 * Validator that checks if title supplied in some webfolio 
 * entry form already exists.
 *
 * @author Nikola Posa <posa.nikola@gmail.com>
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License
 */
class WebfolioCMS_Validate_DuplicateTitle extends Zend_Validate_Abstract
{
	const DUPLICATE_TITLE = 'duplicateTitle';
	
	/**
     * Webfolio entry type for which this validator is being used.
     *
     * @var string
     */
	protected $_type;
	
	/**
     * Constructor.
     *
     * @param string Webfolio entry type.
     * @return WebfolioCMS_Validate_DuplicateTitle
     */
    public function __construct($type)
    {
        $this->setType($type);
		
		$this->_messageTemplates = array(
			self::DUPLICATE_TITLE => ucfirst($this->getType()) . ' with that title already exists. Please supply some other title.'
		);
    }
	
	/**
     * Returns webfolio entry type for which this validator is 
	 * being used.
     *
     * @return string
     */
    public function getType()
    {
        return $this->_type;
    }
	
	/**
     * Sets webfolio entry type for which this validator is being 
	 * used.
     *
     * @param string Webfolio entry type.
     * @return WebfolioCMS_Validate_DuplicateTitle
     */
    public function setType($type)
    {
        $this->_type = (string)$type;
		
        return $this;
    }
	
	/**
	 * Defined by Zend_Validate_Interface.
	 *
	 * Sends query and checks if title supplied in item form 
	 * already exists.
	 *
	 * @param string Form element (title) value.
	 * @param array Data submitted in the form.
	 * @return bool
	 */
    public function isValid($value, $context = null)
    {
		$dbHandler = Zend_Registry::get('dbHandler');
		$sql = 'SELECT id 
				FROM wf_entries 
				WHERE type = ' . $dbHandler->quote($this->_type) . ' AND title = ' . $dbHandler->quote($value) . ' AND id != ' . $dbHandler->quote($context['id'], Zend_DB::INT_TYPE);
				
		$result = $dbHandler->fetchAll($sql);
		
		if (empty($result)) {
			return true;
		}
		else {
			$this->_error();
			return false;
		}
    }
}
?>