<?php
/**
 * Webfolio CMS
 *
 * Copyright (C) 2009 Nikola Posa (http://www.nikolaposa.in.rs)
 *
 * This file is part of Webfolio CMS.
 *
 * Webfolio CMS is free software: you can redistribute it and/or modify 
 * it under the terms of the GNU General Public License as published by 
 * the Free Software Foundation, either version 3 of the License, or 
 * (at your option) any later version.
 *
 * Webfolio CMS is distributed in the hope that it will be useful, but 
 * WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU 
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License 
 * along with Webfolio CMS. If not, see <http://www.gnu.org/licenses/>.
 */
 
/**
 * Validator that checks if username supplied in user profile 
 * form (somehow) already exists.
 *
 * @author Nikola Posa <posa.nikola@gmail.com>
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License
 */
class WebfolioCMS_Validate_DuplicateUsername extends Zend_Validate_Abstract
{
	const DUPLICATE_TITLE = 'duplicateUsername';
	
	 /**
     * Validation failure message template definitions
     *
     * @var array
     */
    protected $_messageTemplates = array(
        self::DUPLICATE_TITLE => 'That username already exists. Please supply some other username.'
    );
	
	/**
     * Defined by Zend_Validate_Interface
     *
     * Returns true if and only if $value contains only alphabetic and digit characters
     *
     * @param  string $value
     * @return boolean
     */
    public function isValid($value, $context = null)
    {
		$dbHandler = Zend_Registry::get('dbHandler');
		$sql = 'SELECT id 
				FROM ' . $this->dbTableName . ' 
				WHERE title = ' . $dbHandler->quote($value) . ' AND id != ' . $dbHandler->quote($context['id'], Zend_DB::INT_TYPE);
				
		$result = $dbHandler->fetchAll($sql);
		
		if (empty($result)) {
			return true;
		}
		else {
			$this->_error();
			return false;
		}
    }
}
?>