<?php
/**
 * Webfolio CMS
 *
 * Copyright (C) 2009 Nikola Posa (http://www.nikolaposa.in.rs)
 *
 * This file is part of Webfolio CMS.
 *
 * Webfolio CMS is free software: you can redistribute it and/or modify 
 * it under the terms of the GNU General Public License as published by 
 * the Free Software Foundation, either version 3 of the License, or 
 * (at your option) any later version.
 *
 * Webfolio CMS is distributed in the hope that it will be useful, but 
 * WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU 
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License 
 * along with Webfolio CMS. If not, see <http://www.gnu.org/licenses/>.
 */
 
/**
 * Abstract class which all view helpers that want to act as 
 * content plugins must extend from.
 *
 * @author Nikola Posa <posa.nikola@gmail.com>
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License
 */
abstract class WebfolioCMS_View_Helper_ContentPlugin_Abstract extends Zend_View_Helper_Abstract
{
	/**
	 * Type of a content plugin (i.e. PRE or POST content). 
	 * Because same view helper can be used as, for example, 
	 * both PRE or POST content plugin, this variable should 
	 * be used by helper's custom logic.
	 *
	 * @var string
	 */
	protected $type;
	
	/**
	 * Sets plugin type.
	 *
	 * @return void
	 */
	public function setType($type)
	{
		$this->type = (string)$type;
	}
	
	/**
	 * Plugins may use some partial view scripts of site's themes, 
	 * and this function checks whether theme has partial view 
	 * script with supplied name, so plugin can use that script for 
	 * partial rendering.
	 *
	 * @param string File name of some active theme's view script.
	 * @return bool
	 */
	protected function hasThemeViewScript($fileName)
	{
		return is_file(BASE_PATH . '/front-end/themes/' . Model_WebfolioSettings::getSettings('theme_dir') . '/' . $fileName);
	}
	
	/**
	 * Renders content of some plugin.
	 *
	 * @param mixed Content that is currently being outputted.
	 * @return string
	 */
	abstract public function render($content);
}
?>