<?php
/**
 * Webfolio CMS
 *
 * Copyright (C) 2009 Nikola Posa (http://www.nikolaposa.in.rs)
 *
 * This file is part of Webfolio CMS.
 *
 * Webfolio CMS is free software: you can redistribute it and/or modify 
 * it under the terms of the GNU General Public License as published by 
 * the Free Software Foundation, either version 3 of the License, or 
 * (at your option) any later version.
 *
 * Webfolio CMS is distributed in the hope that it will be useful, but 
 * WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU 
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License 
 * along with Webfolio CMS. If not, see <http://www.gnu.org/licenses/>.
 */
 
/**
 * ViewHelper for generating date/time.
 *
 * @author Nikola Posa <posa.nikola@gmail.com>
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License
 */
class WebfolioCMS_View_Helper_DateTime extends Zend_View_Helper_Abstract
{
	/**
	 * Zend_Date object.
	 *
	 * @var Zend_Date
	 */
	protected $_date;
	
	/**
	 * Date format configured by user of Webfolio CMS.
	 *
	 * @var string
	 */
	protected $_defaultDateFormat;
	
	/**
	 * Time format configured by user of Webfolio CMS.
	 *
	 * @var string
	 */
	protected $_defaultTimeFormat;
	
	/**
	 * Constructor.
	 *
	 * @return void
	 */
	public function __construct()
	{
        //Initializing Zend_Date object.
		$this->_date = new Zend_Date();
		$this->_date->setOptions(array('format_type'=>'php'));

		$this->_defaultDateFormat = Model_WebfolioSettings::getSettings('date_format');
		$this->_defaultTimeFormat = Model_WebfolioSettings::getSettings('time_format');
	}
	
	/**
	 * View helper entry point. 
	 *
	 * Returns dateTime helper object or optionally allows direct 
	 * rendering of date/time.
	 * 
	 * @param string|null Date/time. (optional)
	 * @param string Mode ("date" or "time"). (optional)
	 * @param string|null The format the date/time will be displayed in. Defaults to the date and time format configured by user of Webfolio CMS. (optional)
	 * @return string
	 */
	public function dateTime($dateTime = null, $mode = null, $format = null)
	{	
		$timestamp = null;
		if ($dateTime != null && !($timestamp = strtotime((string)$dateTime))) {	
			throw new Exception('Invalid date/time string is supplied.');
		}

        $this->_date->setTimestamp($timestamp);
        
		if ($mode !== null && is_string($mode)) { //Direct usage of this helper?
			$action = 'render' . ucfirst($mode);
			
			return $this->$action($format);
		}
		else {
			return $this;
		}
	}
	
	/**
     * Overload method access. Renders date/time.
     *
     * Allows the following method calls:
     * - renderDate($format = null)
     * - renderTime($format = null)
     *
     * @param string Method name.
     * @param array The parameters for the method.
     * @return string
     */
	public function __call($method, $args)
	{
		if (preg_match('/^render(Date|Time)$/', $method, $matches)) {
			$defaultFormat = '_default' . $matches[1] . 'Format';
			
			$format = $args[0];
			$format = ($format != null) ? (string)$format : $this->$defaultFormat;
			
			return $this->_date->toString($format);
		}
		else {
			throw new Exception('Method ' . $method . ' does not exist in ' . get_class($this) . ' class.');
		}
	}
}
?>